@@ -8,7 +8,7 @@
 
 #################################################################################
 #    PHP-RESIDENCE
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2004 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -32,32 +32,39 @@ $vecchio = @is_file("./dati/connessione_db.php");
 if ($molto_vecchio) {
 include ("./datipermanenti/connessione_db.inc");
 $PHPR_DB_TYPE = "postgresql";
+$PHPR_TAB_PRE = "";
+include("./includes/funzioni_$PHPR_DB_TYPE.php");
 } # fine if ($molto_vecchio)
 else {
 if ($vecchio) {
 include ("./dati/connessione_db.php");
 $PHPR_DB_TYPE = "postgresql";
+$PHPR_TAB_PRE = "";
+include("./includes/funzioni_$PHPR_DB_TYPE.php");
 } # fine if ($vecchio)
 else {
 include("./dati/dati_connessione.php");
+include("./includes/funzioni_$PHPR_DB_TYPE.php");
 connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
 } # fine else if ($vecchio)
 } # fine else if ($molto_vecchio)
 
-include("./includes/funzioni_$PHPR_DB_TYPE.php");
 include ("./includes/funzioni.php");
+include("./dati/lingua.php");
+if (@is_array($lingua)) $lingua_mex = $lingua[1];
+else $lingua_mex = $lingua;
 
 
-$versione_corrente = @pg_exec("select * from versioni where idversioni = 1");
+$versione_corrente = @esegui_query("select * from ".$PHPR_TAB_PRE."versioni where idversioni = 1");
 
-#pg_exec("begin");
-#pg_exec("lock table anni");
-$anni = pg_exec("select * from anni order by idanni");
-$num_anni = pg_numrows($anni);
+#esegui_query("begin");
+#esegui_query("lock table anni");
+$anni = esegui_query("select * from ".$PHPR_TAB_PRE."anni order by idanni");
+$num_anni = numlin_query($anni);
 for ($num1 = 0 ; $num1 < $num_anni ; $num1 = $num1 + 1) {
-$anno_mostra = pg_result($anni,$num1,idanni);
-$tableprenota = prenota. $anno_mostra;
-pg_exec("lock table $tableprenota");
+$anno_mostra = risul_query($anni,$num1,idanni);
+$tableprenota = $PHPR_TAB_PRE."prenota".$anno_mostra;
+#pg_exec("lock table $tableprenota");
 } # fine for $num1
 
 
@@ -68,9 +75,9 @@ pg_exec("insert into versioni (idversioni, num_versione) values (1, '0.1')");
 $versione_corrente = "0.1";
 } # fine if (!$versione_corrente)
 else {
-pg_exec("lock table versioni");
-$versione_corrente = pg_exec("select * from versioni where idversioni = 1");
-$versione_corrente = pg_result($versione_corrente,0,num_versione);
+#pg_exec("lock table versioni");
+#$versione_corrente = esegui_query("select * from versioni where idversioni = 1");
+$versione_corrente = risul_query($versione_corrente,0,num_versione);
 } # fine else if (!$versione_corrente)
 
 if ($versione_corrente < "0.12") {
@@ -290,15 +297,15 @@ rmdir("$anno_mostra");
 } # fine for $num1
 } # fine if ($versione_corrente < "0.19")
 else {
-pg_exec("lock table appartamenti");
+#pg_exec("lock table appartamenti");
 for ($num1 = 0 ; $num1 < $num_anni ; $num1 = $num1 + 1) {
-$anno_mostra = pg_result($anni,$num1,idanni);
+$anno_mostra = risul_query($anni,$num1,idanni);
 $tableregole = regole. $anno_mostra;
-pg_exec("lock table $tableregole");
+#pg_exec("lock table $tableregole");
 $tablesoldi = soldi. $anno_mostra;
-pg_exec("lock table $tablesoldi");
+#pg_exec("lock table $tablesoldi");
 } # fine for $num1
-pg_exec("lock table personalizza");
+#pg_exec("lock table personalizza");
 } # fine else if ($versione_corrente < "0.19")
 
 if ($versione_corrente < "0.21") {
@@ -617,10 +624,120 @@ copy ("dati/selectperiodi$anno_cambia.php","dati/selperiodimenu$anno_cambia.php"
 } # fine for $num_a
 } # fine if ($versione_corrente < "0.30")
 
+if ($versione_corrente < "0.31") {
+$aggiornato = "SI";
+$anni = esegui_query("select * from anni order by idanni");
+$num_anni = numlin_query($anni);
+for ($num_a = 0 ; $num_a < $num_anni ; $num_a++) {
+$anno_cambia = risul_query($anni,$num_a,idanni);
+$tablenometariffe = ntariffe . $anno_cambia;
+$idntariffe = esegui_query("select max(idntariffe) from $tablenometariffe");
+$idntariffe = risul_query($idntariffe,0,0) + 1;
+esegui_query("update $tablenometariffe set regole = '$idntariffe' where idntariffe = 1");
+} # fine for $num_a
+} # fine if ($versione_corrente < "0.31")
+
+if ($versione_corrente < "0.32") {
+$aggiornato = "SI";
+include("./dati/dati_connessione.php");
+$file_conn = fopen("./dati/dati_connessione.php","w+");
+fwrite($file_conn,"<?php
+\$PHPR_DB_TYPE = \"$PHPR_DB_TYPE\";
+\$PHPR_DB_NAME = \"$PHPR_DB_NAME\";
+\$PHPR_DB_HOST = \"$PHPR_DB_HOST\";
+\$PHPR_DB_PORT = \"$PHPR_DB_PORT\";
+\$PHPR_DB_USER = \"$PHPR_DB_USER\";
+\$PHPR_DB_PASS = \"$PHPR_DB_PASS\";
+\$PHPR_LOAD_EXT = \"$PHPR_LOAD_EXT\";
+\$PHPR_TAB_PRE = \"\";
+?>");
+fclose($file_conn);
+$PHPR_TAB_PRE = "";
+$col_tab_tutte_prenota = esegui_query("select * from personalizza where idpersonalizza = 'col_tab_tutte_prenota'");
+$col_tab_tutte_prenota = risul_query($col_tab_tutte_prenota,0,valpersonalizza);
+if ($col_tab_tutte_prenota) $col_tab_tutte_prenota .= "#@&tc";
+else $col_tab_tutte_prenota = "tc";
+esegui_query("update personalizza set valpersonalizza = '$col_tab_tutte_prenota' where idpersonalizza = 'col_tab_tutte_prenota'");
+} # fine if ($versione_corrente < "0.32")
+
+if ($versione_corrente < "0.33") {
+$aggiornato = "SI";
+} # fine if ($versione_corrente < "0.33")
+
+if ($versione_corrente < "0.40") {
+$aggiornato = "SI";
+esegui_query("create table ".$PHPR_TAB_PRE."utenti (idutenti integer primary key, nome_utente text, password text, tipo_pass varchar(1) )");
+esegui_query("insert into ".$PHPR_TAB_PRE."utenti (idutenti, nome_utente, tipo_pass) values (1,'admin','n')");
+esegui_query("create table ".$PHPR_TAB_PRE."privilegi (idutente integer, anno integer, regole1_consentite text, tariffe_consentite text, costi_agg_consentiti text, contratti_consentiti text, priv_ins_prenota varchar(20), priv_mod_prenota varchar(35), priv_mod_pers varchar(15), priv_ins_clienti varchar(10), prefisso_clienti text, priv_ins_costi varchar(5), priv_vedi_tab varchar(30), priv_ins_tariffe varchar(10), priv_ins_regole varchar(10) )");
+esegui_query("create table ".$PHPR_TAB_PRE."sessioni (idsessioni varchar(30) primary key, idutente integer, indirizzo_ip text, user_agent text, ultimo_accesso datetime)");
+esegui_query("create table ".$PHPR_TAB_PRE."transazioni (idtransazioni varchar(30) primary key, idsessione varchar(30), tipo_transazione varchar(5), anno integer, spostamenti text, dati_transazione1 text, dati_transazione2 text, dati_transazione3 text, dati_transazione4 text, dati_transazione5 text, dati_transazione6 text, dati_transazione7 text, dati_transazione8 text, dati_transazione9 text, dati_transazione10 text, dati_transazione11 text, dati_transazione12 text, dati_transazione13 text, dati_transazione14 text, dati_transazione15 text, dati_transazione16 text, dati_transazione17 text, dati_transazione18 text, ultimo_accesso datetime)");
+esegui_query("alter table ".$PHPR_TAB_PRE."personalizza rename to ".$PHPR_TAB_PRE."pers");
+esegui_query("create table ".$PHPR_TAB_PRE."personalizza (idpersonalizza varchar(50) not null, idutente integer, valpersonalizza text, valpersonalizza_num integer)");
+$pers = esegui_query("select * from ".$PHPR_TAB_PRE."pers");
+for ($num1 = 0 ; $num1 < numlin_query($pers) ; $num1++) {
+$idpersonalizza = risul_query($pers,$num1,idpersonalizza);
+$valpersonalizza = risul_query($pers,$num1,valpersonalizza);
+$valpersonalizza_num = risul_query($pers,$num1,valpersonalizza_num);
+esegui_query("insert into ".$PHPR_TAB_PRE."personalizza (idpersonalizza,valpersonalizza,valpersonalizza_num) values ('$idpersonalizza','$valpersonalizza','$valpersonalizza_num')");
+} # fine for $num1
+esegui_query("drop table ".$PHPR_TAB_PRE."pers");
+esegui_query("update ".$PHPR_TAB_PRE."personalizza set idutente = '1'");
+esegui_query("insert into ".$PHPR_TAB_PRE."personalizza (idpersonalizza,idutente,valpersonalizza_num) values ('minuti_durata_sessione','1','90')");
+esegui_query("insert into ".$PHPR_TAB_PRE."personalizza (idpersonalizza,idutente,valpersonalizza_num) values ('ore_anticipa_periodo_corrente','1','0')");
+esegui_query("alter table ".$PHPR_TAB_PRE."clienti add column utente_inserimento integer");
+esegui_query("update ".$PHPR_TAB_PRE."clienti set utente_inserimento = '1'");
+for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
+$anno_mostra = risul_query($anni,$num1,idanni);
+$tableprenota = $PHPR_TAB_PRE."prenota". $anno_mostra;
+esegui_query("alter table $tableprenota add column utente_inserimento integer");
+esegui_query("update $tableprenota set utente_inserimento = '1'");
+$tablecosti = $PHPR_TAB_PRE."costi". $anno_mostra;
+esegui_query("alter table $tablecosti add column utente_inserimento integer");
+esegui_query("update $tablecosti set utente_inserimento = '1' where idcosti != '0'");
+$tablesoldi = $PHPR_TAB_PRE."soldi". $anno_mostra;
+esegui_query("alter table $tablesoldi add column utente_inserimento integer");
+esegui_query("update $tablesoldi set utente_inserimento = '1'");
+} # fine for $num1
+include("./dati/lingua.php");
+$fileaperto = fopen("dati/lingua.php","w+");
+flock($fileaperto,2);
+fwrite($fileaperto,"<?php
+\$lingua[1] = \"$lingua\";
+?>");
+flock($fileaperto,3);
+fclose($fileaperto);
+for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
+$anno_cambia = risul_query($anni,$num1,idanni);
+rename("./dati/selectperiodi$anno_cambia.php","./dati/selectperiodi$anno_cambia.1.php");
+rename("./dati/selperiodimenu$anno_cambia.php","./dati/selperiodimenu$anno_cambia.1.php");
+} # fine for $num1
+} # fine if ($versione_corrente < "0.40")
+
+if ($versione_corrente < "0.41") {
+$aggiornato = "SI";
+for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
+$anno_mostra = risul_query($anni,$num1,idanni);
+$tableregole = $PHPR_TAB_PRE."regole".$anno_mostra;
+esegui_query("alter table $tableregole add column tariffa_per_utente text");
+$tablesoldi = $PHPR_TAB_PRE."soldi".$anno_mostra;
+esegui_query("update $tablesoldi set utente_inserimento = '1' where utente_inserimento = '' or utente_inserimento is null");
+} # fine for $num1
+esegui_query("insert into ".$PHPR_TAB_PRE."personalizza (idpersonalizza,idutente,valpersonalizza) values ('tutti_fissi','1','NO')");
+} # fine if ($versione_corrente < "0.41")
+
+if ($versione_corrente < "0.42") {
+$aggiornato = "SI";
+} # fine if ($versione_corrente < "0.42")
+
+if ($versione_corrente < "0.43") {
+$aggiornato = "SI";
+} # fine if ($versione_corrente < "0.43")
+
+
 
 echo "
 <center>
-PHP-RESIDENCE version 0.3, Copyright (C) 2001-2002 Marco M. F. De Santis<br>
+PHP-RESIDENCE version 0.4.3, Copyright (C) 2001-2004 Marco M. F. De Santis<br>
 Php-residence comes with ABSOLUTELY NO WARRANTY; <br>for details see the file 
 <a href=\"COPYING\">COPYING</a>. <br> This is free software, and you are 
 welcome to redistribute it<br>
@@ -629,8 +746,8 @@ welcome to redistribute it<br>
 </center><hr width=\"95%\">
 <br>";
 if ($aggiornato == "SI") {
-pg_exec("update versioni set num_versione = '0.30' where idversioni = 1");
-echo "<font size=+2>".mex("Database aggiornato alla versione",$pag)." <b>0.3</b>!<br></font>";
+esegui_query("update ".$PHPR_TAB_PRE."versioni set num_versione = '0.43' where idversioni = 1");
+echo "<font size=+2>".mex("Database aggiornato alla versione",$pag)." <b>0.4.3</b>!<br></font>";
 } # fine if ($aggiornato == "SI")
 else { echo "<font size=+2>".mex("Niente da aggiornare",$pag).".<br></font>"; }
 
