@@ -1,13 +1,13 @@
 <html>
 <header>
-<topic> </topic>
+<title> Crea anno </title>
 </header>
 <body bgcolor=#ffffff>
 <?php
 
 ##################################################################################
 #    PHP-RESIDENCE
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2004 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -25,16 +25,82 @@
 ##################################################################################
 
 
+
+include("./includes/funzioni.php");
+$pag = "inizio.php";
+
+unset($numconnessione);
+$id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
+if ($id_utente and $id_utente == 1) {
+
+
+if (!$numconnessione) {
 include("./dati/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
 connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
+} # fine if (!$numconnessione)
+$tableanni = $PHPR_TAB_PRE."anni";
+$tableprivilegi = $PHPR_TAB_PRE."privilegi";
 
-
-$tabelle_lock = array("anni");
-$tabelle_lock = lock_tabelle($tabelle_lock);
-$anno_esistente = esegui_query("select * from anni where idanni = $anno");
+$filelock = fopen("./dati/anni.lock","w+");
+flock($filelock,2);
+$anno_esistente = esegui_query("select * from $tableanni where idanni = $anno");
 if (numlin_query($anno_esistente) == 0) {
 
+// creo la tabella con periodi settimanali e prezzi e la tabella con i nomi delle tariffe
+$tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
+$tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
+if ($importa_anno_prec == "SI") {
+$anno_prec = $anno - 1;
+$tablenometariffe_prec = $PHPR_TAB_PRE."ntariffe".$anno_prec;
+$num_tariffe_tab = esegui_query("select nomecostoagg from $tablenometariffe_prec where idntariffe = 1");
+$num_tariffe_tab = risul_query($num_tariffe_tab,0,nomecostoagg);
+} # fine if ($importa_anno_prec == "SI")
+else $num_tariffe_tab = 8;
+$query = "create table $tableperiodi (idperiodi integer primary key, datainizio date not null, datafine date";
+$query2 = "create table $tablenometariffe (idntariffe integer, nomecostoagg varchar(40), costosettimanale float8, costofinale float8, costopercentuale integer, costop_arrotond float8, regole varchar(40)";
+for ($num1 = 1 ; $num1 <= $num_tariffe_tab ; $num1++) {
+$nome_nuova_tariffa = "tariffa" . $num1;
+$query .= ", $nome_nuova_tariffa float8";
+$query2 .= ", $nome_nuova_tariffa varchar(40)";
+} # fine for $num1
+esegui_query($query.")");
+esegui_query($query2.")");
+
+# Creo la tabella delle prernotazioni
+$tableprenotazioni = $PHPR_TAB_PRE."prenota".$anno;
+esegui_query("create table $tableprenotazioni (idprenota integer primary key, idclienti integer, idappartamenti varchar(100), iddatainizio integer, iddatafine integer, assegnazioneapp varchar(4), app_assegnabili text, num_persone integer, idprenota_compagna text, tariffa text, costiaggiuntivi text, sconto float8, tariffa_tot float8, caparra float8, pagato float8, commento text, conferma varchar(4), datainserimento datetime, hostinserimento varchar(50), data_modifica datetime, utente_inserimento integer )");
+
+# Creo la tabella per le regole di assegnazione
+$tableregole = $PHPR_TAB_PRE."regole".$anno;
+esegui_query("create table $tableregole (idregole integer, app_agenzia varchar(100), tariffa_per_app text, tariffa_per_utente text, iddatainizio integer, iddatafine integer, motivazione text)");
+
+# Creo la tabella con i costi di gestione
+$tablecosti = $PHPR_TAB_PRE."costi".$anno;
+esegui_query("create table $tablecosti (idcosti integer unique,nome_costo text, val_costo float8, persona_costo text, provenienza_costo text, tipo_costo text, datainserimento datetime, hostinserimento varchar(50), utente_inserimento integer)");
+
+# Creo la tabella per la storia entrate-uscite
+$tablesoldi = $PHPR_TAB_PRE."soldi".$anno;
+esegui_query("create table $tablesoldi (idsoldi integer unique, motivazione text, saldo_prenota float8, saldo_cassa float8, soldi_prima float8, data_inserimento datetime, utente_inserimento integer)");
+
+$tabelle_lock = array("$tableanni","$tableprenotazioni","$tablenometariffe","$tableperiodi","$tablecosti","$tableregole","$tablesoldi","$tableprivilegi");
+if ($importa_anno_prec == "SI") {
+$anno_prec = $anno - 1;
+$tablenometariffe_prec = $PHPR_TAB_PRE."ntariffe".$anno_prec;
+$tableprenota_prec = $PHPR_TAB_PRE."prenota".$anno_prec;
+$tableperiodi_prec = $PHPR_TAB_PRE."periodi".$anno_prec;
+$tableregole_prec = $PHPR_TAB_PRE."regole".$anno_prec;
+$altre_tab_lock = array("$tableprenota_prec","$tablenometariffe_prec","$tableperiodi_prec","$tableregole_prec");
+} # fine if ($importa_anno_prec == "SI")
+else unset($altre_tab_lock);
+$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
+
+# Inserisco l'anno nella tabella anni
+esegui_query("insert into $tableanni (idanni,tipo_periodi) values ($anno,'$tipo_periodi')");
+
+esegui_query("insert into $tablecosti (idcosti) values (0)");
+esegui_query("insert into $tablesoldi (idsoldi,motivazione,soldi_prima) values ('1','soldi_prenotazioni_cancellate','0')");
+
 // trovo il primo giorno di inizio/fine dell'anno (nel caso di periodi settimanali)
 $numgiorno = 1;
 do {
@@ -50,34 +116,15 @@ $aggiungi_giorni = 1;
 else $aggiungi_giorni = 7;
 
 if ($mese_ini > $mese_fine) {
-echo "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre.<br>";
+echo mex("I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre",$pag).".<br>";
 $mese_ini = 1;
 $mese_fine = 12;
 } # fine if ($mese_ini > $mese_fine)
 
 $anno_fine = $anno + 1;
 
-//creo la directory dell'anno
-#mkdir($anno, 0777);
-
-// creo il file e la tabella con periodi settimanali e prezzi 
-$tableperiodi = periodi . $anno;
-if ($importa_anno_prec == "SI") {
-$anno_prec = $anno - 1;
-$tablenometariffe_prec = ntariffe . $anno_prec;
-$num_tariffe_tab = esegui_query("select nomecostoagg from $tablenometariffe_prec where idntariffe = 1");
-$num_tariffe_tab = risul_query($num_tariffe_tab,0,nomecostoagg);
-} # fine if ($importa_anno_prec == "SI")
-else $num_tariffe_tab = 8;
-$query = "create table $tableperiodi (idperiodi integer primary key, datainizio date not null, datafine date";
-for ($num1 = 1 ; $num1 <= $num_tariffe_tab ; $num1++) {
-$nome_nuova_tariffa = "tariffa" . $num1;
-$query .= ", $nome_nuova_tariffa float8";
-} # fine for $num1
-esegui_query($query.")");
-
 $idperiodi = 1;
-$fileaperto = fopen("dati/selectperiodi$anno.php","a+");
+$fileaperto = fopen("dati/selectperiodi$anno.1.php","a+");
 flock($fileaperto,2);
 fwrite($fileaperto,"<?php 
 echo \"
@@ -155,48 +202,20 @@ fwrite($fileaperto,"\";
 ?>");
 flock($fileaperto,3);
 fclose($fileaperto);
-copy ("dati/selectperiodi$anno.php","dati/selperiodimenu$anno.php");
-
-# Inserisco l'anno nella tabella anni
-esegui_query("insert into anni (idanni,tipo_periodi) values ($anno,'$tipo_periodi')");
-
-# Creo la tabella con il nome delle tariffe (creata dopo)
-$tablenometariffe = ntariffe . $anno;
-#esegui_query("create table $tablenometariffe (idntariffe integer, nomecostoagg varchar(40), costosettimanale float8, costofinale float8, costopercentuale integer, costop_arrotond float8, regole varchar(40), tariffa1 varchar(40), tariffa2 varchar(40), tariffa3 varchar(40), tariffa4 varchar(40), tariffa5 varchar(40), tariffa6 varchar(40), tariffa7 varchar(40), tariffa8 varchar(40), tariffa9 varchar(40), tariffa10 varchar(40) )");
-
-# Creo la tabella delle prernotazioni
-$tableprenotazioni = prenota . $anno;
-esegui_query("create table $tableprenotazioni (idprenota integer primary key, idclienti integer, idappartamenti varchar(100), iddatainizio integer, iddatafine integer, assegnazioneapp varchar(4), app_assegnabili text, num_persone integer, idprenota_compagna text, tariffa text, costiaggiuntivi text, sconto float8, tariffa_tot float8, caparra float8, pagato float8, commento text, conferma varchar(4), datainserimento datetime, hostinserimento varchar(50), data_modifica datetime )");
-
-# Creo la tabella per le regole di assegnazione
-$tableregole = regole . $anno;
-esegui_query("create table $tableregole (idregole integer, app_agenzia varchar(100), tariffa_per_app text, iddatainizio integer, iddatafine integer, motivazione text)");
-
-# Creo la tabella con i costi di gestione
-$tablecosti = costi . $anno;
-esegui_query("create table $tablecosti (idcosti integer unique,nome_costo text, val_costo float8, persona_costo text, provenienza_costo text, tipo_costo text, datainserimento datetime, hostinserimento varchar(50))");
-esegui_query("insert into $tablecosti (idcosti) values (0)");
-
-# Creo la tabella per la storia entrate-uscite
-$tablesoldi = soldi . $anno;
-esegui_query("create table $tablesoldi (idsoldi integer unique, motivazione text, saldo_prenota float8, saldo_cassa float8, soldi_prima float8, data_inserimento datetime)");
-esegui_query("insert into $tablesoldi (idsoldi,motivazione,soldi_prima) values ('1','soldi_prenotazioni_cancellate','0')");
+copy ("dati/selectperiodi$anno.1.php","dati/selperiodimenu$anno.1.php");
 
 # Importo eventuali prenotazioni, tariffe e regole dell'anno precedente
 if ($importa_anno_prec == "SI") {
-$anno_prec = $anno - 1;
-$tablenometariffe_prec = ntariffe . $anno_prec;
 $tableprenota = $tableprenotazioni;
-$tableprenota_prec = prenota .$anno_prec;
-$tableperiodi_prec = periodi . $anno_prec;
-$tableregole_prec = regole . $anno_prec;
 $data_inizio_periodi = esegui_query("select * from $tableperiodi where idperiodi = 1");
 $data_inizio_periodi = risul_query($data_inizio_periodi,0,datainizio);
 $ini_periodo_interferenza =  esegui_query("select * from $tableperiodi_prec where datainizio = '$data_inizio_periodi'");
 $num_periodo_interferenza = numlin_query($ini_periodo_interferenza);
+$tipo_periodi_prec = esegui_query("select * from $tableanni where idanni = $anno_prec");
+$tipo_periodi_prec = risul_query($tipo_periodi_prec,0,tipo_periodi);
+if ($tipo_periodi_prec != $tipo_periodi) $num_periodo_interferenza = 0;
 if ($num_periodo_interferenza == 0) {
-echo mex("Non ci sono periodi che riguardano il ",$pag).$anno.mex(" nel ",$pag).$anno_prec.mex(", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi
- aggiuntivi, caparra, nome delle tariffe e regole di assegnazione 2",$pag).".<br>";
+echo mex("Non ci sono periodi che riguardano il ",$pag).$anno.mex(" nel ",$pag).$anno_prec.mex(", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3",$pag).".<br>";
 } # fine if ($num_periodo_interferenza == 0)
 else {
 $id_data_fine_periodi = esegui_query("select max(idperiodi) from $tableperiodi");
@@ -274,37 +293,66 @@ esegui_query("insert into $tableregole (idregole,app_agenzia,iddatainizio,iddata
 } # fine else if ($num_periodo_interferenza == 0)
 $num_tariffe_prec = esegui_query("select nomecostoagg from $tablenometariffe_prec where idntariffe = 1");
 $num_tariffe_prec = risul_query($num_tariffe_prec,0,nomecostoagg);
-$query = "create table $tablenometariffe (idntariffe integer, nomecostoagg varchar(40), costosettimanale float8, costofinale float8, costopercentuale integer, costop_arrotond float8, regole varchar(40)";
 $colonne = "idntariffe,nomecostoagg,costosettimanale,costofinale,costopercentuale,costop_arrotond,regole";
 for ($num1 = 1 ; $num1 <= $num_tariffe_prec ; $num1++) {
 $nome_nuova_tariffa = "tariffa" . $num1;
-$query .= ", $nome_nuova_tariffa varchar(40)";
 $colonne .= ",$nome_nuova_tariffa";
 } # fine for $num1
-esegui_query($query.")");
 esegui_query("insert into $tablenometariffe ($colonne) select $colonne from $tablenometariffe_prec");
 esegui_query("insert into $tableregole select * from $tableregole_prec where tariffa_per_app != ''");
+esegui_query("insert into $tableregole select * from $tableregole_prec where tariffa_per_utente != ''");
+$privilegi_prec = esegui_query("select * from $tableprivilegi where anno = '$anno_prec'");
+for ($num1 = 0 ; $num1 < numlin_query($privilegi_prec) ; $num1++) {
+$idutente_p = risul_query($privilegi_prec,$num1,idutente);
+$regole1_consentite_p = risul_query($privilegi_prec,$num1,regole1_consentite);
+$tariffe_consentite_p = risul_query($privilegi_prec,$num1,tariffe_consentite);
+$costi_agg_consentiti_p = risul_query($privilegi_prec,$num1,costi_agg_consentiti);
+$contratti_consentiti_p = risul_query($privilegi_prec,$num1,contratti_consentiti);
+$priv_ins_prenota_p = risul_query($privilegi_prec,$num1,priv_ins_prenota);
+$priv_mod_prenota_p = risul_query($privilegi_prec,$num1,priv_mod_prenota);
+$priv_mod_pers_p = risul_query($privilegi_prec,$num1,priv_mod_pers);
+$priv_ins_clienti_p = risul_query($privilegi_prec,$num1,priv_ins_clienti);
+$prefisso_clienti_p = risul_query($privilegi_prec,$num1,prefisso_clienti);
+$priv_ins_costi_p = risul_query($privilegi_prec,$num1,priv_ins_costi);
+$priv_vedi_tab_p = risul_query($privilegi_prec,$num1,priv_vedi_tab);
+$priv_ins_tariffe_p = risul_query($privilegi_prec,$num1,priv_ins_tariffe);
+$priv_ins_regole_p = risul_query($privilegi_prec,$num1,priv_ins_regole);
+esegui_query("insert into $tableprivilegi (idutente,anno,regole1_consentite,tariffe_consentite,costi_agg_consentiti,contratti_consentiti,priv_ins_prenota,priv_mod_prenota,priv_mod_pers,priv_ins_clienti,prefisso_clienti,priv_ins_costi,priv_vedi_tab,priv_ins_tariffe,priv_ins_regole) values ('$idutente_p','$anno','$regole1_consentite_p','$tariffe_consentite_p','$costi_agg_consentiti_p','$contratti_consentiti_p','$priv_ins_prenota_p','$priv_mod_prenota_p','$priv_mod_pers_p','$priv_ins_clienti_p','$prefisso_clienti_p','$priv_ins_costi_p','$priv_vedi_tab_p','$priv_ins_tariffe_p','$priv_ins_regole_p')");
+} # fine for $num1
 $inserisci_in_ntariffe = "NO";
 } # fine if ($importa_anno_prec == "SI")
 
 if ($inserisci_in_ntariffe != "NO") {
-$query = "create table $tablenometariffe (idntariffe integer, nomecostoagg varchar(40), costosettimanale float8, costofinale float8, costopercentuale integer, costop_arrotond float8, regole varchar(40)";
-for ($num1 = 1 ; $num1 <= 8 ; $num1++) {
-$nome_nuova_tariffa = "tariffa" . $num1;
-$query .= ", $nome_nuova_tariffa varchar(40)";
-} # fine for $num1
-esegui_query($query.")");
 # rigo 1: nomi tariffe; 2-3: caparra (% e arrotondo).
 for ($numtariffe =1 ; $numtariffe <= 3 ; $numtariffe = $numtariffe + 1) {
 esegui_query("insert into $tablenometariffe (idntariffe) values ($numtariffe)");
 } # fine for $numtariffe
 esegui_query("update $tablenometariffe set nomecostoagg = 8 where idntariffe = 1");
+esegui_query("update $tablenometariffe set regole = 4 where idntariffe = 1");
 } # fine if ($inserisci_in_ntariffe != "NO")
 
+unlock_tabelle($tabelle_lock);
 
 } # fine if (numlin_query($anno_esistente) == 0)
 else echo mex("Anno gi creato",$pag).".<br>";
-unlock_tabelle($tabelle_lock);
+
+flock($filelock,3);
+fclose($filelock);
+unlink("./dati/anni.lock");
+
+
+echo "<br> ".mex("Anno ",$pag).$anno.mex(" creato",$pag)."! <br><br>
+<form method=\"post\" action=\"inizio.php\">
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"submit\" name=\"ok\" value=\"OK\"><br>
+</form>";
+
+
+
+} # fine if ($id_utente and $id_utente == 1)
+
+
 
 ?>
 
