@@ -8,7 +8,7 @@
 
 #################################################################################
 #    PHP-RESIDENCE
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2004 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -29,6 +29,17 @@
 
 include("./includes/funzioni.php");
 $pag = "creadb.php";
+
+unset($numconnessione);
+unset($PHPR_TAB_PRE);
+unset($id_sessione);
+unset($nome_utente_phpr);
+unset($password_phpr);
+$id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
+if ($id_utente and $id_utente == 1) {
+
+
+
 function mex2 ($messaggio,$pagina,$lingua) {
 
 if ($lingua != "ita") {
@@ -42,16 +53,21 @@ return $messaggio;
 
 // creo la tabella appartamenti e vi inserisco i dati forniti.
 if ($insappartamenti) {
+include("./dati/lingua.php");
+$lingua_mex = $lingua[1];
 include("./dati/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
 connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
-esegui_query("create table appartamenti ( idappartamenti varchar(100) primary key, numpiano text, maxoccupanti integer, numcasa text, app_vicini text, priorita integer, commento text )");
+$tableappartamenti = $PHPR_TAB_PRE."appartamenti";
+esegui_query("create table $tableappartamenti ( idappartamenti varchar(100) primary key, numpiano text, maxoccupanti integer, numcasa text, app_vicini text, priorita integer, commento text )");
 $fileaperto = fopen("dati/selectappartamenti.php","a+");
 fwrite($fileaperto,"<?php \necho \"\n");
 for ( $num = 1; $num <= $numappartamenti; $num = $num + 1) {
 $numapp = "numapp" . $num;
 $numapp = $$numapp;
 $numapp = str_replace (",","",$numapp);
+$numapp = str_replace ("'","",$numapp);
+if (str_replace (" ","",$numapp) == "") $numapp = str_replace (" ","_",$numapp);
 $piano = "piano" . $num;
 $piano = $$piano;
 $maxoccupanti = "maxoccupanti" . $num;
@@ -62,33 +78,33 @@ $priorita = "priorita" . $num;
 $priorita = $$priorita;
 $app_vicini = "app_vicini" . $num;
 $app_vicini = $$app_vicini;
-esegui_query("insert into appartamenti ( idappartamenti ) values ( '$numapp' )");
+esegui_query("insert into $tableappartamenti ( idappartamenti ) values ( '$numapp' )");
 fwrite($fileaperto,"<option value=\\\"$numapp\\\">$numapp</option>
 ");
 if ($piano) {
-esegui_query("update appartamenti set numpiano = '$piano' where idappartamenti = '$numapp'");
+esegui_query("update $tableappartamenti set numpiano = '$piano' where idappartamenti = '$numapp'");
 } # fine if ($piano)
 if ($maxoccupanti) {
-esegui_query("update appartamenti set maxoccupanti = $maxoccupanti where idappartamenti = '$numapp'");
+esegui_query("update $tableappartamenti set maxoccupanti = $maxoccupanti where idappartamenti = '$numapp'");
 } # fine if ($maxoccupanti)
 if ($numcasa) {
-esegui_query("update appartamenti set numcasa = '$numcasa' where idappartamenti = '$numapp'");
+esegui_query("update $tableappartamenti set numcasa = '$numcasa' where idappartamenti = '$numapp'");
 } # fine if ($numcasa)
 if ($priorita) {
-esegui_query("update appartamenti set priorita = $priorita where idappartamenti = '$numapp'");
+esegui_query("update $tableappartamenti set priorita = $priorita where idappartamenti = '$numapp'");
 } # fine if ($priorita)
 if ($app_vicini and $assegna_vicini_nc != "SI") {
-esegui_query("update appartamenti set app_vicini = $app_vicini where idappartamenti = '$numapp'");
+esegui_query("update $tableappartamenti set app_vicini = $app_vicini where idappartamenti = '$numapp'");
 } # fine if ($app_vicini and assegna_vicini_nc != "SI")
 } # fine for $num
 fwrite($fileaperto,"\"; \n?>");
 if ($assegna_vicini_nc == "SI") {
-$appart = esegui_query("select * from appartamenti");
+$appart = esegui_query("select * from $tableappartamenti");
 for ( $num1 = 0; $num1 < $numappartamenti; $num1 = $num1 + 1) {
 $idapp = risul_query($appart,$num1,idappartamenti);
 $nc = risul_query($appart,$num1,numcasa);
 $np = risul_query($appart,$num1,numpiano);
-$query = "select idappartamenti from appartamenti where numcasa = '$nc' and idappartamenti != '$idapp'";
+$query = "select idappartamenti from $tableappartamenti where numcasa = '$nc' and idappartamenti != '$idapp'";
 if ($assegna_vicini_np == "SI") {
 $query = $query." and numpiano = '$np'";
 } # fine if ($assegna_vicini_np == "SI")
@@ -100,7 +116,7 @@ $id_av = risul_query($av,$num2,idappartamenti);
 if ($app_vicini == "") { $app_vicini = $id_av; }
 else { $app_vicini = $app_vicini . "," . $id_av; }
 } # fine for $num2
-esegui_query("update appartamenti set app_vicini = '$app_vicini' where idappartamenti = '$idapp'");
+esegui_query("update $tableappartamenti set app_vicini = '$app_vicini' where idappartamenti = '$idapp'");
 } # fine for $num1
 } # fine if ($assegna_vicini_nc == "SI")
 echo mex("Dati inseriti",$pag)."!<br>".mex("Tutti i dati permanenti sono stati inseriti",$pag).".<br>";
@@ -112,6 +128,7 @@ echo "<form method=\"post\" action=\"inizio.php\">
 else{
 
 if ($creabase) {
+if (!$prefisso_tab or ereg('^[_a-z][_0-9a-z]*$',$prefisso_tab)) {
 if ($tipo_db == "postgresql") {
 if ($carica_estensione == "SI") { dl("pgsql.so"); }
 if ($database_esistente == "SI") $tempdatabase = $database;
@@ -146,42 +163,63 @@ $numconnessione = mysql_connect ("$host:$port", "$user", "$password");
 mysql_select_db($database);
 } # fine if ($tipo_db == "mysql")
 # creo la tabella clienti.
-esegui_query("create table clienti (idclienti integer primary key, cognome varchar(50) not null, nome varchar(50), sesso char, cognome2 varchar(50), nome2 varchar(50), sesso2 char, datanascita date, datanascita2 date, cittanascita varchar(50), cittanascita2 varchar(50), nazione varchar(50), citta varchar(50), via varchar(50), numcivico varchar(20), cap varchar(10), telefono varchar(50), telefono2 varchar(50), telefono3 varchar(50), fax varchar(50), email varchar(50), commento text, datainserimento datetime, hostinserimento varchar(50) )");
+$tableclienti = $prefisso_tab."clienti";
+esegui_query("create table $tableclienti (idclienti integer primary key, cognome varchar(50) not null, nome varchar(50), sesso char, cognome2 varchar(50), nome2 varchar(50), sesso2 char, datanascita date, datanascita2 date, cittanascita varchar(50), cittanascita2 varchar(50), nazione varchar(50), citta varchar(50), via varchar(50), numcivico varchar(20), cap varchar(10), telefono varchar(50), telefono2 varchar(50), telefono3 varchar(50), fax varchar(50), email varchar(50), commento text, datainserimento datetime, hostinserimento varchar(50), utente_inserimento integer )");
 # creo la tabella anni.
-esegui_query("create table anni (idanni integer primary key, tipo_periodi text)");
+$tableanni = $prefisso_tab."anni";
+esegui_query("create table $tableanni (idanni integer primary key, tipo_periodi text)");
 # creo la tabella versione ed inserisco quella corrente.
-esegui_query("create table versioni (idversioni integer primary key, num_versione float4)");
-esegui_query("insert into versioni (idversioni, num_versione) values (1, '0.30')");
-esegui_query("insert into versioni (idversioni, num_versione) values (2, '100')");
+$tableversioni = $prefisso_tab."versioni";
+esegui_query("create table $tableversioni (idversioni integer primary key, num_versione float4)");
+esegui_query("insert into $tableversioni (idversioni, num_versione) values (1, '0.43')");
+esegui_query("insert into $tableversioni (idversioni, num_versione) values (2, '100')");
 # creo la tabella per le personalizzazioni.
-esegui_query("create table personalizza (idpersonalizza varchar(50) primary key, valpersonalizza text, valpersonalizza_num integer)");
-esegui_query("insert into personalizza (idpersonalizza,valpersonalizza) values ('col_tab_tutte_prenota','ca#@&pa#@&ap#@&pe#@&co')");
-esegui_query("insert into personalizza (idpersonalizza,valpersonalizza) values ('valuta','Euro')");
-esegui_query("insert into personalizza (idpersonalizza,valpersonalizza) values ('stile_soldi','europa')");
-esegui_query("insert into personalizza (idpersonalizza,valpersonalizza) values ('costi_agg_in_tab_prenota','')");
-esegui_query("insert into personalizza (idpersonalizza,valpersonalizza_num) values ('aggiunta_tronca_nomi_tab1','0')");
-esegui_query("insert into personalizza (idpersonalizza,valpersonalizza_num) values ('num_linee_tab2_prenota','30')");
-esegui_query("insert into personalizza (idpersonalizza,valpersonalizza) values ('nomi_contratti','')");
-esegui_query("insert into personalizza (idpersonalizza,valpersonalizza_num) values ('num_righe_tab_tutte_prenota','200')");
-esegui_query("insert into personalizza (idpersonalizza,valpersonalizza_num) values ('num_righe_tab_storia_soldi','200')");
-esegui_query("insert into personalizza (idpersonalizza,valpersonalizza) values ('stile_data','europa')");
-esegui_query("insert into personalizza (idpersonalizza,valpersonalizza_num) values ('num_righe_tab_tutti_clienti','200')");
+$tablepersonalizza = $prefisso_tab."personalizza";
+esegui_query("create table $tablepersonalizza (idpersonalizza varchar(50) not null, idutente integer, valpersonalizza text, valpersonalizza_num integer)");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('col_tab_tutte_prenota','1','tc#@&ca#@&pa#@&ap#@&pe#@&co')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('valuta','1','Euro')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('stile_soldi','1','europa')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('costi_agg_in_tab_prenota','1','')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('aggiunta_tronca_nomi_tab1','1','0')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_linee_tab2_prenota','1','30')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('nomi_contratti','1','')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_tutte_prenota','1','200')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_storia_soldi','1','200')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('stile_data','1','europa')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_tutti_clienti','1','200')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('minuti_durata_sessione','1','90')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('ore_anticipa_periodo_corrente','1','0')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('tutti_fissi','1','NO')");
+$tableutenti = $prefisso_tab."utenti";
+esegui_query("create table $tableutenti (idutenti integer primary key, nome_utente text, password text, tipo_pass varchar(1) )");
+esegui_query("insert into $tableutenti (idutenti, nome_utente, tipo_pass) values (1,'admin','n')");
+$tableprivilegi = $prefisso_tab."privilegi";
+esegui_query("create table $tableprivilegi (idutente integer, anno integer, regole1_consentite text, tariffe_consentite text, costi_agg_consentiti text, contratti_consentiti text, priv_ins_prenota varchar(20), priv_mod_prenota varchar(35), priv_mod_pers varchar(15), priv_ins_clienti varchar(5), prefisso_clienti text, priv_ins_costi varchar(10), priv_vedi_tab varchar(30), priv_ins_tariffe varchar(10), priv_ins_regole varchar(10) )");
+$tablesessioni = $prefisso_tab."sessioni";
+esegui_query("create table $tablesessioni (idsessioni varchar(30) primary key, idutente integer, indirizzo_ip text, user_agent text, ultimo_accesso datetime)");
+$tabletransazioni = $prefisso_tab."transazioni";
+esegui_query("create table $tabletransazioni (idtransazioni varchar(30) primary key, idsessione varchar(30), tipo_transazione varchar(5), anno integer, spostamenti text, dati_transazione1 text, dati_transazione2 text, dati_transazione3 text, dati_transazione4 text, dati_transazione5 text, dati_transazione6 text, dati_transazione7 text, dati_transazione8 text, dati_transazione9 text, dati_transazione10 text, dati_transazione11 text, dati_transazione12 text, dati_transazione13 text, dati_transazione14 text, dati_transazione15 text, dati_transazione16 text, dati_transazione17 text, dati_transazione18 text, ultimo_accesso datetime)");
 
 # creo i file permanenti.
 if ($fileaperto = fopen("./dati/dati_connessione.php","a+")) {
+$database_scrivi = aggiungi_slash($database);
+$host_scrivi = aggiungi_slash($host);
+$user_scrivi = aggiungi_slash($user);
+$password_scrivi = aggiungi_slash($password);
 fwrite($fileaperto,"<?php
 \$PHPR_DB_TYPE = \"$tipo_db\";
-\$PHPR_DB_NAME = \"$database\";
-\$PHPR_DB_HOST = \"$host\";
+\$PHPR_DB_NAME = \"$database_scrivi\";
+\$PHPR_DB_HOST = \"$host_scrivi\";
 \$PHPR_DB_PORT = \"$port\";
-\$PHPR_DB_USER = \"$user\";
-\$PHPR_DB_PASS = \"$password\";
+\$PHPR_DB_USER = \"$user_scrivi\";
+\$PHPR_DB_PASS = \"$password_scrivi\";
 \$PHPR_LOAD_EXT = \"$carica_estensione\";
+\$PHPR_TAB_PRE = \"$prefisso_tab\";
 ?>");
-if ($lingua != "ita" and $lingua != "en" and $lingua != "es") { $lingua = "en"; }
+if ($lingua != "ita" and (!@is_dir("./includes/lang/".$lingua) or strlen($lingua) > 3)) $lingua = "en";
 $fileaperto = fopen("./dati/lingua.php","w+");
 fwrite($fileaperto,"<?php
-\$lingua = \"$lingua\";
+\$lingua[1] = \"$lingua\";
 ?>");
 
 # seconda form di inserimento (appartamenti).
@@ -217,10 +255,14 @@ echo "<input type=\"submit\" name=\"insappartamenti\" value=\"".mex2("Inserisci
 } # fine if ($fileaperto = @fopen("./dati/connessione_db.php","a+"))
 
 else {
-esegui_query("drop table clienti");
-esegui_query("drop table anni");
-esegui_query("drop table versioni");
-esegui_query("drop table personalizza");
+esegui_query("drop table $tableclienti");
+esegui_query("drop table $tableanni");
+esegui_query("drop table $tableversioni");
+esegui_query("drop table $tablepersonalizza");
+esegui_query("drop table $tableutenti");
+esegui_query("drop table $tableprivilegi");
+esegui_query("drop table $tablesessioni");
+esegui_query("drop table $tabletransazioni");
 disconnetti_db($numconnessione);
 if ($database_esistente == "NO") {
 sleep(3);
@@ -246,6 +288,11 @@ else {
 echo "<br>".mex2("I dati inseriti non sono esatti o il database non  in ascolto (se postgres assicurarsi che venga avviato con -i e di avere i permessi giusti in pg_hba.conf)",$pag,$lingua).".<br>";
 $torna_indietro = "SI";
 } # fine else if ($numconnessione)
+} # fine if (!$prefisso_tab or ereg('^[_a-z][_0-9a-z]*$',$prefisso_tab))
+else {
+echo "<br>".mex2("Il prefisso del nome delle tabelle  sbagliato (accettate solo lettere minuscole, numeri e _ , primo carattere lettera)",$pag,$lingua).".<br>";
+$torna_indietro = "SI";
+} # fine else if (!$prefisso_tab or ereg('^[_a-z][_0-9a-z]*$',$prefisso_tab))
 if ($torna_indietro == "SI") {
 echo "<form method=\"post\" action=\"creadb.php\">
 <input type=\"hidden\" name=\"lingua\" value=\"$lingua\">
@@ -273,7 +320,7 @@ echo "<center><font size=+2>".mex2("Inserimento dei dati permanenti",$pag,$lingu
 <select name=\"database_esistente\">
 <option value=\"SI\">".mex2("Si",$pag,$lingua)."</option>
 <option value=\"NO\" selected>".mex2("No",$pag,$lingua)."</option>
-</select>(".mex2("Se gi esistente il database deve essere vuoto",$pag,$lingua).")<br>
+</select><font size=\"-1\">(".mex2("Se gi esistente e non vuoto usare un prefisso non presente nel database per il nome delle tabelle",$pag,$lingua).")</font><br>
 ".mex2("Nome del computer a cui collegarsi",$pag,$lingua).":
 <input type=\"text\" name=\"host\" value=\"localhost\"><br>
 ".mex2("Numero della porta a cui collegarsi",$pag,$lingua).": 
@@ -289,6 +336,8 @@ echo "<center><font size=+2>".mex2("Inserimento dei dati permanenti",$pag,$lingu
 </select> <font size=\"-1\">(".mex2("scegliere si se non viene caricata automaticamente da php",$pag,$lingua).")</font><br>
 ".mex2("Nome del database a cui collegarsi temporaneamente",$pag,$lingua).":
 <input type=\"text\" name=\"tempdatabase\" value=\"template1\"><font size=\"-1\">(".mex2("solo per Postgresql con database non esistente",$pag,$lingua).")</font><br>
+".mex2("Prefisso nel nome delle tabelle",$pag,$lingua).":
+<input type=\"text\" name=\"prefisso_tab\" maxlength=\"8\" size=\"9\"><font size=\"-1\">(".mex2("opzionale, utile per pi installazioni di php-residence nello stesso database",$pag,$lingua).")</font><br>
 ".mex2("Numero di appartamenti da gestire",$pag,$lingua).": 
 <input type=\"text\" name=\"numappartamenti\"><br>
 <center><input type=\"submit\" name=\"creabase\" value=\"".mex2("Crea il database",$pag,$lingua)."\"></center><br>
@@ -299,6 +348,12 @@ echo "<center><font size=+2>".mex2("Inserimento dei dati permanenti",$pag,$lingu
 
 } # fine else if ($insappartamenti)
 
+
+
+} # fine if ($id_utente and $id_utente == 1)
+
+
+
 ?>
 
 </body>
