@@ -8,7 +8,7 @@
 
 #################################################################################
 #    PHP-RESIDENCE
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2004 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -29,16 +29,24 @@ $pag = "creaprezzi.php";
 
 include("./dati/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
-connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
+$numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
 include ("./includes/funzioni.php");
 include ("./includes/sett_gio.php");
+
+
+$id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
+if ($id_utente and $id_utente == 1) {
+
+
 $Euro = nome_valuta();
+$stile_data = stile_data();
 
 $numcaselle = 8;
-$tableperiodi = periodi . $anno;
-$tablenometariffe = ntariffe . $anno;
+$tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
+$tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
+$tableanni = $PHPR_TAB_PRE."anni";
 
-$tipo_periodi = esegui_query("select * from anni where idanni = $anno");
+$tipo_periodi = esegui_query("select * from $tableanni where idanni = $anno");
 $tipo_periodi = risul_query($tipo_periodi,0,tipo_periodi);
 
 # Inserisco la caparra
@@ -57,6 +65,7 @@ unlock_tabelle($tabelle_lock);
 echo "
 <form method=\"post\" action=\"creaprezzi.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"submit\" name=\"ok\" value=\"OK\"><br>
 </form>";
 } # fine if ($modificacaparra)
@@ -164,7 +173,8 @@ if ($chiedi_tariffe == "SI" and !$tariffe_selezionate) {
 $rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 ");
 $numero_tariffe = risul_query($rigatariffe,0,nomecostoagg);
 echo "<form method=\"post\" action=\"creaprezzi.php\">
-<input type=\"hidden\" name=\"anno\" value=\"$anno\">";
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">";
 if ($applicarecf == "s") {
 echo mex("Scegli le tariffe a cui verr applicato automatiamente il costo <b>finale</b>",$pag).":<br>";
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
@@ -233,6 +243,7 @@ echo "<center>
 </center></form><center>
 <form method=\"post\" action=\"creaprezzi.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"submit\" name=\"ok\" value=\"".mex("Torna indietro",$pag)."\"><br>
 </form></center>";
 } # fine if ($chiedi_tariffe == "SI" and !$tariffe_selezionate)
@@ -244,8 +255,8 @@ if (!$chiederencs) $chiederencs = "n";
 if (!$letto_agg_cs) $letto_agg_cs = "n";
 if (!$chiederencp) $chiederencp = "n";
 if (!$letto_agg) $letto_agg = "n";
-$idntariffe = esegui_query("select max(idntariffe) from $tablenometariffe");
-$idntariffe = risul_query($idntariffe,0,0) + 1;
+$idntariffe = esegui_query("select regole from $tablenometariffe where idntariffe = 1");
+$idntariffe = risul_query($idntariffe,0,0);
 if ($costofineaffitto) {
 $regole = $mostrarecfa . $chiederencf . $letto_agg_cf;
 esegui_query("insert into $tablenometariffe (idntariffe, costofinale, regole) values ($idntariffe, '$costofineaffitto', '$regole')");
@@ -263,6 +274,7 @@ if ($$cftariffa or $applicarecf == "t") esegui_query("update $tablenometariffe s
 } # fine if ($applicarecf == "s" or $applicarecf == "t")
 echo mex("Il costo aggiuntivo finale",$pag)." \"$nomecostofineaffitto\" ".mex(" stato inserito",$pag).".<br>";
 $idntariffe++;
+esegui_query("update $tablenometariffe set regole = '$idntariffe' where idntariffe = 1");
 } # fine if ($costofineaffitto)
 if ($costosettimanale) {
 $regole = $mostrarecs . $applicarens . $chiederencs . $letto_agg_cs;
@@ -281,6 +293,7 @@ if ($$cstariffa or $applicarecs == "t") esegui_query("update $tablenometariffe s
 } # fine if ($applicarecs == "s" or $applicarecs == "t")
 echo mex("Il costo aggiuntivo $parola_settimanale",$pag)." \"$nomecostosettimanale\" ".mex(" stato inserito",$pag).".<br>";
 $idntariffe++;
+esegui_query("update $tablenometariffe set regole = '$idntariffe' where idntariffe = 1");
 } # fine if ($costosettimanale)
 if ($costopercentuale) {
 $regole = $mostrarecp . $chiederencp . $letto_agg;
@@ -298,9 +311,12 @@ if ($$cptariffa or $applicarecp == "t") esegui_query("update $tablenometariffe s
 } # fine for $numtariffa
 } # fine if ($applicarecp == "s" or $applicarecp == "t")
 echo mex("Il costo aggiuntivo percentuale",$pag)." \"$nomecostopercentuale\" ".mex(" stato inserito",$pag).".<br>";
+$idntariffe++;
+esegui_query("update $tablenometariffe set regole = '$idntariffe' where idntariffe = 1");
 } # fine if ($costopercentuale)
 echo "<form method=\"post\" action=\"creaprezzi.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"submit\" name=\"ok\" value=\"OK\"><br>
 </form>";
 } # fine else if ($chiedi_tariffe == "SI" and !$tariffe_selezionate)
@@ -309,6 +325,7 @@ if ($inserire == "NO") {
 echo mex("Nessun dato  stato inserito",$pag).".<br>";
 echo "<form method=\"post\" action=\"creaprezzi.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"submit\" name=\"ok\" value=\"".mex("Torna indietro",$pag)."\"><br>
 </form>";
 } # fine if ($inserire == "NO")
@@ -374,12 +391,15 @@ $num1++;
 if ($prezzoperiodo1sabdom) esegui_query("update $tableperiodi set $tipotariffa = $prezzoperiodo1sabdom where idperiodi = $num1 ");
 } # fine for $num1
 unlock_tabelle($tabelle_lock);
-echo mex("I prezzi per le settimane dal",$pag)." <b>$inizioperiodosett1</b> ".mex("al",$pag)." <b>$fineperiodosett1</b> ".mex("della <b>tariffa",$pag)."$num_tariffa</b> ".mex("sono stati inseriti",$pag).". <br>";
+$inizioperiodosett1_f = formatta_data($inizioperiodosett1,$stile_data);
+$fineperiodosett1_f = formatta_data($fineperiodosett1,$stile_data);
+echo mex("I prezzi per le settimane dal",$pag)." <b>$inizioperiodosett1_f</b> ".mex("al",$pag)." <b>$fineperiodosett1_f</b> ".mex("della <b>tariffa",$pag)."$num_tariffa</b> ".mex("sono stati inseriti",$pag).". <br>";
 } # fine if ($inserire_prezzi != "NO")
 
 echo "
 <form method=\"post\" action=\"creaprezzi.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"tariffa_selected$num_tariffa\" value=\" selected\">
 <input type=\"submit\" name=\"ok\" value=\"OK\"><br>
 </form>";
@@ -400,6 +420,7 @@ $numero_tariffe = risul_query($rigatariffe,0,nomecostoagg);
 # Controllo se i campi inseriti sono gi presenti
 $tipotariffa_vedi = mex("tariffa",$pag).substr($tipotariffa,7);
 if ($nometariffa) {
+$nometariffa = stripslashes($nometariffa);
 $vecchionometariffa = esegui_query("select * from $tablenometariffe where idntariffe = 1 and $tipotariffa != ''");
 $esistenometariffa = numlin_query($vecchionometariffa) ;
 if ($esistenometariffa > 0) {
@@ -472,6 +493,7 @@ $inserire = "NO";
 # Inserisco i nuovi dati
 if ( $inserire == "SI" ) {
 if ($nometariffa) {
+$nometariffa = addslashes($nometariffa);
 esegui_query("update $tablenometariffe set $tipotariffa = '$nometariffa' where idntariffe = 1 ");
 echo mex("Il soprannome della",$pag)." $tipotariffa_vedi ".mex(" stato cambiato",$pag).".<br>";
 } # fine if ($nometariffa)
@@ -495,6 +517,7 @@ echo mex("Nessun dato  stato inserito",$pag).".<br>";
 unlock_tabelle($tabelle_lock);
 echo "
 <form method=\"post\" action=\"creaprezzi.php?anno=$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"submit\" name=\"ok\" value=\"OK\"><br>
 </form>";
 } # fine if ($inserisci or $modifica)
@@ -512,6 +535,7 @@ echo "<center><font size=+2>".mex("Inserisci i prezzi per l'anno",$pag)." $anno<
 
 echo "<br>
 <form method=\"post\" action=\"creaprezzi.php?anno=$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <hr width=\"95%\">";
 if ($tipo_periodi == "g") echo mex("Inserzione per giorni",$pag)."<br><br>";
 
@@ -541,11 +565,11 @@ $fineperiodo = "fineperiodo" . $numperiodo;
 $prezzoperiodo = "prezzoperiodo" . $numperiodo;
 echo "
 $numperiodo. ".mex("Dal",$pag)." <select name=\"$inizioperiodo\">";
-include("./dati/selectperiodi$anno.php");
+include("./dati/selectperiodi$anno.$id_utente.php");
 echo "
 </select>
 ".mex("al",$pag)." <select name=\"$fineperiodo\">";
-include("./dati/selectperiodi$anno.php");
+include("./dati/selectperiodi$anno.$id_utente.php");
 echo "
 </select>
 :  <input type=\"text\" name=\"$prezzoperiodo\" size=\"15\">$Euro<br>";
@@ -561,7 +585,8 @@ echo "
 if ($tipo_periodi == "g") {
 echo mex("Inserzione per settimane",$pag)."<br><br>
 <form method=\"post\" action=\"creaprezzi.php\">
-<input type=\"hidden\" name=\"anno\" value=\"$anno\">";
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">";
 
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
 $tariffa = "tariffa".$numtariffa;
@@ -582,7 +607,7 @@ echo mex("Prezzi della",$pag)."
 $select_nomi_tariffe
 </select><br><br> ";
 
-$file_date = file("dati/selectperiodi$anno.php");
+$file_date = file("dati/selectperiodi$anno.$id_utente.php");
 $num_linee_file_date = count($file_date);
 for ($num1 = 0 ; $num1 < $num_linee_file_date ; $num1++) {
 if (substr($file_date[$num1],0,7) == "<option") {
@@ -630,6 +655,7 @@ echo "
 echo "
 <form method=\"post\" action=\"creaprezzi.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 ".mex("Costi aggiuntivi",$pag)."<br><br></center>
 ".mex("Costo aggiuntivo di <b>fine locazione</b> soprannominato",$pag)."
 <input type=\"text\" name=\"nomecostofineaffitto\" size=\"16\"> : 
@@ -686,6 +712,7 @@ echo "
 
 <form method=\"post\" action=\"creaprezzi.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 ".mex("Caparra",$pag)."</center><br>"
 .mex("La caparra normale per la",$pag)."
  <select name=\"tipotariffa\">";
@@ -713,12 +740,14 @@ echo "</select> ".mex(" del",$pag)."
 
 <br><form method=\"post\" action=\"visualizza_tabelle.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"periodi\">
 <input type=\"submit\" name=\"visualizza\" value=\"".mex("Vedi i prezzi gi inseriti",$pag)."\">
 </form>
 
 <form method=\"post\" action=\"inizio.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"submit\" name=\"indietro\" value=\"".mex("Torna al men principale",$pag)."\">
 </form></center>";
 
@@ -734,6 +763,11 @@ echo "</select> ".mex(" del",$pag)."
 
 
 
+
+} # fine if ($id_utente and $id_utente == 1)
+
+
+
 ?>
 
 </body>
