@@ -8,7 +8,7 @@
 
 ##################################################################################
 #    PHP-RESIDENCE
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2004 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -29,16 +29,22 @@ $pag = "crearegole.php";
 
 include("./dati/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
-connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
+$numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
 include ("./includes/funzioni.php");
-$tableregole = regole . $anno;
-$tableperiodi = periodi . $anno;
-$tablenometariffe = ntariffe . $anno;
+$tableregole = $PHPR_TAB_PRE."regole".$anno;
+$tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
+$tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
+$tableappartamenti = $PHPR_TAB_PRE."appartamenti";
+$tableutenti = $PHPR_TAB_PRE."utenti";
+
+
+$id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
+if ($id_utente and $id_utente == 1) {
 
 
 if ($inserisci) {
 $tabelle_lock = array("$tableregole");
-$altre_tab_lock = array("$tableperiodi","appartamenti");
+$altre_tab_lock = array("$tableperiodi","$tableappartamenti","$tableutenti");
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 
 if ($regola_1) {
@@ -62,12 +68,15 @@ if ($num_vecchia_regola != 0) {
 echo mex("Esiste gi una regola di questo tipo nell'appartamento e nel periodo selezionato",$pag).".<br>";
 } # fine if ($num_vecchia_regola != 0)
 else {
+if ($motivazione == " ") echo mex("Motivazione non valida",$pag).".<br>";
+else {
 $idregole = esegui_query("select max(idregole) from $tableregole");
 $idregole = risul_query($idregole,0,0);
 $idregole = $idregole + 1;
 esegui_query("insert into $tableregole (idregole,app_agenzia,iddatainizio,iddatafine) values ($idregole,'$appartamento', $idinizioperiodo, $idfineperiodo)");
 if ($motivazione) esegui_query("update $tableregole set motivazione = '$motivazione' where idregole = $idregole");
 echo mex("La regola  stata inserita",$pag).".";
+} # fine else if ($motivazione == "nessuna")
 } # fine else if ($num_vecchia_regola != 0)
 } # fine else if ($idfineperiodo < $idinizioperiodo)
 } # fine else if (!$inizioperiodo or !$fineperiodo or !$appartamento)
@@ -82,6 +91,7 @@ else {
 echo mex("Sei sicuro di voler cancellare tutte le regole del tipo 1",$pag)."?
 <form method=\"post\" action=\"crearegole.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"inserisci\" value=\"SI\">
 <input type=\"hidden\" name=\"canc_regola_1\" value=\"$canc_regola_1\">
 <input type=\"submit\" name=\"gia_stato\" value=\"  ".mex("SI",$pag)."  \"></form>";
@@ -106,7 +116,7 @@ $inserire = "NO";
 echo mex("Si deve inserire almeno un appartamento da associare",$pag).".<br>";
 } # fine if (!$lista_app)
 else {
-$appartamenti = esegui_query ("select idappartamenti from appartamenti");
+$appartamenti = esegui_query ("select idappartamenti from $tableappartamenti");
 $num_appartamenti = numlin_query ($appartamenti);
 for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1 = $num1 + 1) {
 $appartamento = risul_query($appartamenti,$num1,idappartamenti);
@@ -130,11 +140,46 @@ echo mex("La regola di assegnazione 2  stata inserita",$pag).".<br>";
 } # fine if ($inserire != "NO")
 } # fine if ($regola_2)
 
+if ($regola_3) {
+if (!$tipotariffa) {
+$inserire = "NO";
+echo mex("Si deve scegliere la tariffa",$pag).".<br>";
+} # fine if (!$tipotariffa)
+else {
+$regola_esistente = esegui_query("select * from $tableregole where tariffa_per_utente = '$tipotariffa'");
+$num_regole_esistente = numlin_query($regola_esistente);
+if ($num_regole_esistente != 0) {
+$inserire = "NO";
+echo mex("La tariffa scelta ha gi un utente associato, cancella la regola prima di inserirne una nuova",$pag).".<br>";
+} # fine if ($num_regole_esistente != 0)
+} # fine else if (!$tipotariffa)
+if (!$id_utente_inserimento) {
+$inserire = "NO";
+echo mex("Si deve inserire l'utente da associare",$pag).".<br>";
+} # fine if (!$id_utente_inserimento)
+else {
+$id_utente_inserimento = addslashes($id_utente_inserimento);
+$utente_tariffa = esegui_query("select nome_utente from $tableutenti where idutenti = '$id_utente_inserimento'");
+if (numlin_query($utente_tariffa) != 1) {
+$inserire = "NO";
+echo mex("L'utente ",$pag).$id_utente_inserimento.mex(" non esiste",$pag).".<br>";
+} # fine if ($numlin_query($utente_tariffa) != 1)
+} # fine else if (!$id_utente_inserimento)
+if ($inserire != "NO") {
+$idregole = esegui_query("select max(idregole) from $tableregole");
+$idregole = risul_query($idregole,0,0);
+$idregole = $idregole + 1;
+esegui_query("insert into $tableregole (idregole,tariffa_per_utente,iddatainizio) values ('$idregole','$tipotariffa', '$id_utente_inserimento')");
+echo mex("La regola di assegnazione 3  stata inserita",$pag).".<br>";
+} # fine if ($inserire != "NO")
+} # fine if ($regola_3)
+
 unlock_tabelle($tabelle_lock);
 
 echo "
 <form method=\"post\" action=\"crearegole.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"submit\" name=\"ok\" value=\"".mex("Torna indietro",$pag)."\">";
 } # fine if ($inserisci)
 
@@ -147,17 +192,18 @@ echo "<br><center><font size=+2>".mex("Inserisci le regole di assegnazione per l
 <center>".mex("Regola di assegnazione",$pag)." <b>1</b>.</center><br>
 <form method=\"post\" action=\"crearegole.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"inserisci\" value=\"SI\">
 ".mex("Chiedi prima di assegnare l'appartamento",$pag)." <select name=\"appartamento\">
 <option value=\"\" selected>--</option>";
 include("./dati/selectappartamenti.php");
 echo "</select> ".mex("nel periodo dal",$pag)." 
 <select name=\"inizioperiodo\">";
-include("./dati/selectperiodi$anno.php");
+include("./dati/selectperiodi$anno.$id_utente.php");
 echo "
 </select>
 ".mex("al",$pag)." <select name=\"fineperiodo\">";
-include("./dati/selectperiodi$anno.php");
+include("./dati/selectperiodi$anno.$id_utente.php");
 echo "</select><br>".mex("motivazione",$pag).":
  <input type=\"text\" name=\"motivazione\" size=\"30\" maxlength=\"30\">
  (".mex("opzionale",$pag).")<br><center>
@@ -165,6 +211,7 @@ echo "</select><br>".mex("motivazione",$pag).":
 </form></center>
 <form method=\"post\" action=\"crearegole.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"inserisci\" value=\"SI\">
 <input type=\"submit\" name=\"canc_regola_1\" value=\"".mex("Cancella tutte le regole di questo tipo",$pag)."\">
 </form><hr width=\"95%\">
@@ -172,6 +219,7 @@ echo "</select><br>".mex("motivazione",$pag).":
 <center>".mex("Regola di assegnazione",$pag)." <b>2</b>.</center><br>
 <form method=\"post\" action=\"crearegole.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"inserisci\" value=\"SI\">
 ".mex("Quando si sceglie la tariffa",$pag)."
 <select name=\"tipotariffa\">
@@ -193,15 +241,61 @@ echo "</select>
  ".mex("se non si inserisce nessun altro metodo di assegnazione",$pag).".<br>";
 echo "<center>
 <input type=\"submit\" name=\"regola_2\" value=\"".mex("Inserisci la regola",$pag)." 2\">
-</center></form>";
-echo "<hr width=\"95%\"><center><br>
+</center></form><hr width=\"95%\">";
+
+$tutti_utenti = esegui_query("select * from $tableutenti order by idutenti");
+$num_tutti_utenti = numlin_query($tutti_utenti);
+if ($num_tutti_utenti > 1) {
+unset($option_select_utenti);
+for ($num1 = 0 ; $num1 < $num_tutti_utenti ; $num1++) {
+$idutenti = risul_query($tutti_utenti,$num1,idutenti);
+if ($idutenti != 1) {
+$nome_utente_option = risul_query($tutti_utenti,$num1,nome_utente);
+$option_select_utenti .= "<option value=\"$idutenti\">$nome_utente_option</option>";
+} # fine if ($idutenti != $id_utente_inserimento)
+else $nome_utente1 = risul_query($tutti_utenti,$num1,nome_utente);
+} # fine for $num1
+echo "<center>".mex("Regola di assegnazione",$pag)." <b>3</b>.</center><br>
+<form method=\"post\" action=\"crearegole.php\">
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"inserisci\" value=\"SI\">
+".mex("Quando l'utente amministratore",$pag)." ($nome_utente1) ".mex("sceglie la tariffa",$pag)."
+<select name=\"tipotariffa\">
+<option value=\"\" selected>----</option>";
+$rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 ");
+$numero_tariffe = risul_query($rigatariffe,0,nomecostoagg);
+for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa = $numtariffa + 1) {
+$tariffa = "tariffa".$numtariffa;
+$tariffa_vedi = mex("tariffa","prenota.php").$numtariffa;
+$nometariffa = risul_query($rigatariffe,0,$tariffa);
+if ($nometariffa != "") $nometariffa_vedi = " ($nometariffa)";
+else $nometariffa_vedi = "";
+echo "
+<option value=\"$tariffa\">$tariffa_vedi$nometariffa_vedi</option>";
+} # fine for $numtariffa
+echo "</select>
+ ".mex("fai risultare come se l'utente",$pag)."
+ <select name=\"id_utente_inserimento\">
+<option value=\"\" selected>----</option>
+$option_select_utenti
+</select>
+ ".mex("avesse inserito la prenotazione e l'eventuale cliente",$pag).".<br>";
+echo "<center>
+<input type=\"submit\" name=\"regola_3\" value=\"".mex("Inserisci la regola",$pag)." 3\">
+</center></form><hr width=\"95%\">";
+} # fine if ($num_tutti_utenti > 1)
+
+echo "<center><br>
 <form method=\"post\" action=\"visualizza_tabelle.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"regole\">
 <input type=\"submit\" name=\"visualizza\" value=\"".mex("Vedi le regole gi inserite",$pag)."\">
 </form>
 <form method=\"post\" action=\"inizio.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"submit\" name=\"torna\" value=\"".mex("Torna al men principale",$pag)."\">
 <br></center></form>";
 
@@ -209,6 +303,11 @@ echo "<hr width=\"95%\"><center><br>
 } # fine else if ($inserisci)
 
 
+
+} # fine if ($id_utente and $id_utente == 1)
+
+
+
 ?>
 
 </body>
