@@ -69,8 +69,20 @@ case "Inserisci i dati":  			$messaggio = "Insert data"; break;
 case "Torna al men principale":  		$messaggio = "Back to main menu"; break;
 case "Italia":  				$messaggio = ""; break;
 case "non verrano modificati i dati specifici delle 2 persone di riferimento":	$messaggio = "data specific to the 2 reference people will not be changed"; break;
-case "":  		$messaggio = ""; break;
-case "":  		$messaggio = ""; break;
+case "sono stati modificati":  			$messaggio = "have been modified"; break;
+case "e":  					$messaggio = "and"; break;
+case "Non ci sono":  				$messaggio = "There are not"; break;
+case "appartamenti tra quelli richiesti che possano ospitare":	$messaggio = "apartments between the requested ones that can accomodate"; break;
+case "Il numero di prenotazioni  sbagliato":	$messaggio = "The number of reservations is wrong"; break;
+case "Aggiungi":  				$messaggio = "Add"; break;
+case "N di tipologie da aggiungere":  		$messaggio = "Number of types to add"; break;
+case "Non si  trovato nessun cliente chiamato":	$messaggio = "There are no clients called"; break;
+case "Non c' nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "There are no periods in assignation rule 1 in which is allowed to insert reservations for user"; break;
+case "Non c' nessun appartamento tra quelli richiesti in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "There are no apartments between the requested ones in which is allowed to insert reservations for user"; break;
+case "appartamenti tra quelli richiesti in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "apartments between the requested ones in which is allowed to insert reservations for user"; break;
+case "L'appartamento":  			$messaggio = "The apartment"; break;
+case "contenuto nella lista non esiste":  	$messaggio = "included in the list does not exist"; break;
+case "Il numero di persone  sbagliato":  	$messaggio = "The number of people is wrong"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
