@@ -35,12 +35,12 @@ case "Tutti i dati permanenti sono stati inseriti":	$messaggio = "All the perman
 case "Non ho i permessi di scrittura sulla directory dati, cambiarli e reiniziare l'installazione":	$messaggio = "I don't have write permissions on dati folder, change them and begin again installation"; break;
 case "Tipo di database":			$messaggio = "Database type"; break;
 case "Database gi esistente":			$messaggio = "Existing database"; break;
-case "Se gi esistente il database deve essere vuoto":	$messaggio = "If already existing it must be empty"; break;
+case "Se gi esistente e non vuoto usare un prefisso non presente nel database per il nome delle tabelle":	$messaggio = "If already existing and not empty use a prefix not present in the database for tables names"; break;
 case "Normalmete 5432 per Postgresql o 3306 per Mysql":	$messaggio = "Normally 5432 for Postgresql or 3306 for Mysql"; break;
 case "solo per Postgresql con database non esistente":	$messaggio = "only for Postgresql with database not existing"; break;
-case "":					$messaggio = ""; break;
-case "":					$messaggio = ""; break;
-case "":					$messaggio = ""; break;
+case "Prefisso nel nome delle tabelle":		$messaggio = "Prefix in tables name"; break;
+case "opzionale, utile per pi installazioni di php-residence nello stesso database":	$messaggio = "optional, useful for more installations of php-residence in the same database"; break;
+case "Il prefisso del nome delle tabelle  sbagliato (accettate solo lettere minuscole, numeri e _ , primo carattere lettera)":	$messaggio = "The prefix of tables names is wrong (only accepted lower case letters, numbers and _ , first character letter)"; break;
 case "":					$messaggio = ""; break;
 case "":					$messaggio = ""; break;
 case "":					$messaggio = ""; break;
