@@ -31,10 +31,15 @@ case "L'appartamento ":  			$messaggio = "The apartment "; break;
 case " non esiste":  				$messaggio = " does not exist"; break;
 case "La regola di assegnazione 2  stata inserita":	$messaggio = "The assignation rule 2 has been inserted"; break;
 case "Torna indietro":  			$messaggio = "Go back"; break;
-case "":  		$messaggio = ""; break;
-case "":  		$messaggio = ""; break;
-case "":  		$messaggio = ""; break;
-case "":  		$messaggio = ""; break;
+case "Motivazione non valida":  		$messaggio = "Non valid motivation"; break;
+case "La regola di assegnazione 3  stata inserita":	$messaggio = "The assignation rule 3 has been inserted"; break;
+case "La tariffa scelta ha gi un utente associato, cancella la regola prima di inserirne una nuova":	$messaggio = "The choosen fare has already an assigned user, delete the rule before inserting a new one"; break;
+case "Quando l'utente amministratore":  	$messaggio = "When the administrator user"; break;
+case "sceglie la tariffa":  			$messaggio = "chooses fare"; break;
+case "fai risultare come se l'utente":  	$messaggio = "show as if the user"; break;
+case "avesse inserito la prenotazione e l'eventuale cliente":	$messaggio = "had inserted the reservationand the eventual client"; break;
+case "Si deve inserire l'utente da associare":	$messaggio = "You have to choose the user to be associated"; break;
+case "L'utente ":  				$messaggio = "The user "; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
