@@ -12,8 +12,10 @@ case "al":  					$messaggio = "to"; break;
 case " piena":  				$messaggio = "is full"; break;
 case " pieno":  				$messaggio = "is full"; break;
 case "<b>C'</b> ancora disponibilit nel periodo richiesto":	$messaggio = "<b>There is</b> still availability in the requested period"; break;
-case " in appartamenti da <b>almeno":  		$messaggio = " in apartment of <b>at least"; break;
+case " in un appartamento da <b>almeno":  	$messaggio = " in an apartment of <b>at least"; break;
 case " in appartamenti da":  			$messaggio = " in apartments of"; break;
+case " in":  					$messaggio = " in"; break;
+case "appartamenti da":  			$messaggio = "apartments of"; break;
 case ", ma si dovranno fare degli spostamenti nei periodi della <font color=\"blue\">regola di assegnazione 1</font>":	$messaggio = ", but some movements will have to be made in periods of <font color=\"blue\">assignation rule 1</font>"; break;
 case "<b>Non c'</b> pi disponibilit nel periodo richiesto":	$messaggio = "<b>There is not</b> availability in the requested period any more"; break;
 case "Si potrebbe inserire la prenotazione dividendola in":	$messaggio = "The reservation could be inserted breaking it into"; break;
@@ -32,8 +34,15 @@ case "Visualizza il contratto":  		$messaggio = "View contract"; break;
 case "di tipo":  				$messaggio = "type"; break;
 case "con la tariffa":  			$messaggio = "with fare"; break;
 case "Inserisci la prenotazione":  		$messaggio = "Insert the reservation"; break;
-case "":  		$messaggio = ""; break;
-case "":  		$messaggio = ""; break;
+case "Ricontrolla la disponibilit negli appartamenti selezionati":	$messaggio = "Check again availability in selected apartments"; break;
+case " in un appartamento della <b>tariffa selezionata</b>":	$messaggio = " in an apartment of the <b>selected fare</b>"; break;
+case "appartamenti delle <b>tariffe selezionate</b>":	$messaggio = "apartments of the <b>selected fares</b>"; break;
+case " in un appartamento da":  		$messaggio = " in an apartment of"; break;
+case "settimana":  				$messaggio = "week"; break;
+case "giorno":  				$messaggio = "day"; break;
+case "TOTALE":  				$messaggio = "TOTAL"; break;
+case "Non c' nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "There are no periods in assignation rule 1 in which is allowed to insert reservations for user"; break;
+case "Non c' nessun appartamento tra quelli richiesti in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "There are no apartments between the requested ones in which is allowed to insert reservations for user"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
