@@ -17,7 +17,7 @@ case "Agosto":  				$messaggio = "August"; break;
 case "Settembre":  				$messaggio = "September"; break;
 case "Ottobre":  				$messaggio = "October"; break;
 case "Novembre":  				$messaggio = "November"; break;
-case "Dicembre":  				$messaggio = "Dicember"; break;
+case "Dicembre":  				$messaggio = "December"; break;
 case "Visualizza la tabella":  			$messaggio = "View the table"; break;
 case "con":  					$messaggio = "with"; break;
 case "tutte le prenotazioni":  			$messaggio = "all the reservations"; break;
@@ -67,14 +67,12 @@ case "Ott. anno successivo":  			$messaggio = "Oct. next year"; break;
 case "Nov. anno successivo":  			$messaggio = "Nov. next year"; break;
 case "Dic. anno successivo":  			$messaggio = "Dic. next year"; break;
 case "Gen. 2 anni successivi":  		$messaggio = "Jan. 2 years later"; break;
-case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi) e 
-regole d'assegnazione relative a quest'anno.":  $messaggio = "Import from previous year reservations, fares (inclusive the extra costs) and assignation rules that refer to this year."; break;
+case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi), privilegi degli utenti e regole d'assegnazione.":  $messaggio = "Import from previous year reservations, fares (inclusive the extra costs), users privileges and assignation rules."; break;
 case "Anno ":  					$messaggio = "Year "; break;
 case " creato":  				$messaggio = " created"; break;
 case "Non ci sono periodi che riguardano il ":  $messaggio = "There are no periods regarding "; break;
 case " nel ":  					$messaggio = " in "; break;
-case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi
- aggiuntivi, caparra, nome delle tariffe e regole di assegnazione 2":  	$messaggio = ", or the day of beginning/end rental was different, only data about extra costs, deposit, the names of the fares and the assignation rules 2 has been imported"; break;
+case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3":	$messaggio = ", or the day of beginning/end rental was different, only data about extra costs, deposit, the names of the fares, users privileges and the assignation rules 2 and 3 have been imported"; break;
 case "Attenzione</b></font>: i periodi del ":  	$messaggio = "Warning</b></font>: the periods of "; break;
 case " finivano dopo quelli del ":  		$messaggio = " ended after the ones of "; break;
 case " e vi erano":  				$messaggio = " and there were"; break;
@@ -101,9 +99,10 @@ case "Ott":  					$messaggio = "Oct"; break;
 case "Nov":  					$messaggio = "Nov"; break;
 case "Dic":  					$messaggio = "Dec"; break;
 case "Il formato dell'anno richiesto  sbagliato":	$messaggio = "The format of the requested year is wrong"; break;
+case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "Months were wrongly selected, they have been inserted from January to December"; break;
+case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
-
 
 } # fine switch ($messaggio)
 
