@@ -49,7 +49,7 @@ case "caratteri per colonna":  			$messaggio = "characters per column"; break;
 case "La lunghezza dei cognomi nelle tabelle dei mesi  stata cambiata":	$messaggio = "Surnames length in the months tables has been changed"; break;
 case "Cambia il numero delle tariffe":  	$messaggio = "Change the number of fares"; break;
 case "per l'anno":  				$messaggio = "for year"; break;
-case "Il numero della tariffe  stato cambiato":	$messaggio = "The number of fares has been changed"; break;
+case "Il numero delle tariffe  stato cambiato":	$messaggio = "The number of fares has been changed"; break;
 case "Il numero di tariffe  sbagliato":  	$messaggio = "The number of fares is wrong"; break;
 case "Sistema di backup":  			$messaggio = "Backup system"; break;
 case "Il numero delle righe  sbagliato":  	$messaggio = "The number of rows is wrong"; break;
@@ -72,6 +72,47 @@ case "separatore":  				$messaggio = "separator"; break;
 case "spazio":  				$messaggio = "space"; break;
 case "trattino":  				$messaggio = "hyphen"; break;
 case "a capo":  				$messaggio = "new line"; break;
+case "Modelli per internet":  			$messaggio = "Internet templates"; break;
+case " Do":  					$messaggio = " Su"; break;
+case " Lu":  					$messaggio = " Mo"; break;
+case " Ma":  					$messaggio = " Tu"; break;
+case " Me":  					$messaggio = " We"; break;
+case " Gi":  					$messaggio = " Th"; break;
+case " Ve":  					$messaggio = " Fr"; break;
+case " Sa":  					$messaggio = " Sa"; break;
+case "Gen":  					$messaggio = "Jan"; break;
+case "Feb":  					$messaggio = "Feb"; break;
+case "Mar":  					$messaggio = "Mar"; break;
+case "Apr":  					$messaggio = "Apr"; break;
+case "Mag":  					$messaggio = "May"; break;
+case "Giu":  					$messaggio = "Jun"; break;
+case "Lug":  					$messaggio = "Jul"; break;
+case "Ago":  					$messaggio = "Aug"; break;
+case "Set":  					$messaggio = "Sep"; break;
+case "Ott":  					$messaggio = "Oct"; break;
+case "Nov":  					$messaggio = "Nov"; break;
+case "Dic":  					$messaggio = "Dec"; break;
+case "nome della tariffa":  			$messaggio = "fare name"; break;
+case "data di inserimento":  			$messaggio = "insertion date"; break;
+case "tariffa completa":  			$messaggio = "complete fare"; break;
+case "Gestione utenti":  			$messaggio = "Users management"; break;
+case "Personalizzazioni dell'utente":  		$messaggio = "Customizations of user"; break;
+case "Cambia":  				$messaggio = "Change"; break;
+case "quelle di":  				$messaggio = "those of"; break;
+case "Importa i nomi dei contratti":  		$messaggio = "Import contract names"; break;
+case "dell'utente":  				$messaggio = "of user"; break;
+case "I minuti di durata di sessioni e transazioni sono stati cambiati":	$messaggio = "The duration in minutes of sessions and transactions has been changed"; break;
+case "Le ore di anticipo dell'inizio delle prenotazioni sono state cambiate":	$messaggio = "The hours of advance of the beginning of reservations have been changed"; break;
+case "Minuti dopo i quali considerare scadute sessioni e transazioni non aggiornate":	$messaggio = "Minutes after which consider expired not updated sessions and transactions"; break;
+case "Numero di ore di cui anticipare il momento in cui si considera iniziata una prenotazione":	$messaggio = "Number of hours by which anticipate the moment in which reservations are considered begun"; break;
+case "utente":  				$messaggio = "user"; break;
+case "Interconnessioni":  			$messaggio = "Interconnections"; break;
+case "Assegnazione automatica disattivata":  	$messaggio = "Automatic assignation disabled"; break;
+case "Assegnazione automatica attivata":  	$messaggio = "Automatic assignation enabled"; break;
+case "Assegnazione automatica disattivata (le prenotazioni non verranno mosse dal loro appartamento)":	$messaggio = "Automatic assignation disabled (reservations will not be moved from their apartment)"; break;
+case "Attiva":  				$messaggio = "Enable"; break;
+case "Assegnazione automatica attivata (le prenotazioni potranno essere mosse tra gli appartamenti assegnati)":	$messaggio = "Automatic assignation enabled (reservations can be moved between assigned apartments)"; break;
+case "Disattiva":  				$messaggio = "Disable"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
