@@ -74,6 +74,13 @@ case "Sconto":  				$messaggio = "Discount"; break;
 case " necessario inserire il cognome del cliente":	$messaggio = "The client's surname is needed"; break;
 case "confermata":  				$messaggio = "confirmed"; break;
 case "Confermata":  				$messaggio = "Confirmed"; break;
+case "N di prenotazioni di questa tipologia":	$messaggio = "Number of reservations of this type"; break;
+case "Aggiungi altre tipologie":  		$messaggio = "Add other types"; break;
+case "Tipologia":  				$messaggio = "Type"; break;
+case "Nessuna nuova prenotazione  stata inserita":	$messaggio = "No new reservation has been inserted"; break;
+case "perch l'appartamento assegnato non esiste pi":	$messaggio = "because the assigned apartment doesn't exist anymore"; break;
+case "Transazione scaduta":  			$messaggio = "Transaction expired"; break;
+case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
