@@ -22,8 +22,8 @@ case "Torna indietro":  			$messaggio = "Go back"; break;
 case "Trasferito in cassa":  			$messaggio = "Transferred in cash box"; break;
 case "RESTO":  					$messaggio = "REST"; break;
 case "pagine":  				$messaggio = "pages"; break;
-case "":  		$messaggio = ""; break;
-case "":  		$messaggio = ""; break;
+case "Cliente":  				$messaggio = "Client"; break;
+case "Utente":  				$messaggio = "User"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
