@@ -53,7 +53,7 @@ case "Inserisci nuove spese o entrate":  	$messaggio = "Insert new cash receipts
 case "Storia entrate-uscite prenotazioni":  	$messaggio = "History of reservations payments"; break;
 case "Sei sicuro di voler cancellare il costo aggiuntivo":	$messaggio = "Are you sure you want to delete extra cost"; break;
 case "Il costo aggiuntivo":  			$messaggio = "The extra cost"; break;
-case "Il costo aggiuntivo  cambiato nel frattempo, non  stao cancellato":	$messaggio = "The extra cost was changed meanwhile, it has not been deleted"; break;
+case "Il costo aggiuntivo  cambiato nel frattempo, non  stato cancellato":	$messaggio = "The extra cost was changed meanwhile, it has not been deleted"; break;
 case " stato cancellato":  			$messaggio = "has been deleted"; break;
 case "I periodi sono stati aggiunti fino al":  	$messaggio = "Periods have been added until"; break;
 case "Tabella con periodi e relative tariffe del":	$messaggio = "Table with periods and respective fares of"; break;
@@ -113,10 +113,10 @@ case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 1 dell'app
 case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 2 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignation rule 2 for"; break;
 case "La regola di assegnazione  stata cancellata":	$messaggio = "The assignation rule has been deleted"; break;
 case "La regola di assegnazione  gi stata cancellata":	$messaggio = "The assignation rule has already been deleted"; break;
-case "Tabella con la regole di assegnazione 1 del":	$messaggio = "Table with the assignation rules 1 of"; break;
+case "Tabella con le regole di assegnazione 1 del":	$messaggio = "Table with the assignation rules 1 of"; break;
 case "Motivazione":  				$messaggio = "Motivation"; break;
 case "Appartamento":  				$messaggio = "Apartment"; break;
-case "Tabella con la regole di assegnazione 2 del":	$messaggio = "Table with the assignation rules 2 of"; break;
+case "Tabella con le regole di assegnazione 2 del":	$messaggio = "Table with the assignation rules 2 of"; break;
 case "Appartamenti":  				$messaggio = "Apartments"; break;
 case "Tariffa":  				$messaggio = "Fare"; break;
 case "Inserisci nuove regole":  		$messaggio = "Insert new rules"; break;
@@ -144,12 +144,12 @@ case "Non_mostrare":  				$messaggio = "Do_not_display"; break;
 case "Regole":  				$messaggio = "Rules"; break;
 case "Tariffe abbinate":  			$messaggio = "Associated fares"; break;
 case "pagine":  				$messaggio = "pages"; break;
-case "Verranno effettuati i seguenti cambiamenti":	$messaggio = "I will make this changes"; break;
+case "Verranno effettuati i seguenti cambiamenti":	$messaggio = "You will make this changes"; break;
 case "I soldi pagati per la prenotazione":  	$messaggio = "Money paid for reservation"; break;
 case "a nome di":  				$messaggio = "for Mr/Mrs"; break;
 case "verranno cambiati da":  			$messaggio = "will be changed from"; break;
 case "a":  					$messaggio = "to"; break;
-case "differenza":  				$messaggio = "difference"; break;
+case "saldo":  					$messaggio = "difference"; break;
 case "Le prenotazioni <b>non sono state modificate</b> perch sono cambiate nel frattempo":	$messaggio = "The reservations <b>have not been modified</b> because the reservations table changed meanwhile"; break;
 case "Cambia le prenotazioni selezionate":  	$messaggio = "Change selected reservations"; break;
 case "ponendo":  				$messaggio = "to"; break;
@@ -161,6 +161,25 @@ case "di":  					$messaggio = "of"; break;
 case "la conferma":  				$messaggio = "confirmed"; break;
 case "La prenotazione":  			$messaggio = "The reservation"; break;
 case "verr confermata":  			$messaggio = "will be confirmed"; break;
+case "Data di inserimento":  			$messaggio = "Insertion date"; break;
+case "Calcola il subtotale delle prenotazioni selezionate":	$messaggio = "Calculate subtotal of selected reservations"; break;
+case "selezionate precedentemente":  		$messaggio = "previously selected"; break;
+case "Saldo totale":  				$messaggio = "Total difference"; break;
+case "l'anno":  				$messaggio = "year"; break;
+case "dal database":  				$messaggio = "from database"; break;
+case "<font color=\"red\"><b>ATTENZIONE</b></font>: premendo su <b>\"<i>Continua</i>\"</b>, tutti i dati riguardanti l'anno":	$messaggio = "<font color=\"red\"><b>WARNING</b></font>: if you press <b>\"<i>Continue</i>\"</b>, all data regarding year"; break;
+case "verranno <b>cancellati</b>":  		$messaggio = "will be <b>deleted</b>"; break;
+case "L'anno":  				$messaggio = "Year"; break;
+case " stato cancellato dal batabase":  	$messaggio = "has been deleted from database"; break;
+case "Non  stato possibile cancellare l'anno":	$messaggio = "It has not been possible to delete year"; break;
+case "dal database, controllare i permessi sulla cartella dati":	$messaggio = "from database, check permissions on dati folder"; break;
+case "Profilo":  				$messaggio = "Profile"; break;
+case "Cliente":  				$messaggio = "Client"; break;
+case "cliente":  				$messaggio = "client"; break;
+case "Tabella con le regole di assegnazione 3 del":	$messaggio = "Table with the assignation rules 3 of"; break;
+case "Utente":  				$messaggio = "User"; break;
+case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignation rule 3 for"; break;
+case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
