@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    PHP-RESIDENCE
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2004 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -20,7 +20,8 @@
 ##################################################################################
 
 
-$tipo_periodi = esegui_query("select * from anni where idanni = $anno");
+$tableanni = $PHPR_TAB_PRE."anni";
+$tipo_periodi = esegui_query("select * from $tableanni where idanni = $anno");
 $tipo_periodi = risul_query($tipo_periodi,0,tipo_periodi);
 if ($tipo_periodi == "g") {
 $parola_settimanale = "giornaliero";
