@@ -2,7 +2,7 @@
 
 #################################################################################
 #    PHP-RESIDENCE
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2004 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -21,33 +21,28 @@
 
 
 
+$debug = "off";
+
+
 
 # Function per passare dalla tabella prenota alle variabili
-function tab_a_var ($limiti_var,$app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_settimana_id,$anno,$dati_app,$profondita,$nome_tab_prenota = "prenota") {
+function tab_a_var (&$limiti_var,&$app_prenota_id,&$app_orig_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$app_assegnabili_id,&$prenota_in_settimana_id,$anno,&$dati_app,$profondita,$nome_tab_prenota = "prenota") {
+global $PHPR_TAB_PRE;
+global $debug;
 $tableprenota = $nome_tab_prenota . $anno . $profondita[iniziale];
-$tableperiodi = periodi . $anno;
+$tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
+$tableappartamenti = $PHPR_TAB_PRE."appartamenti";
 
-#calcolo l'id del periodo corrente per le prenotazioni gi iniziate ==> fisse
-if (!$limiti_var[idperiodocorrente]) {
-$oggi = date("Y-m-d");
-$annocorrente = date("Y");
-$idperiodocorrente = esegui_query("select idperiodi from $tableperiodi where datainizio <= '$oggi' and datafine >= '$oggi' ");
-$numidperiodocorrente = numlin_query($idperiodocorrente);
-if ($numidperiodocorrente >= 1) {
-$num_risposta = 0;
-if ($numidperiodocorrente == 2) $num_risposta = 1;
-$idperiodocorrente = risul_query($idperiodocorrente,$num_risposta,idperiodi);
-} # fine if ($numidperiodocorrente >= 1)
-else {
-if ( $anno < $annocorrente ) $idperiodocorrente = 100000;
-if ( $anno >= $annocorrente ) $idperiodocorrente = -1;
-} # fine else if ($numidperiodocorrente >= 1)
-$limiti_var[idperiodocorrente] = $idperiodocorrente;
-} # fine if (!$limiti_var[idperiodocorrente])
+if (!$limiti_var[idperiodocorrente]) $limiti_var[idperiodocorrente] = calcola_id_periodo_corrente($anno);
+if (!$limiti_var[tutti_fissi]) {
+$tablepersonalizza = $PHPR_TAB_PRE."personalizza";
+$prenota_tutte_fisse = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'tutti_fissi' and idutente = '1'");
+$limiti_var[tutti_fissi] = risul_query($prenota_tutte_fisse,0,valpersonalizza);
+} # fine if (!$limiti_var[tutti_fissi])
 
 # metto i dati della tabella appartamenti in $dati_app
 if (!$dati_app) {
-$idapp = esegui_query("select idappartamenti,maxoccupanti from appartamenti order by priorita");
+$idapp = esegui_query("select idappartamenti,maxoccupanti from $tableappartamenti order by priorita");
 $numappartamenti = numlin_query($idapp);
 for ($num1 = 0 ; $num1 < $numappartamenti ; $num1++) {
 $numapp = risul_query($idapp,$num1,idappartamenti);
@@ -66,9 +61,9 @@ $dati_app[lista] = $lista_tutti_app;
 $dati_app[totapp] = $numappartamenti;
 } # fine if (!$dati_app)
 
-if (!$limiti_var[ini]) $limiti_var[ini] = $limiti_var[n_fine];
-if (!$limiti_var[fine]) $limiti_var[fine] = $limiti_var[n_ini];
-$prenota_in_var = esegui_query("select idprenota,idappartamenti,iddatainizio,iddatafine,assegnazioneapp,app_assegnabili,num_persone from $tableprenota where (iddatainizio <= '".$limiti_var[ini]."' and iddatafine >= '".$limiti_var[n_ini]."') or (iddatainizio <= '".$limiti_var[n_fine]."' and iddatafine >= '".$limiti_var[fine]."')");
+if (!$limiti_var[ini]) $limiti_var[ini] = ($limiti_var[n_fine] + 1);
+if (!$limiti_var[fine]) $limiti_var[fine] = ($limiti_var[n_ini] - 1);
+$prenota_in_var = esegui_query("select idprenota,idappartamenti,iddatainizio,iddatafine,assegnazioneapp,app_assegnabili,num_persone from $tableprenota where (iddatainizio < '".$limiti_var[ini]."' and iddatafine >= '".$limiti_var[n_ini]."') or (iddatainizio <= '".$limiti_var[n_fine]."' and iddatafine > '".$limiti_var[fine]."')");
 $num_prenota_in_var = numlin_query($prenota_in_var);
 for ($num1 = 0 ; $num1 < $num_prenota_in_var ; $num1++) {
 $idprenota = risul_query($prenota_in_var,$num1,idprenota);
@@ -77,12 +72,13 @@ $app_prenota_id[$idprenota] = risul_query($prenota_in_var,$num1,idappartamenti);
 $app_orig_prenota_id[$idprenota] = $app_prenota_id[$idprenota];
 $inizio_prenota_id[$idprenota] = risul_query($prenota_in_var,$num1,iddatainizio);
 $fine_prenota_id[$idprenota] = risul_query($prenota_in_var,$num1,iddatafine);
+if ($debug == "on") echo "Aggiunta prenota $idprenota dal ".$inizio_prenota_id[$idprenota]." al ".$fine_prenota_id[$idprenota]."<br>";
 for ($num2 = $inizio_prenota_id[$idprenota] ; $num2 <= $fine_prenota_id[$idprenota] ; $num2++) {
 if (!$prenota_in_settimana_id[$num2]) $prenota_in_settimana_id[$num2] = ",";
 $prenota_in_settimana_id[$num2] .= "$idprenota,";
 } # fine for $num2
 $assegnazione_app = risul_query($prenota_in_var,$num1,assegnazioneapp);
-if ($inizio_prenota_id[$idprenota] > $limiti_var[idperiodocorrente] and $assegnazione_app != "k") {
+if ($inizio_prenota_id[$idprenota] > $limiti_var[idperiodocorrente] and $assegnazione_app != "k" and $limiti_var[tutti_fissi] != "SI") {
 $num_persone = risul_query($prenota_in_var,$num1,num_persone);
 $app_assegnabili = risul_query($prenota_in_var,$num1,app_assegnabili);
 if (!$num_persone or $num_persone <= $dati_app[minocc]) {
@@ -102,7 +98,7 @@ $lista_app = str_replace(",".$app_in_lista[$num2].",",",",$lista_app);
 $lista_app = substr($lista_app,1,-1);
 $app_assegnabili_id[$idprenota] = $lista_app;
 } # fine else if (!$num_persone or $num_persone <= $dati_app[minocc])
-} # fine if ($inizio_prenota_id[$idprenota] > $limiti_var[idperiodocorrente] and $assegnazione_app != "k")
+} # fine if ($inizio_prenota_id[$idprenota] > $limiti_var[idperiodocorrente] and $assegnazione_app != "k" and...
 } # fine if (!$app_prenota_id[$idprenota])
 } # fine for $num1
 if ($limiti_var[n_ini] < $limiti_var[ini]) $limiti_var[ini] = $limiti_var[n_ini];
@@ -113,7 +109,6 @@ if ($limiti_var[n_fine] > $limiti_var[fine]) $limiti_var[fine] = $limiti_var[n_f
 
 
 
-
 # Function per trovare tutte le prenotazioni in un appartamento in un certo periodo
 function prenota_in_app_e_periodo ($app,$ini_periodo,$fine_periodo,$app_prenota_id,$prenota_in_settimana_id) {
 for ($num1 = $ini_periodo ; $num1 <= $fine_periodo ; $num1++) $lista_prenota_periodo .= substr($prenota_in_settimana_id[$num1],1);
@@ -129,9 +124,102 @@ return $prenota_presente;
 
 
 
+function inserisci_prenota_fittizie ($info_periodi,&$profondita,&$app_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$prenota_in_settimana_id,&$app_assegnabili_id) {
+for ($num1 = 0 ; $num1 < $info_periodi[numero] ; $num1++) {
+$id_app_periodo = $info_periodi[app][$num1];
+$idinizio_periodo = $info_periodi[ini][$num1];
+$idfine_periodo = $info_periodi[fine][$num1];
+$idinizio_prenota_falsa = $idinizio_periodo;
+$prenota_falsa_da_inserire = "NO";
+for ($num2 = $idinizio_periodo ; $num2 <= ($idfine_periodo + 1) ; $num2++) {
+$prenota_presente = prenota_in_app_e_periodo($id_app_periodo,$num2,$num2,$app_prenota_id,$prenota_in_settimana_id);
+$num_prenota_presente = count($prenota_presente);
+if ($num_prenota_presente != 0 or $num2 == ($idfine_periodo + 1)) {
+if ($prenota_falsa_da_inserire == "SI") {
+$profondita[tot_prenota_attuale]++;
+$app_prenota_id[$profondita[tot_prenota_attuale]] = $id_app_periodo;
+$inizio_prenota_id[$profondita[tot_prenota_attuale]] = $idinizio_prenota_falsa;
+$fine_prenota_id[$profondita[tot_prenota_attuale]] = $idfine_prenota_falsa;
+for ($num3 = $idinizio_prenota_falsa ; $num3 <= $idfine_prenota_falsa ; $num3++) {
+if (!$prenota_in_settimana_id[$num3]) $prenota_in_settimana_id[$num3] = ",";
+$prenota_in_settimana_id[$num3] .= $profondita[tot_prenota_attuale].",";
+} # fine for $num3
+} # fine if ($prenota_falsa_da_inserire == "SI")
+$prenota_falsa_da_inserire = "NO";
+$idinizio_prenota_falsa = $num2 + 1;
+if ($num2 != ($idfine_periodo + 1)) {
+reset($prenota_presente);
+while (list ($key, $val) = each ($prenota_presente)) $app_assegnabili_id[$key] = "";
+} # fine if ($num2 != ($idfine_periodo + 1))
+} # fine if ($num_prenota_presente != 0 or $num2 == ($idfine_periodo + 1))
+else {
+$prenota_falsa_da_inserire = "SI";
+$idfine_prenota_falsa = $num2;
+} # fine else if ($num_prenota_presente != 0 or $num2 == ($idfine_periodo + 1))
+} # fine for $num2
+} # fine for $num1
+} # fine function inserisci_prenota_fittizie
+
+
+
+
+function aggiorna_tableprenota ($app_prenota_id,$app_orig_prenota_id,$nome_tableprenota) {
+if (@is_array($app_orig_prenota_id)) {
+reset($app_orig_prenota_id);
+while (list($idprenota, $app_prenota) = each($app_orig_prenota_id)) {
+if ($app_prenota_id[$idprenota] != $app_prenota) {
+$app_cambiato = $app_prenota_id[$idprenota];
+esegui_query("update $nome_tableprenota set idappartamenti = '$app_cambiato' where idprenota = '$idprenota'");
+#$adesso = date("Y-M-d H:i:s");
+#esegui_query("update $tableprenota set data_modifica = '$adesso' where idprenota = '$idprenota'");
+} # fine if ($app_prenota_id[$idprenota] != $app_prenota)
+} # fine while (list($key, $val) = each($app_orig_prenota_id))
+} # fine if (@is_array($app_orig_prenota_id))
+} # fine function aggiorna_tableprenota
+
+
+
+
+# function che controlla che gli app. richiesti non siano tutti occupati
+function controlla_tutti_occupati ($idinizio,$idfine,$app_richiesti,$prenota_in_settimana_id,$app_prenota_id,$app_assegnabili_id,$dati_app) {
+$tutti_occupati = "NO";
+if ($app_richiesti) while (list($key, $val) = each($app_richiesti)) if ($val != "SI") unset($app_richiesti[$key]);
+if (!$app_richiesti) $num_app_controlla_orig = $dati_app[totapp];
+else $num_app_controlla_orig = count($app_richiesti);
+for ($num1 = $idinizio ; $num1 <= $idfine ; $num1++) {
+$num_prenota_presenti_in_settimana = count(explode(",",$prenota_in_settimana_id[$num1])) - 2;
+if ($num_prenota_presenti_in_settimana >= $num_app_controlla_orig) {
+if (!$app_richiesti) { $tutti_occupati = "SI"; break; }
+else {
+$app_controlla = $app_richiesti;
+$uno_libero = "NO";
+reset($app_controlla);
+while (list($key, $val) = each($app_controlla)) {
+$prenotainperiodo = prenota_in_app_e_periodo($key,$num1,$num1,$app_prenota_id,$prenota_in_settimana_id);
+if (count($prenotainperiodo) == 0) { $uno_libero = "SI"; break; }
+$app_assegnabili_prenota = $app_assegnabili_id[key($prenotainperiodo)];
+if ($app_assegnabili_prenota == "v") {
+if ($num_prenota_presenti_in_settimana < $dati_app[totapp]) $uno_libero = "SI";
+break;
+} # fine if ($app_assegnabili_prenota == "v")
+if ($app_assegnabili_prenota) {
+$app_assegnabili_prenota = explode (",", $app_assegnabili_prenota);
+for ($num2 = 0 ; $num2 < count($app_assegnabili_prenota) ; $num2++) if (!$app_controlla[$app_assegnabili_prenota[$num2]]) $app_controlla[$app_assegnabili_prenota[$num2]] = "SI";
+} # fine if ($app_assegnabili_prenota)
+} # fine while (list($key, $val) = each($app_controlla))
+if ($uno_libero == "NO") { $tutti_occupati = "SI"; break; }
+} # fine else if (!$app_richiesti)
+} # fine if ($num_prenota_presenti_in_settimana >= $num_app_controlla_orig)
+} # fine for $num1
+return $tutti_occupati;
+} # fine function controlla_tutti_occupati
+
+
+
+
 # Struttura delle variabili sulle prenotazioni create con tab_a_var() :
 #
-# $prenota_in_settimana_id[id_settimana] = ",id_prenota,id_prenota,...,id_prenota,"
+# $prenota_in_settimana_id[id_settimana] = ",id_prenota,id_prenota,...,id_prenota," ("" se vuoto)
 # $inizio_prenota_id[id_prenota] = "id_settimana"
 # $fine_prenota_id[id_prenota] = "id_settimana"
 # $app_prenota_id[id_prenota] = "id_app"
@@ -142,12 +230,45 @@ return $prenota_presente;
 
 
 #
-# LIBERASETTIMANE: function ricorsiva per l'assegnazione dell'appartamento.
+# LIBERASETTIMANE: function ricorsiva per l'assegnazione degli appartamenti.
 #
-function liberasettimane ($idinizio,$idfine,$limiti_var,$anno,$fatto,$appartamento,$profondita,$app_richiesti,$app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_settimana_id,$dati_app,$nome_tab_prenota = "prenota") {
+function liberasettimane ($idinizio,$idfine,&$limiti_var,$anno,&$fatto,&$appartamento,$profondita,$app_richiesti,&$app_prenota_id,&$app_orig_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$app_assegnabili_id,&$prenota_in_settimana_id,&$dati_app,$nome_tab_prenota = "prenota") {
+global $debug;
+
+if ($app_richiesti[",numero,"]) {
+$app_richiesti_vett = $app_richiesti;
+$idinizio_vett = $idinizio;
+$idfine_vett = $idfine;
+$appartamento_vett = $appartamento;
+if (!$app_richiesti_vett[id]) {
+$app_richiesti_vett[id] = 1;
+$limiti_var[n_ini] = "";
+$limiti_var[n_fine] = "";
+for ($num1 = 1 ; $num1 <= $app_richiesti_vett[",numero,"] ; $num1++) {
+if (!$limiti_var[n_ini] or $limiti_var[n_ini] > $idinizio_vett[$num1]) $limiti_var[n_ini] = $idinizio_vett[$num1];
+if (!$limiti_var[n_fine] or $limiti_var[n_fine] < $idfine_vett[$num1]) $limiti_var[n_fine] = $idfine_vett[$num1];
+} # fine for $num1
+} # fine if (!$app_richiesti_vett[id])
+else {
+$app_richiesti_vett[id]++;
+$limiti_var[n_ini] = $idinizio_vett[$app_richiesti_vett[id]];
+$limiti_var[n_fine] = $idfine_vett[$app_richiesti_vett[id]];
+} # fine else if (!$app_richiesti_vett[id])
+unset($app_richiesti);
+if ($app_richiesti_vett[$app_richiesti_vett[id]] != ",tutti,") {
+$vett_app = explode(",",$app_richiesti_vett[$app_richiesti_vett[id]]);
+for ($num1 = 0 ; $num1 < count($vett_app) ; $num1++) $app_richiesti[$vett_app[$num1]] = "SI";
+} # fine if ($app_richiesti_vett[$app_richiesti_vett[id]] != ",tutti,")
+$idinizio = $idinizio_vett[$app_richiesti_vett[id]];
+$idfine = $idfine_vett[$app_richiesti_vett[id]];
+$appartamento = "";
+} # fine if ($app_richiesti[",numero,"])
+else {
 $limiti_var[n_ini] = $idinizio;
 $limiti_var[n_fine] = $idfine;
-if (!is_array($profondita)) {
+} # fine else if ($app_richiesti[",numero,"])
+
+if (!@is_array($profondita)) {
 $primo_ciclo = "SI";
 $prof_copia = $profondita;
 $profondita = "";
@@ -158,27 +279,34 @@ $max_prenota = esegui_query("select max(idprenota) from $tableprenota");
 $tot_prenota = risul_query($max_prenota,0,0);
 $profondita[tot_prenota_ini] = $tot_prenota;
 $profondita[tot_prenota_attuale] = $tot_prenota;
-tab_a_var (&$limiti_var,&$app_prenota_id,&$app_orig_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$app_assegnabili_id,&$prenota_in_settimana_id,$anno,&$dati_app,$profondita,$nome_tab_prenota);
-} # fine if (!is_array($profondita))
-$fatto = "NO";
+tab_a_var ($limiti_var,$app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_settimana_id,$anno,$dati_app,$profondita,$nome_tab_prenota);
+} # fine if (!@is_array($profondita))
+if ($profondita[controllato_tutti_occupati] != "SI") {
+$tutti_occupati = controlla_tutti_occupati ($idinizio,$idfine,$app_richiesti,$prenota_in_settimana_id,$app_prenota_id,$app_assegnabili_id,$dati_app);
+$profondita[controllato_tutti_occupati] = "SI";
+} # fine if ($profondita[controllato_tutti_occupati] != "SI")
+if ($tutti_occupati == "SI") $fatto = "SI";
+else $fatto = "NO";
 $num_da_liberare = 1;
 
 
 # cicli da ripetere per ogni appartamento fino a che $fatto = SI
-$fatto = "NO";
 
 # primo ciclo che controlla se c' gi un appartamento libero
+if ($fatto != "SI") {
 for ($num1 = 0 ; $num1 < $dati_app[totapp] ; $num1++) {
 $numapp = $dati_app[posizione][$num1];
 if (!$app_richiesti or $app_richiesti[$numapp] == "SI") {
-$prenotainperiodo = prenota_in_app_e_periodo($numapp,$idinizio,$idfine,&$app_prenota_id,&$prenota_in_settimana_id);
+$prenotainperiodo = prenota_in_app_e_periodo($numapp,$idinizio,$idfine,$app_prenota_id,$prenota_in_settimana_id);
 if (count($prenotainperiodo) == 0) {
 $appartamento = $numapp;
 $fatto = "SI";
+if ($debug == "on") echo "LIBERATO1 $appartamento<br>";
 break;
 } # fine if (count($prenotainperiodo) == 0)
 } # fine if (!$app_richiesti or $app_richiesti[$numapp] == "SI")
 } # fine for $num1
+} # fine if ($fatto != "SI")
 
 if ($fatto != "SI") {
 
@@ -189,11 +317,11 @@ for ($num1 = $idinizio ; $num1 <= $idfine ; $num1++) $lista_prenota_periodo .= s
 $limiti_var[s_ini] = $idinizio;
 $limiti_var[s_fine] = $idfine;
 } # fine if (!$limiti_var[s_ini])
-if ($limiti_var[s_ini] > $idinizio) { 
+if ($limiti_var[s_ini] > $idinizio) {
 for ($num1 = $idinizio ; $num1 < $limiti_var[s_ini] ; $num1++) $lista_prenota_periodo .= substr($prenota_in_settimana_id[$num1],1);
 $limiti_var[s_ini] = $idinizio;
 } # fine if ($limiti_var[s_ini] > $idinizio)
-if ($limiti_var[s_fine] < $idfine) { 
+if ($limiti_var[s_fine] < $idfine) {
 for ($num1 = $limiti_var[s_fine] + 1 ; $num1 <= $idfine ; $num1++) $lista_prenota_periodo .= substr($prenota_in_settimana_id[$num1],1);
 $limiti_var[s_fine] = $idfine;
 } # fine if ($limiti_var[s_ini] > $idinizio)
@@ -205,7 +333,7 @@ if ($inizio_prenota_id[$lista_prenota_periodo[$num1]] < $limiti_var[n_ini]) $lim
 if ($fine_prenota_id[$lista_prenota_periodo[$num1]] > $limiti_var[n_fine]) $limiti_var[n_fine] = $fine_prenota_id[$lista_prenota_periodo[$num1]];
 } # fine for $num1
 if ($limiti_var[n_ini] < $limiti_var[ini] or $limiti_var[n_fine] > $limiti_var[fine]) {
-tab_a_var (&$limiti_var,&$app_prenota_id,&$app_orig_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$app_assegnabili_id,&$prenota_in_settimana_id,$anno,&$dati_app,$profondita,$nome_tab_prenota);
+tab_a_var ($limiti_var,$app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_settimana_id,$anno,$dati_app,$profondita,$nome_tab_prenota);
 } # fine if ($limiti_var[n_ini] < $limiti_var[ini] or $limiti_var[n_fine] > $limiti_var[fine])
 
 # ciclo che prova a spostare le prime prenotazioni ed eventualmente le
@@ -213,9 +341,10 @@ tab_a_var (&$limiti_var,&$app_prenota_id,&$app_orig_prenota_id,&$inizio_prenota_
 for ($num1 = 0 ; $num1 < $dati_app[totapp] ; $num1++) {
 $numapp = $dati_app[posizione][$num1];
 if (!$app_richiesti or $app_richiesti[$numapp] == "SI") {
-$prenotainperiodo = prenota_in_app_e_periodo($numapp,$idinizio,$idfine,&$app_prenota_id,&$prenota_in_settimana_id);
+$prenotainperiodo = prenota_in_app_e_periodo($numapp,$idinizio,$idfine,$app_prenota_id,$prenota_in_settimana_id);
 $idiniziop = "";
 $idfinep = "";
+unset($app_assegnabili);
 $mobile = "SI";
 $numprenotainperiodo = count($prenotainperiodo);
 
@@ -261,9 +390,9 @@ $idprenotainperiodo = $key;
 for ($num3 = 0 ; $num3 < $dati_app[totapp] ; $num3++) {
 if ($num3 != $num1) {
 $numapp2 = $dati_app[posizione][$num3];
-$prenotainperiodo2 = prenota_in_app_e_periodo($numapp2,$inizio_prenota_id[$idprenotainperiodo],$fine_prenota_id[$idprenotainperiodo],&$app_prenota_id,&$prenota_in_settimana_id);
-$numprenotainperiodo2 = count($prenotainperiodo2);
 if ($app_assegnabili_id[$idprenotainperiodo] == "v" or $app_assegnabili[$idprenotainperiodo][$numapp2] == "SI") {
+$prenotainperiodo2 = prenota_in_app_e_periodo($numapp2,$inizio_prenota_id[$idprenotainperiodo],$fine_prenota_id[$idprenotainperiodo],$app_prenota_id,$prenota_in_settimana_id);
+$numprenotainperiodo2 = count($prenotainperiodo2);
 if ($numprenotainperiodo2 == 0) {
 $nuovo_app[$idprenotainperiodo] = $numapp2;
 $liberabile[$idprenotainperiodo] = "SI";
@@ -277,6 +406,23 @@ reset($prenotainperiodo2);
 while (list($key2, $val2) = each($prenotainperiodo2)) {
 $idprenotainperiodo2 = $key2;
 if (!$app_assegnabili_id[$idprenotainperiodo2]) $prenota_fissa_presente = "SI";
+else {
+# se $idprenotainperiodo  uguale o minore di $idprenotainperiodo2 e ne contiene gli app. assegnabili  inutile fare lo scambio
+if ($inizio_prenota_id[$idprenotainperiodo2] <= $inizio_prenota_id[$idprenotainperiodo] and $fine_prenota_id[$idprenotainperiodo2] >= $fine_prenota_id[$idprenotainperiodo]) {
+if ($app_assegnabili_id[$idprenotainperiodo] == "v") $prenota_fissa_presente = "SI";
+else {
+if ($app_assegnabili_id[$idprenotainperiodo2] != "v") {
+$vett_assegnabili = explode (",",$app_assegnabili_id[$idprenotainperiodo2]);
+$num_assegnabili = count($vett_assegnabili);
+$lista_app_contenuta = "SI";
+for ($num4 = 0 ; $num4 < $num_assegnabili ; $num4++) {
+if ($app_assegnabili[$idprenotainperiodo][$vett_assegnabili[$num4]] != "SI") { $lista_app_contenuta = "NO"; break; }
+} # fine for $num4
+if ($lista_app_contenuta == "SI") $prenota_fissa_presente = "SI";
+} # fine if ($app_assegnabili_id[$idprenotainperiodo2] != "v")
+} # fine else if ($app_assegnabili_id[$idprenotainperiodo] == "v")
+} # fine if ($inizio_prenota_id[$idprenotainperiodo2] <= $inizio_prenota_id[$idprenotainperiodo] and...
+} # fine else if (!$app_assegnabili_id[$idprenotainperiodo2])
 } # fine while (list($key2, $val2) = each($prenotainperiodo2))
 if ($prenota_fissa_presente == "NO") {
 $scambiabile[$idprenotainperiodo] = "SI";
@@ -301,6 +447,7 @@ $app_prenota_id[$idprenotainperiodo] = $n_app;
 } # fine while (list($key, $val) = each($prenotainperiodo))
 $appartamento = $numapp;
 $fatto = "SI";
+if ($debug == "on") echo "LIBERATO2 $appartamento<br>";
 break;
 } # fine if ($tutti_liberabili != "NO")
 
@@ -323,9 +470,8 @@ if ($fatto == "SI") { break; }
 # Se non  ancora $fatto chiamo ricorsivamente liberasettimane con i dati
 # in $da_liberare e $da_scambiare, operando su una variabile temporanea.
 if ($fatto == "NO") {
-$nuova_profondita[iniziale] = $profondita[iniziale];
+$nuova_profondita = $profondita;
 $nuova_profondita[attuale] = $profondita[attuale] + 1;
-$nuova_profondita[tot_prenota_ini] = $profondita[tot_prenota_ini];
 
 for ($num1 = 1 ; $num1 < $num_da_liberare ; $num1++) {
 $n_app_prenota_id = $app_prenota_id;
@@ -333,7 +479,7 @@ $nuova_profondita[tot_prenota_attuale] = $profondita[tot_prenota_attuale];
 $idiniziop = $idinizio_da_liberare[$num1];
 $idfinep = $idfine_da_liberare[$num1];
 $numapp = $app_da_liberare[$num1];
-$prenotainperiodo = prenota_in_app_e_periodo($numapp,$idiniziop,$idfinep,&$n_app_prenota_id,&$prenota_in_settimana_id);
+$prenotainperiodo = prenota_in_app_e_periodo($numapp,$idiniziop,$idfinep,$n_app_prenota_id,$prenota_in_settimana_id);
 $numprenotainperiodo = count($prenotainperiodo);
 
 # Muovo le prenotazioni liberabili
@@ -350,11 +496,10 @@ $n_app_prenota_id[$idprenotainperiodo] = $n_app;
 $idinizio_prenota_falsa = $idinizio;
 $prenota_falsa_da_inserire = "NO";
 for ($num2 = $idinizio ; $num2 <= ($idfine+1) ; $num2++) {
-$prenota_presente = prenota_in_app_e_periodo($numapp,$num2,$num2,&$n_app_prenota_id,&$prenota_in_settimana_id);
+$prenota_presente = prenota_in_app_e_periodo($numapp,$num2,$num2,$n_app_prenota_id,$prenota_in_settimana_id);
 $num_prenota_presente = count($prenota_presente);
 if ($num_prenota_presente != 0 or $num2 == ($idfine+1)) {
 if ($prenota_falsa_da_inserire == "SI") {
-$new_num_tot_prenota = $new_num_tot_prenota + 1;
 $nuova_profondita[tot_prenota_attuale]++;
 $n_app_prenota_id[$nuova_profondita[tot_prenota_attuale]] = $numapp;
 $inizio_prenota_id[$nuova_profondita[tot_prenota_attuale]] = $idinizio_prenota_falsa;
@@ -405,7 +550,15 @@ for ($num3 = 0 ; $num3 < $dati_app[totapp] ; $num3++) {
 $numapp2 = $dati_app[posizione][$num3];
 if ($da_scambiare[$idprenotainperiodo][$numapp2] == "SI") { $ap_ric[$numapp2] = "SI"; }
 } # fine for $num3
-liberasettimane ($idinizioprenota2,$idfineprenota2,&$limiti_var,$anno,&$fatto2,&$appartamento2,$nuova_profondita,$ap_ric,&$n_app_prenota_id,&$app_orig_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$app_assegnabili_id,&$prenota_in_settimana_id,&$dati_app,$nome_tab_prenota);
+if ($debug == "on") {
+for ($i = 0 ; $i < $profondita[attuale] ; $i++) echo "&nbsp;&nbsp;";
+echo "<b>".$profondita[attuale]."</b> libera il $numapp da $idinizioprenota2 a $idfineprenota2 negli app $ap_ric_vedi<br>";
+} # fine if ($debug == "on")
+liberasettimane ($idinizioprenota2,$idfineprenota2,$limiti_var,$anno,$fatto2,$appartamento2,$nuova_profondita,$ap_ric,$n_app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_settimana_id,$dati_app,$nome_tab_prenota);
+if ($debug == "on") {
+for ($i = 0 ; $i < $profondita[attuale] ; $i++) echo "&nbsp;&nbsp;";
+echo "<b>".$profondita[attuale]."</b> finito<br>";
+} # fine if ($debug == "on")
 $inizio_prenota_id[$idprenotainperiodo] = $idinizioprenota2;
 $fine_prenota_id[$idprenotainperiodo] = $idfineprenota2;
 for ($num3 = $idinizioprenota2 ; $num3 < $idinizio_rimpicciolito ; $num3++) {
@@ -441,36 +594,66 @@ break;
 } # fine if ($scambiabile[$idprenotainperiodo] == "SI")
 } # fine while (list($key, $val) = each($prenotainperiodo))
 
-if ($fatto3 == "SI") {
-$app_prenota_id = $n_app_prenota_id;
+# cancello le prenotazioni kostanti
 for ($num2 = ($profondita[tot_prenota_attuale] + 1) ; $num2 <= $nuova_profondita[tot_prenota_attuale] ; $num2++) {
 for ($num3 = $inizio_prenota_id[$num2] ; $num3 <= $fine_prenota_id[$num2] ; $num3++) {
 $prenota_in_settimana_id[$num3] = str_replace(",$num2,",",",$prenota_in_settimana_id[$num3]);
 if ($prenota_in_settimana_id[$num3] == ",") $prenota_in_settimana_id[$num3] = "";
 } # fine for $num3
-$app_prenota_id[$num2] = "";
+$n_app_prenota_id[$num2] = "";
 $inizio_prenota_id[$num2] = "";
 $fine_prenota_id[$num2] = "";
 } # fine for $num2
+
+if ($fatto3 == "SI") {
+$app_prenota_id = $n_app_prenota_id;
 $fatto = "SI";
 $appartamento = $numapp;
 break;
 } # fine if ($fatto3 == "SI")
+
 } # fine for $num1
 
 } # fine if ($fatto == "NO")
 
 
-if ($primo_ciclo == "SI" and $fatto == "SI" and is_array($app_orig_prenota_id)) {
-reset($app_orig_prenota_id);
-while (list($idprenota, $app_prenota) = each($app_orig_prenota_id)) {
-if ($app_prenota_id[$idprenota] != $app_prenota) {
-$app_cambiato = $app_prenota_id[$idprenota];
-esegui_query("update $tableprenota set idappartamenti = '$app_cambiato' where idprenota = $idprenota");
-} # fine if ($app_prenota_id[$idprenota] != $app_prenota)
-} # fine while (list($key, $val) = each($app_orig_prenota_id))
-} # fine if ($primo_ciclo == "SI" and $fatto == "SI" and is_array($app_orig_prenota_id))
+if ($tutti_occupati == "SI") $fatto = "NO";
 
+# Se bisogna liberare altri appartamenti oltre a quello appena liberato
+if ($fatto == "SI" and $app_richiesti_vett[",numero,"]) {
+if ($app_richiesti_vett[",numero,"] > $app_richiesti_vett[id]) {
+$nuova_profondita = $profondita;
+$nuova_profondita[attuale]++;
+$nuova_profondita[controllato_tutti_occupati] = "NO";
+$n_app_prenota_id = $app_prenota_id;
+$nuova_profondita[tot_prenota_attuale]++;
+$id_prenota_lib = $nuova_profondita[tot_prenota_attuale];
+$n_app_prenota_id[$id_prenota_lib] = $appartamento;
+$inizio_prenota_id[$id_prenota_lib] = $idinizio;
+$fine_prenota_id[$id_prenota_lib] = $idfine;
+for ($num1 = $idinizio ; $num1 <= $idfine ; $num1++) {
+if (!$prenota_in_settimana_id[$num1]) $prenota_in_settimana_id[$num1] = ",";
+$prenota_in_settimana_id[$num1] .= $id_prenota_lib.",";
+} # fine for $num1
+if ($app_richiesti_vett[$app_richiesti_vett[id]] == ",tutti,") $app_assegnabili_id[$id_prenota_lib] = "v";
+else if (str_replace(",","",$app_richiesti_vett[$app_richiesti_vett[id]]) != $app_richiesti_vett[$app_richiesti_vett[id]]) $app_assegnabili_id[$id_prenota_lib] = $app_richiesti_vett[$app_richiesti_vett[id]];
+liberasettimane ($idinizio_vett,$idfine_vett,$limiti_var,$anno,$fatto,$appartamento_vett,$nuova_profondita,$app_richiesti_vett,$n_app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_settimana_id,$dati_app,$nome_tab_prenota);
+if ($fatto == "SI") $app_prenota_id = $n_app_prenota_id;
+$appartamento_vett[$app_richiesti_vett[id]] = $app_prenota_id[$id_prenota_lib];
+for ($num1 = $idinizio ; $num1 <= $idfine ; $num1++) {
+$prenota_in_settimana_id[$num1] = str_replace(",$id_prenota_lib,",",",$prenota_in_settimana_id[$num1]);
+if ($prenota_in_settimana_id[$num1] == ",") $prenota_in_settimana_id[$num1] = "";
+} # fine for $num1
+$app_prenota_id[$id_prenota_lib] = "";
+$inizio_prenota_id[$id_prenota_lib] = "";
+$fine_prenota_id[$id_prenota_lib] = "";
+$app_assegnabili_id[$id_prenota_lib] = "";
+} # fine if ($app_richiesti_vett[",numero,"] > $app_richiesti_vett[id])
+else $appartamento_vett[$app_richiesti_vett[id]] = $appartamento;
+$appartamento = $appartamento_vett;
+} # fine if ($fatto == "SI" and $app_richiesti_vett[",numero,"])
+
+if ($primo_ciclo == "SI" and $fatto == "SI") aggiorna_tableprenota ($app_prenota_id,$app_orig_prenota_id,$tableprenota);
 
 } # fine function liberasettimane
 
