@@ -8,7 +8,7 @@
 
 ##################################################################################
 #    PHP-RESIDENCE
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2004 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -29,38 +29,46 @@ $pag = "modifica_app.php";
 
 include("./dati/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
-connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
+$numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
 include ("./includes/funzioni.php");
-$tablenometariffe = ntariffe . $anno;
-$tableprenota = prenota .$anno;
-$tableperiodi = periodi . $anno;
-$tableregole = regole . $anno;
+$tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
+$tableprenota = $PHPR_TAB_PRE."prenota".$anno;
+$tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
+$tableregole = $PHPR_TAB_PRE."regole".$anno;
+$tableappartamenti = $PHPR_TAB_PRE."appartamenti";
+$tableanni = $PHPR_TAB_PRE."anni";
 
 
+$id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
+if ($id_utente and $id_utente == 1) {
+
+
+$idappartamenti = addslashes($idappartamenti);
+
 if ($cancella_app) {
 $oggi = date("Y-m-d");
 $anno_attuale = date("Y");
 
-$anni_esistenti = esegui_query("select * from anni order by idanni");
+$anni_esistenti = esegui_query("select * from $tableanni order by idanni");
 $num_anni_esistenti = numlin_query($anni_esistenti);
 $num_tab = 0;
 $num_altre_tab = 0;
-$tabelle_lock[$num_tab] = "anni";
+$tabelle_lock[$num_tab] = "$tableanni";
 for ($num1 = 0 ;$num1 < $num_anni_esistenti ; $num1++) {
 $anno_esistente = risul_query($anni_esistenti,$num1,idanni);
-$tableprenota_lock = prenota . $anno_esistente;
+$tableprenota_lock = $PHPR_TAB_PRE."prenota".$anno_esistente;
 $num_tab++;
 $tabelle_lock[$num_tab] = $tableprenota_lock;
 if ($anno_esistente >= $anno_attuale) {
-$tableperiodi_lock = periodi . $anno_esistente;
-$num_altre_tab++;
+$tableperiodi_lock = $PHPR_TAB_PRE."periodi".$anno_esistente;
 $altre_tab_lock[$num_altre_tab] = $tableperiodi_lock;
+$num_altre_tab++;
 } # fine if ($anno_esistente >= $anno_attuale)
 } # fine for $num1
 $num_tab++;
-$tabelle_lock[$num_tab] = "appartamenti";
+$tabelle_lock[$num_tab] = "$tableappartamenti";
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
-$anni_esistenti2 = esegui_query("select * from anni order by idanni");
+$anni_esistenti2 = esegui_query("select * from $tableanni order by idanni");
 $num_anni_esistenti2 = numlin_query($anni_esistenti2);
 if ($num_anni_esistenti != $num_anni_esistenti2) $cancellare = "NO";
 for ($num1 = 0 ;$num1 < $num_anni_esistenti ; $num1++) {
@@ -70,13 +78,13 @@ if ($anno_esistente != $anno_esistente2) $cancellare = "NO";
 } # fine for $num1
 if ($cancellare == "NO") echo mex("<b>L'appartamento non  stato cancellato</b> perch il database  cambiato nel frattempo",$pag).".<br>";
 
-$anni_da_controllare = esegui_query("select * from anni where idanni >= $anno_attuale");
+$anni_da_controllare = esegui_query("select * from $tableanni where idanni >= $anno_attuale");
 $num_anni_da_controllare = numlin_query($anni_da_controllare);
 for ($num1 = 0 ;$num1 < $num_anni_da_controllare ; $num1++) {
 $anno_da_controllare = risul_query($anni_da_controllare,$num1,idanni);
-$tableprenota_da_controllare = prenota . $anno_da_controllare;
+$tableprenota_da_controllare = $PHPR_TAB_PRE."prenota".$anno_da_controllare;
 if ($anno_da_controllare == $anno_attuale) {
-$tableperiodi_attuale = periodi . $anno_attuale;
+$tableperiodi_attuale = $PHPR_TAB_PRE."periodi".$anno_attuale;
 $idperiodocorrente = esegui_query("select idperiodi from $tableperiodi_attuale where datainizio <= '$oggi' and datafine >= '$oggi' ");
 $numidperiodocorrente = numlin_query($idperiodocorrente);
 if ( $numidperiodocorrente >= 1 ) {
@@ -101,7 +109,7 @@ break;
 } # fine if ($num_prenota_presenti != 0)
 } # fine for $num1
 
-$app_esiste = esegui_query("select * from appartamenti where idappartamenti = '$idappartamenti'");
+$app_esiste = esegui_query("select * from $tableappartamenti where idappartamenti = '$idappartamenti'");
 $num_app_esiste = numlin_query($app_esiste);
 if ($num_app_esiste != 1) {
 echo mex("L'appartamento",$pag)." $idappartamenti ".mex(" gi stato cancellato",$pag).".<br>";
@@ -113,6 +121,7 @@ if ($cancella_sicuro != "SI") {
 echo mex("Sei sicuro di voler <b>cancellare</b> l'appartamento",$pag)." <b>$idappartamenti</b>?<br>
 <form method=\"post\" action=\"modifica_app.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idappartamenti\" value=\"$idappartamenti\">
 <input type=\"hidden\" name=\"cancella_sicuro\" value=\"SI\">
 <input type=\"submit\" name=\"cancella_app\" value=\"".mex("SI",$pag)."\">
@@ -121,8 +130,8 @@ echo mex("Sei sicuro di voler <b>cancellare</b> l'appartamento",$pag)." <b>$idap
 } # fine if ($cancella_sicuro != "SI")
 
 else {
-esegui_query("delete from appartamenti where idappartamenti = '$idappartamenti'");
-$id_appartamenti = esegui_query("select idappartamenti from appartamenti order by idappartamenti ");
+esegui_query("delete from $tableappartamenti where idappartamenti = '$idappartamenti'");
+$id_appartamenti = esegui_query("select idappartamenti from $tableappartamenti order by idappartamenti ");
 $num_appartamenti = numlin_query($id_appartamenti);
 $fileaperto = fopen("dati/selectappartamenti.php","w+");
 flock($fileaperto,2);
@@ -138,6 +147,7 @@ fclose($fileaperto);
 echo mex("L'appartamento",$pag)." <b>$idappartamenti</b> ".mex(" stato cancellato",$pag).".<br>
 <form method=\"post\" action=\"visualizza_tabelle.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"appartamenti\">
 <input type=\"submit\" name=\"torna\" value=\"OK\">
 </form>";
@@ -148,6 +158,7 @@ else {
 echo "
 <form method=\"post\" action=\"modifica_app.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idappartamenti\" value=\"$idappartamenti\">
 <input type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
 <br></form>";
@@ -161,32 +172,42 @@ else {
 
 if ($modificaappartamento) {
 
-$anni_esistenti = esegui_query("select * from anni order by idanni");
+$n_commento = stripslashes($n_commento);
+$d_commento = stripslashes($d_commento);
+$n_nome_app = str_replace(",","",$n_nome_app);
+if (str_replace (" ","",$n_nome_app) == "") $n_nome_app = str_replace(" ","_",$n_nome_app);
+$n_nome_app = elimina_caratteri_slash ($n_nome_app);
+$n_numcasa = elimina_caratteri_slash ($n_numcasa);
+$n_numpiano = elimina_caratteri_slash ($n_numpiano);
+$n_maxoccupanti = elimina_caratteri_slash ($n_maxoccupanti);
+$n_priorita = elimina_caratteri_slash ($n_priorita);
+
+$anni_esistenti = esegui_query("select * from $tableanni order by idanni");
 $num_anni_esistenti = numlin_query($anni_esistenti);
 $num_tab = 0;
 $num_altre_tab = 0;
 if ($n_nome_app and $modificaappartamento == "Continua") {
-$tabelle_lock[$num_tab] = "anni";
+$tabelle_lock[$num_tab] = "$tableanni";
 for ($num1 = 0 ;$num1 < $num_anni_esistenti ; $num1++) {
 $anno_esistente = risul_query($anni_esistenti,$num1,idanni);
-$tableprenota_lock = prenota . $anno_esistente;
+$tableprenota_lock = $PHPR_TAB_PRE."prenota".$anno_esistente;
 $num_tab++;
 $tabelle_lock[$num_tab] = $tableprenota_lock;
 } # fine for $num1
 $num_tab++;
 } # fine if ($n_nome_app and $modificaappartamento == "Continua")
-$tabelle_lock[$num_tab] = "appartamenti";
+$tabelle_lock[$num_tab] = "$tableappartamenti";
 if ($n_nome_app and $modificaappartamento == "Continua") {
 for ($num1 = 0 ;$num1 < $num_anni_esistenti ; $num1++) {
 $anno_esistente = risul_query($anni_esistenti,$num1,idanni);
-$tableregole_lock = regole . $anno_esistente;
+$tableregole_lock = $PHPR_TAB_PRE."regole".$anno_esistente;
 $num_tab++;
 $tabelle_lock[$num_tab] = $tableregole_lock;
 } # fine for $num1
 } # fine if ($n_nome_app and $modificaappartamento == "Continua")
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 if ($n_nome_app and $modificaappartamento == "Continua") {
-$anni_esistenti2 = esegui_query("select * from anni order by idanni");
+$anni_esistenti2 = esegui_query("select * from $tableanni order by idanni");
 $num_anni_esistenti2 = numlin_query($anni_esistenti2);
 if ($num_anni_esistenti != $num_anni_esistenti2) $modificare = "NO";
 for ($num1 = 0 ;$num1 < $num_anni_esistenti ; $num1++) {
@@ -197,7 +218,7 @@ if ($anno_esistente != $anno_esistente2) $modificare = "NO";
 if ($modificare == "NO") echo mex("<b>L'appartamento non  stato modificato</b> perch il database  cambiato nel frattempo",$pag).".<br>";
 } # fine if ($n_nome_app and $modificaappartamento == "Continua")
 
-$app_esiste = esegui_query("select * from appartamenti where idappartamenti = '$idappartamenti'");
+$app_esiste = esegui_query("select * from $tableappartamenti where idappartamenti = '$idappartamenti'");
 $num_app_esiste = numlin_query($app_esiste);
 if ($num_app_esiste != 1) {
 echo mex("L'appartamento",$pag)." $idappartamenti ".mex("non esiste pi",$pag).".<br>";
@@ -206,7 +227,7 @@ $tornare_a = "inizio.php";
 } # fine if ($num_app_esiste != 1)
 else $tornare_a = $pag;
 if ($n_nome_app) {
-$app_esiste = esegui_query("select * from appartamenti where idappartamenti = '$n_nome_app'");
+$app_esiste = esegui_query("select * from $tableappartamenti where idappartamenti = '$n_nome_app'");
 $num_app_esiste = numlin_query($app_esiste);
 if ($num_app_esiste != 0) {
 echo mex("L'appartamento",$pag)." $n_nome_app ".mex("esiste gi",$pag).".<br>";
@@ -218,9 +239,6 @@ $modificare = "NO";
 if ($modificare != "NO") {
 
 if ($modificaappartamento != "Continua") {
-$n_commento = stripslashes($n_commento);
-$d_commento = stripslashes($d_commento);
-$n_nome_app = str_replace (",","",$n_nome_app);
 if ($n_nome_app) { echo mex("Il nome dell'appartamento verr cambiato da",$pag)." $idappartamenti ".mex("a",$pag)." $n_nome_app.<br>"; }
 if ($n_numcasa) { echo mex("La casa verr cambiata da",$pag)." $d_numcasa ".mex("a",$pag)." $n_numcasa.<br>"; }
 if ($n_numpiano) { echo mex("Il piano verr cambiato da",$pag)." $d_numpiano ".mex("a",$pag)." $n_numpiano.<br>"; }
@@ -229,6 +247,7 @@ if ($n_priorita) { echo mex("La priorit verr cambiata da",$pag)." $d_priorita ".
 if ($n_commento != $d_commento) { echo mex("Il commento verr cambiato",$pag).".<br>"; }
 echo "<form method=\"post\" action=\"modifica_app.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idappartamenti\" value=\"$idappartamenti\">
 <input type=\"hidden\" name=\"n_nome_app\" value=\"$n_nome_app\">
 <input type=\"hidden\" name=\"n_numcasa\" value=\"$n_numcasa\">
@@ -247,10 +266,10 @@ echo "<form method=\"post\" action=\"modifica_app.php\">
 else {
 
 if ($n_nome_app) {
-esegui_query("update appartamenti set idappartamenti = '$n_nome_app' where idappartamenti = '$idappartamenti' ");
+esegui_query("update $tableappartamenti set idappartamenti = '$n_nome_app' where idappartamenti = '$idappartamenti' ");
 for ($num1 = 0 ; $num1 < $num_anni_esistenti ; $num1++) {
 $anno_cambia = risul_query($anni_esistenti,$num1,idanni);
-$tableprenota_cambia = prenota . $anno_cambia;
+$tableprenota_cambia = $PHPR_TAB_PRE."prenota".$anno_cambia;
 esegui_query("update $tableprenota_cambia set idappartamenti = '$n_nome_app' where idappartamenti = '$idappartamenti' ");
 $prenota_c = esegui_query("select * from $tableprenota_cambia where app_assegnabili != '' ");
 $num_prenota_c = numlin_query($prenota_c);
@@ -271,7 +290,7 @@ break;
 } # fine if ($app_assegnabili[$num3] == $idappartamenti)
 } # fine for $num3
 } # fine for $num2
-$tableregole_cambia = regole . $anno_cambia;
+$tableregole_cambia = $PHPR_TAB_PRE."regole".$anno_cambia;
 esegui_query("update $tableregole_cambia set app_agenzia = '$n_nome_app' where app_agenzia = '$idappartamenti' ");
 $regole2 = esegui_query("select * from $tableregole_cambia where tariffa_per_app != '' ");
 $num_regole2 = numlin_query($regole2);
@@ -294,7 +313,7 @@ break;
 } # fine for $num2
 } # fine for $num1
 $idappartamenti = $n_nome_app;
-$id_appartamenti = esegui_query("select idappartamenti from appartamenti order by idappartamenti ");
+$id_appartamenti = esegui_query("select idappartamenti from $tableappartamenti order by idappartamenti ");
 $num_appartamenti = numlin_query($id_appartamenti);
 $fileaperto = fopen("dati/selectappartamenti.php","w+");
 flock($fileaperto,2);
@@ -310,19 +329,20 @@ fclose($fileaperto);
 } # fine if ($n_nome_app)
 
 if ($n_numcasa) {
-esegui_query("update appartamenti set numcasa = '$n_numcasa' where idappartamenti = '$idappartamenti' ");
+esegui_query("update $tableappartamenti set numcasa = '$n_numcasa' where idappartamenti = '$idappartamenti' ");
 } # fine if ($n_numcasa)
 if ($n_numpiano) {
-esegui_query("update appartamenti set numpiano = '$n_numpiano' where idappartamenti = '$idappartamenti' ");
+esegui_query("update $tableappartamenti set numpiano = '$n_numpiano' where idappartamenti = '$idappartamenti' ");
 } # fine if ($n_numpiano)
 if ($n_maxoccupanti) {
-esegui_query("update appartamenti set maxoccupanti = '$n_maxoccupanti' where idappartamenti = '$idappartamenti' ");
+esegui_query("update $tableappartamenti set maxoccupanti = '$n_maxoccupanti' where idappartamenti = '$idappartamenti' ");
 } # fine if ($n_maxoccupanti)
 if ($n_priorita) {
-esegui_query("update appartamenti set priorita = '$n_priorita' where idappartamenti = '$idappartamenti' ");
+esegui_query("update $tableappartamenti set priorita = '$n_priorita' where idappartamenti = '$idappartamenti' ");
 } # fine if ($n_priorita)
 if ($n_commento != $d_commento) {
-esegui_query("update appartamenti set commento = '$n_commento' where idappartamenti = '$idappartamenti' ");
+$n_commento = addslashes($n_commento);
+esegui_query("update $tableappartamenti set commento = '$n_commento' where idappartamenti = '$idappartamenti' ");
 } # fine if ($n_commento != $d_commento)
 echo mex("L'appartamento",$pag)." $idappartamenti ".mex(" stato modificato",$pag).".<br>";
 } # fine else if ($modificaappartamento != "Continua")
@@ -333,6 +353,7 @@ unlock_tabelle($tabelle_lock);
 echo "<center>
 <form method=\"post\" action=\"$tornare_a\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idappartamenti\" value=\"$idappartamenti\">";
 echo "<input type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
 <br></form></center>";
@@ -345,7 +366,7 @@ else {
 # Form per modificare l'appartamento.
 echo "<center><font size=+2><b>".mex("Modifica l'appartamento",$pag)." $idappartamenti.</b></font></center>";
 
-$appartamento = esegui_query("select * from appartamenti where idappartamenti = '$idappartamenti'");
+$appartamento = esegui_query("select * from $tableappartamenti where idappartamenti = '$idappartamenti'");
 $d_numcasa = risul_query($appartamento,0,numcasa);
 $d_numpiano = risul_query($appartamento,0,numpiano);
 $d_maxoccupanti = risul_query($appartamento,0,maxoccupanti);
@@ -355,6 +376,7 @@ $d_commento = risul_query($appartamento,0,commento);
 echo "<br>
 <form method=\"post\" action=\"modifica_app.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idappartamenti\" value=\"$idappartamenti\">
 <table cellspacing=2 cellpadding=5>
 <tr><td>".mex("Nome",$pag).": <b>$idappartamenti</b></td>
@@ -383,12 +405,14 @@ echo "<br>
 <hr width=\"95%\"><br><center>
 <form method=\"post\" action=\"modifica_app.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idappartamenti\" value=\"$idappartamenti\">
 <input type=\"submit\" name=\"cancella_app\" value=\"".mex("Cancella l'appartamento",$pag)." $idappartamenti\">
 </form></center>
 <hr width=\"95%\"><center>
 <form method=\"post\" action=\"visualizza_tabelle.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"appartamenti\">
 <input type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
 </form></center>";
@@ -401,6 +425,10 @@ echo "<br>
 
 
 
+} # fine if ($id_utente and $id_utente == 1)
+
+
+
 ?>
 
 
