@@ -8,7 +8,7 @@
 
 ##################################################################################
 #    PHP-RESIDENCE
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2004 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -29,18 +29,78 @@ $pag = "modifica_cliente.php";
 
 include("./dati/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
-connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
+$numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
 include ("./includes/funzioni.php");
 include("./dati/lingua.php");
-$tablenometariffe = ntariffe . $anno;
-$tableprenota = prenota .$anno;
-$tableperiodi = periodi . $anno;
-$tableregole = regole . $anno;
+$tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
+$tableprenota = $PHPR_TAB_PRE."prenota".$anno;
+$tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
+$tableregole = $PHPR_TAB_PRE."regole".$anno;
+$tableanni = $PHPR_TAB_PRE."anni";
+$tableclienti = $PHPR_TAB_PRE."clienti";
+$tablepersonalizza = $PHPR_TAB_PRE."personalizza";
+$tableutenti = $PHPR_TAB_PRE."utenti";
+
+
+$id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
+if ($id_utente) {
+
+if ($id_utente != 1) {
+$tableprivilegi = $PHPR_TAB_PRE."privilegi";
+$privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
+if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
+else {
+$anno_utente_attivato = "SI";
+$privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
+$priv_ins_clienti = risul_query($privilegi_globali_utente,0,priv_ins_clienti);
+if (substr($priv_ins_clienti,1,1) == "s") $modifica_clienti = "SI";
+if (substr($priv_ins_clienti,1,1) == "p") $modifica_clienti = "PROPRI";
+if (substr($priv_ins_clienti,1,1) != "s" and substr($priv_ins_clienti,1,1) != "p") $modifica_clienti = "NO";
+if (substr($priv_ins_clienti,2,1) == "s") $vedi_clienti = "SI";
+if (substr($priv_ins_clienti,2,1) == "p") $vedi_clienti = "PROPRI";
+if (substr($priv_ins_clienti,2,1) != "s" and substr($priv_ins_clienti,2,1) != "p") $vedi_clienti = "NO";
+$prefisso_clienti = risul_query($privilegi_globali_utente,0,prefisso_clienti);
+$attiva_prefisso_clienti = substr($prefisso_clienti,0,1);
+if ($attiva_prefisso_clienti != "n") {
+$prefisso_clienti = explode(",",$prefisso_clienti);
+$prefisso_clienti = $prefisso_clienti[1];
+} # fine if ($prefisso_clienti != "n")
+$contratti_consentiti = risul_query($privilegi_annuali_utente,0,contratti_consentiti);
+$attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
+if ($attiva_contratti_consentiti == "s") {
+$contratti_consentiti = explode(",",substr($contratti_consentiti,2));
+unset($contratti_consentiti_vett);
+for ($num1 = 0 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
+} # fine if ($attiva_contratti_consentiti == "s")
+$priv_mod_prenota = risul_query($privilegi_annuali_utente,0,priv_mod_prenota);
+$priv_mod_prenotazioni = substr($priv_mod_prenota,0,1);
+$priv_mod_prenota_iniziate = substr($priv_mod_prenota,11,1);
+$priv_mod_prenota_ore = substr($priv_mod_prenota,12,3);
+} # fine else if (numlin_query($privilegi_annuali_utente) == 0)
+} # fine if ($id_utente != 1)
+else {
+$anno_utente_attivato = "SI";
+$modifica_clienti = "SI";
+$vedi_clienti = "SI";
+$attiva_prefisso_clienti = "n";
+$attiva_contratti_consentiti = "n";
+$priv_mod_prenotazioni = "s";
+$priv_mod_prenota_iniziate = "s";
+$priv_mod_prenota_ore = "000";
+} # fine else if ($id_utente != 1)
+
+$idclienti = addslashes($idclienti);
+
+if ($modifica_clienti == "PROPRI" or $vedi_clienti == "PROPRI") {
+$cliente_proprio = esegui_query("select idclienti from $tableclienti where idclienti = '$idclienti' and utente_inserimento = '$id_utente'");
+if (numlin_query($cliente_proprio) == 0) $modifica_clienti = "NO";
+} # fine if ($modifica_clienti == "PROPRI" or $vedi_clienti == "PROPRI")
+if ($anno_utente_attivato == "SI" and $modifica_clienti != "NO" and $vedi_clienti != "NO" and $idclienti and controlla_num_pos($idclienti) == "SI") {
+
+
 $stile_soldi = stile_soldi();
 $stile_data = stile_data();
 
-
-
 if ($modifica_cliente) {
 if ($modifica_cliente != "Continua") {
 
@@ -64,15 +124,39 @@ if (!$d_datanascita2) { $d_datanascita2_f = "---"; }
 else $d_datanascita2_f = formatta_data($d_datanascita2,$stile_data);
 
 $n_cognome = stripslashes($n_cognome);
+$n_cognome = htmlspecialchars($n_cognome);
 $n_cognome2 = stripslashes($n_cognome2);
+$n_cognome2 = htmlspecialchars($n_cognome2);
 $n_citta = stripslashes($n_citta);
+$n_citta = htmlspecialchars($n_citta);
 $n_nazione = stripslashes($n_nazione);
+$n_nazione = htmlspecialchars($n_nazione);
+$n_nomevia = stripslashes($n_nomevia);
+$n_nomevia = htmlspecialchars($n_nomevia);
 $n_nome = stripslashes($n_nome);
+$n_nome = htmlspecialchars($n_nome);
 $n_nome2 = stripslashes($n_nome2);
+$n_nome2 = htmlspecialchars($n_nome2);
 $n_commento = stripslashes($n_commento);
+$n_commento = htmlspecialchars($n_commento);
 $d_commento = stripslashes($d_commento);
 
-if ($n_cognome) { echo mex("Il cognome verr cambiato da",$pag)." <b>$d_cognome</b> ".mex("a",$pag)." <b>$n_cognome</b>.<br>"; }
+$d_cognome = htmlspecialchars($d_cognome);
+$d_cognome2 = htmlspecialchars($d_cognome2);
+$d_citta = htmlspecialchars($d_citta);
+$d_nazione = htmlspecialchars($d_nazione);
+$d_nome = htmlspecialchars($d_nome);
+$d_nome2 = htmlspecialchars($d_nome2);
+$d_via = htmlspecialchars($d_via);
+$d_commento = htmlspecialchars($d_commento);
+
+if ($n_cognome) {
+echo mex("Il cognome verr cambiato da",$pag)." <b>$d_cognome</b> ".mex("a",$pag)." <b>";
+if ($attiva_prefisso_clienti == "p") echo $prefisso_clienti;
+echo $n_cognome;
+if ($attiva_prefisso_clienti == "s") echo $prefisso_clienti;
+echo "</b>.<br>";
+} # fine if ($n_cognome)
 if ($n_nome) { echo mex("Il nome verr cambiato da",$pag)." <b>$d_nome</b> ".mex("a",$pag)." <b>$n_nome</b>.<br>"; }
 if ($n_sesso) { echo mex("Il sesso verr cambiato a",$pag)." <b>$n_sesso</b>.<br>"; }
 if ($n_mesenascita and $n_giornonascita and $n_annonascita) {
@@ -81,9 +165,22 @@ $n_datanascita = $n_annonascita."-".$n_mesenascita."-".$n_giornonascita;
 $n_datanascita_f = formatta_data($n_datanascita,$stile_data);
 echo mex("La data di nascita  verr cambiata da",$pag)." <b>$d_datanascita_f</b> ".mex("a",$pag)." <b>$n_datanascita_f</b>.<br>";
 } # fine if ($mesenascita and $giornonascita and $annonascita)
+
+if ($id_nuovo_utente_inserimento != "" and $id_utente == 1) {
+$id_nuovo_utente_inserimento = addslashes($id_nuovo_utente_inserimento);
+$verifica_utente = esegui_query("select * from $tableutenti where idutenti = '$id_nuovo_utente_inserimento'");
+if (numlin_query($verifica_utente) == 1) {
+$nome_utente_nuovo = risul_query($verifica_utente,0,nome_utente);
+echo mex("Si considerer l'utente",$pag)." <b>$nome_utente_nuovo</b> ".mex("come colui che ha inserito il cliente",$pag).".<br>";
+} # fine if (numlin_query($verifica_utente) == 1)
+else unset($id_nuovo_utente_inserimento);
+} # fine if ($id_nuovo_utente_inserimento != "" and $id_utente == 1)
+
 if ($n_telefono) { echo mex("Il telefono verr cambiato da",$pag)." <b>$d_telefono</b> ".mex("a",$pag)." <b>$n_telefono</b>.<br>"; }
 if ($n_nomevia) {
-if ($lingua == "en") $n_nomevia = $n_nomevia . " " . $n_via;
+include("./dati/lingua.php");
+if ($lingua != "ita") include("./includes/lang/$lingua_mex/ordine_frasi.php");
+if ($ordine_strada == 2) $n_nomevia = $n_nomevia . " " . $n_via;
 else $n_nomevia = $n_via . " " . $n_nomevia;
 echo mex("La via  verr cambiata da",$pag)." <b>$d_via</b> ".mex("a",$pag)." <b>$n_nomevia</b>.<br>";
 } # fine if ($n_nomevia)
@@ -123,6 +220,7 @@ if ($c_nome2) { echo mex("Il <b>nome n 2</b> verr cancellato",$pag).".<br>"; }
 if ($c_datanascita2) { echo mex("La <b>data di nascita n 2</b>  verr cancellata",$pag).".<br>"; }
 echo "<form method=\"post\" action=\"modifica_cliente.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idclienti\" value=\"$idclienti\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
 <input type=\"hidden\" name=\"origine\" value=\"$origine\">
@@ -131,6 +229,7 @@ echo "<form method=\"post\" action=\"modifica_cliente.php\">
 <input type=\"hidden\" name=\"n_nome\" value=\"$n_nome\">
 <input type=\"hidden\" name=\"n_sesso\" value=\"$n_sesso\">
 <input type=\"hidden\" name=\"n_datanascita\" value=\"$n_datanascita\">
+<input type=\"hidden\" name=\"id_nuovo_utente_inserimento\" value=\"$id_nuovo_utente_inserimento\">
 <input type=\"hidden\" name=\"n_telefono\" value=\"$n_telefono\">
 <input type=\"hidden\" name=\"n_nomevia\" value=\"$n_nomevia\">
 <input type=\"hidden\" name=\"n_numcivico\" value=\"$n_numcivico\">
@@ -170,117 +269,161 @@ echo "<form method=\"post\" action=\"modifica_cliente.php\">
 } # fine if ($modifica_cliente != "Continua")
 
 else {
-$tabelle_lock = array("clienti");
-$tabelle_lock = lock_tabelle($tabelle_lock);
+$tabelle_lock = array("$tableclienti");
+$altre_tab_lock = array("$tableutenti");
+$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 if ($n_cognome) {
+if (get_magic_quotes_gpc()) $n_cognome = stripslashes($n_cognome);
+$n_cognome = addslashes($n_cognome);
 $n_cognome_maius = ucwords($n_cognome);
-esegui_query("update clienti set cognome = '$n_cognome_maius' where idclienti = $idclienti ");
+if ($attiva_prefisso_clienti == "p") $n_cognome_maius = $prefisso_clienti.$n_cognome_maius;
+if ($attiva_prefisso_clienti == "s") $n_cognome_maius = $n_cognome_maius.$prefisso_clienti;
+esegui_query("update $tableclienti set cognome = '$n_cognome_maius' where idclienti = '$idclienti' ");
 } # fine if ($n_cognome)
 if ($n_nome) {
+if (get_magic_quotes_gpc()) $n_nome = stripslashes($n_nome);
+$n_nome = addslashes($n_nome);
 $n_nome_maius = ucwords($n_nome);
-esegui_query("update clienti set nome = '$n_nome_maius' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set nome = '$n_nome_maius' where idclienti = '$idclienti' ");
 } # fine if ($n_nome)
 if ($n_sesso) {
-esegui_query("update clienti set sesso = '$n_sesso' where idclienti = $idclienti ");
+$n_sesso = addslashes($n_sesso);
+esegui_query("update $tableclienti set sesso = '$n_sesso' where idclienti = '$idclienti' ");
 } # fine if ($n_sesso)
 if ($n_datanascita) {
-esegui_query("update clienti set datanascita = '$n_datanascita' where idclienti = $idclienti ");
+$n_datanascita = addslashes($n_datanascita);
+esegui_query("update $tableclienti set datanascita = '$n_datanascita' where idclienti = '$idclienti' ");
 } # fine if ($n_datanascita)
+
+if ($id_nuovo_utente_inserimento != "" and $id_utente == 1) {
+$id_nuovo_utente_inserimento = addslashes($id_nuovo_utente_inserimento);
+$verifica_utente = esegui_query("select * from $tableutenti where idutenti = '$id_nuovo_utente_inserimento'");
+if (numlin_query($verifica_utente) == 1) esegui_query("update $tableclienti set utente_inserimento = '$id_nuovo_utente_inserimento' where idclienti = '$idclienti' ");
+} # fine if ($id_nuovo_utente_inserimento != "" and $id_utente == 1)
+
 if ($n_telefono) {
-esegui_query("update clienti set telefono = '$n_telefono' where idclienti = $idclienti ");
+if (get_magic_quotes_gpc()) $n_telefono = stripslashes($n_telefono);
+$n_telefono = addslashes($n_telefono);
+esegui_query("update $tableclienti set telefono = '$n_telefono' where idclienti = '$idclienti' ");
 } # fine if ($n_telefono)
 if ($n_nomevia) {
+if (get_magic_quotes_gpc()) $n_nomevia = stripslashes($n_nomevia);
+$n_nomevia = addslashes($n_nomevia);
 $n_nomevia_maius = ucwords($n_nomevia);
-esegui_query("update clienti set via = '$n_nomevia_maius' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set via = '$n_nomevia_maius' where idclienti = '$idclienti' ");
 } # fine if ($n_nomevia)
 if ($n_numcivico) {
-esegui_query("update clienti set numcivico = '$n_numcivico' where idclienti = $idclienti ");
+if (get_magic_quotes_gpc()) $n_numcivico = stripslashes($n_numcivico);
+$n_numcivico = addslashes($n_numcivico);
+esegui_query("update $tableclienti set numcivico = '$n_numcivico' where idclienti = '$idclienti' ");
 } # fine if ($n_numcivico)
 if ($n_citta) {
+if (get_magic_quotes_gpc()) $n_citta = stripslashes($n_citta);
+$n_citta = addslashes($n_citta);
 $n_citta_maius = ucwords($n_citta);
-esegui_query("update clienti set citta = '$n_citta_maius' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set citta = '$n_citta_maius' where idclienti = '$idclienti' ");
 } # fine if ($n_citta)
 if ($n_nazione) {
+if (get_magic_quotes_gpc()) $n_nazione = stripslashes($n_nazione);
+$n_nazione = addslashes($n_nazione);
 $n_nazione_maius = ucwords($n_nazione);
-esegui_query("update clienti set nazione = '$n_nazione_maius' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set nazione = '$n_nazione_maius' where idclienti = '$idclienti' ");
 } # fine if ($n_nazione)
 if ($n_cap) {
-esegui_query("update clienti set cap = '$n_cap' where idclienti = $idclienti ");
+if (get_magic_quotes_gpc()) $n_cap = stripslashes($n_cap);
+$n_cap = addslashes($n_cap);
+esegui_query("update $tableclienti set cap = '$n_cap' where idclienti = '$idclienti' ");
 } # fine if ($n_cap)
 if ($n_fax) {
-esegui_query("update clienti set fax = '$n_fax' where idclienti = $idclienti ");
+if (get_magic_quotes_gpc()) $n_fax = stripslashes($n_fax);
+$n_fax = addslashes($n_fax);
+esegui_query("update $tableclienti set fax = '$n_fax' where idclienti = '$idclienti' ");
 } # fine if ($n_fax)
 if ($n_email) {
-esegui_query("update clienti set email = '$n_email' where idclienti = $idclienti ");
+if (get_magic_quotes_gpc()) $n_email = stripslashes($n_email);
+$n_email = addslashes($n_email);
+esegui_query("update $tableclienti set email = '$n_email' where idclienti = '$idclienti' ");
 } # fine if ($n_email)
 if ($n_telefono2) {
-esegui_query("update clienti set telefono2 = '$n_telefono2' where idclienti = $idclienti ");
+if (get_magic_quotes_gpc()) $n_telefono2 = stripslashes($n_telefono2);
+$n_telefono2 = addslashes($n_telefono2);
+esegui_query("update $tableclienti set telefono2 = '$n_telefono2' where idclienti = '$idclienti' ");
 } # fine if ($n_telefono2)
 if ($n_telefono3) {
-esegui_query("update clienti set telefono3 = '$n_telefono3' where idclienti = $idclienti ");
+if (get_magic_quotes_gpc()) $n_telefono3 = stripslashes($n_telefono3);
+$n_telefono3 = addslashes($n_telefono3);
+esegui_query("update $tableclienti set telefono3 = '$n_telefono3' where idclienti = '$idclienti' ");
 } # fine if ($n_telefono3)
 if ($n_cognome2) {
+if (get_magic_quotes_gpc()) $n_cognome2 = stripslashes($n_cognome2);
+$n_cognome2 = addslashes($n_cognome2);
 $n_cognome2_maius = ucwords($n_cognome2);
-esegui_query("update clienti set cognome2 = '$n_cognome2_maius' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set cognome2 = '$n_cognome2_maius' where idclienti = '$idclienti' ");
 } # fine if ($n_cognome2)
 if ($n_nome2) {
+if (get_magic_quotes_gpc()) $n_nome2 = stripslashes($n_nome2);
+$n_nome2 = addslashes($n_nome2);
 $n_nome2_maius = ucwords($n_nome2);
-esegui_query("update clienti set nome2 = '$n_nome2_maius' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set nome2 = '$n_nome2_maius' where idclienti = '$idclienti' ");
 } # fine if ($n_nome2)
 if ($n_sesso2) {
-esegui_query("update clienti set sesso2 = '$n_sesso2' where idclienti = $idclienti ");
+$n_sesso2 = addslashes($n_sesso2);
+esegui_query("update $tableclienti set sesso2 = '$n_sesso2' where idclienti = '$idclienti' ");
 } # fine if ($n_sesso2)
 if ($n_datanascita2) {
-esegui_query("update clienti set datanascita2 = '$n_datanascita2' where idclienti = $idclienti ");
+$n_datanascita2 = addslashes($n_datanascita2);
+esegui_query("update $tableclienti set datanascita2 = '$n_datanascita2' where idclienti = '$idclienti' ");
 } # fine if ($n_datanascita2)
 if ($n_commento != $d_commento) {
-esegui_query("update clienti set commento = '$n_commento' where idclienti = $idclienti ");
+if (get_magic_quotes_gpc()) $n_commento = stripslashes($n_commento);
+$n_commento = addslashes($n_commento);
+esegui_query("update $tableclienti set commento = '$n_commento' where idclienti = '$idclienti' ");
 } # fine if ($n_commento != $d_commento)
 
 if ($c_nome) {
-esegui_query("update clienti set nome = '' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set nome = '' where idclienti = '$idclienti' ");
 } # fine if ($c_nome)
 if ($c_datanascita) {
-esegui_query("update clienti set datanascita = null where idclienti = $idclienti ");
+esegui_query("update $tableclienti set datanascita = null where idclienti = '$idclienti' ");
 } # fine if ($c_datanascita)
 if ($c_telefono) {
-esegui_query("update clienti set telefono = '' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set telefono = '' where idclienti = '$idclienti' ");
 } # fine if ($c_telefono)
 if ($c_via) {
-esegui_query("update clienti set via = '' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set via = '' where idclienti = '$idclienti' ");
 } # fine if ($c_via)
 if ($c_numcivico) {
-esegui_query("update clienti set numcivico = '' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set numcivico = '' where idclienti = '$idclienti' ");
 } # fine if ($c_numcivico)
 if ($c_citta) {
-esegui_query("update clienti set citta = '' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set citta = '' where idclienti = '$idclienti' ");
 } # fine if ($c_citta)
 if ($c_nazione) {
-esegui_query("update clienti set nazione = '' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set nazione = '' where idclienti = '$idclienti' ");
 } # fine if ($c_nazione)
 if ($c_cap) {
-esegui_query("update clienti set cap = '' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set cap = '' where idclienti = '$idclienti' ");
 } # fine if ($c_cap)
 if ($c_fax) {
-esegui_query("update clienti set fax = '' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set fax = '' where idclienti = '$idclienti' ");
 } # fine if ($c_fax)
 if ($c_email) {
-esegui_query("update clienti set email = '' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set email = '' where idclienti = '$idclienti' ");
 } # fine if ($c_email)
 if ($c_telefono2) {
-esegui_query("update clienti set telefono2 = '' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set telefono2 = '' where idclienti = '$idclienti' ");
 } # fine if ($c_telefono2)
 if ($c_telefono3) {
-esegui_query("update clienti set telefono3 = '' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set telefono3 = '' where idclienti = '$idclienti' ");
 } # fine if ($c_telefono3)
 if ($c_cognome2) {
-esegui_query("update clienti set cognome2 = '' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set cognome2 = '' where idclienti = '$idclienti' ");
 } # fine if ($c_cognome2)
 if ($c_nome2) {
-esegui_query("update clienti set nome2 = '' where idclienti = $idclienti ");
+esegui_query("update $tableclienti set nome2 = '' where idclienti = '$idclienti' ");
 } # fine if ($c_nome2)
 if ($c_datanascita2) {
-esegui_query("update clienti set datanascita2 = null where idclienti = $idclienti ");
+esegui_query("update $tableclienti set datanascita2 = null where idclienti = '$idclienti' ");
 } # fine if ($c_datanascita2)
 echo mex("Il cliente",$pag)." $idclienti ".mex(" stato modificato",$pag).".<br>";
 unlock_tabelle($tabelle_lock);
@@ -289,6 +432,7 @@ unlock_tabelle($tabelle_lock);
 echo "<center>
 <form method=\"post\" action=\"modifica_cliente.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
 <input type=\"hidden\" name=\"origine\" value=\"$origine\">
 <input type=\"hidden\" name=\"idclienti\" value=\"$idclienti\">";
@@ -303,7 +447,7 @@ else {
 # Form per modificare il cliente.
 echo "<center><font size=+2><b>".mex("Modifica i dati del cliente",$pag)." $idclienti</b></font><br></center><br>";
 
-$cliente = esegui_query("select * from clienti where idclienti = $idclienti");
+$cliente = esegui_query("select * from $tableclienti where idclienti = '$idclienti'");
 $d_cognome = risul_query($cliente,0,cognome);
 $d_nome = risul_query($cliente,0,nome);
 $d_sesso = risul_query($cliente,0,sesso);
@@ -326,14 +470,27 @@ $d_datanascita2 = risul_query($cliente,0,datanascita2);
 if ($d_datanascita2) $d_datanascita2_f = formatta_data($d_datanascita2,$stile_data);
 $d_commento = risul_query($cliente,0,commento);
 
+$d_cognome = htmlspecialchars($d_cognome);
+$d_cognome2 = htmlspecialchars($d_cognome2);
+$d_citta = htmlspecialchars($d_citta);
+$d_nazione = htmlspecialchars($d_nazione);
+$d_nome = htmlspecialchars($d_nome);
+$d_nome2 = htmlspecialchars($d_nome2);
+$d_via = htmlspecialchars($d_via);
+$d_commento = htmlspecialchars($d_commento);
+
 echo "<form method=\"post\" action=\"modifica_cliente.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idclienti\" value=\"$idclienti\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
 <input type=\"hidden\" name=\"origine\" value=\"$origine\">
 <table cellspacing=2 cellpadding=5>
-<tr><td>".mex("Cognome",$pag).": <b>$d_cognome</b></td><td>".mex("cambia in",$pag)."
- <input type=\"text\" name=\"n_cognome\" size=\"20\"></td></tr>
+<tr><td>".mex("Cognome",$pag).": <b>$d_cognome</b></td><td>".mex("cambia in",$pag)." ";
+if ($attiva_prefisso_clienti == "p") echo $prefisso_clienti;
+echo "<input type=\"text\" name=\"n_cognome\" size=\"20\">";
+if ($attiva_prefisso_clienti == "s") echo $prefisso_clienti;
+echo "</td></tr>
 <tr><td>".mex("Nome",$pag).": <b>$d_nome</b></td>
 <td>".mex("cambia in",$pag).": 
 <input type=\"text\" name=\"n_nome\" size=\"20\">
@@ -361,8 +518,33 @@ echo "<option value=\"$num\">$num</option>";
 } # fine for $num
 echo "</select>/
 <input type=\"text\" name=\"n_annonascita\" size=\"5\" maxlength=\"4\" value=\"19\">
-<br><input type=\"checkbox\" name=\"c_datanascita\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
-<tr><td>".mex("Telefono",$pag).": <b>$d_telefono</b></td>
+<br><input type=\"checkbox\" name=\"c_datanascita\" value=\"SI\">".mex("cancella",$pag)."</td></tr>";
+
+if ($id_utente == 1) {
+$tutti_utenti = esegui_query("select * from $tableutenti order by idutenti");
+$num_tutti_utenti = numlin_query($tutti_utenti);
+if ($num_tutti_utenti > 1) {
+$id_utente_inserimento = risul_query($cliente,0,utente_inserimento);
+unset($option_select_utenti);
+for ($num1 = 0 ; $num1 < $num_tutti_utenti ; $num1++) {
+$idutenti = risul_query($tutti_utenti,$num1,idutenti);
+if ($idutenti != $id_utente_inserimento) {
+$nome_utente_option = risul_query($tutti_utenti,$num1,nome_utente);
+$option_select_utenti .= "<option value=\"$idutenti\">$nome_utente_option</option>";
+} # fine if ($idutenti != $id_utente_inserimento)
+else $nome_utente_inserimento = risul_query($tutti_utenti,$num1,nome_utente);
+} # fine for $num1
+echo "<tr><td>
+".mex("Inserito da",$pag)." <b>$nome_utente_inserimento</b>
+</td><td>
+ ".mex("cambia in",$pag)." <select name=\"id_nuovo_utente_inserimento\">
+<option value=\"\" selected>----</option>
+$option_select_utenti
+</select></td></tr>";
+} # fine if ($num_tutti_utenti > 1)
+} # fine if ($id_utente == 1)
+
+echo "<tr><td>".mex("Telefono",$pag).": <b>$d_telefono</b></td>
 <td>".mex("cambia in",$pag).": 
 <input type=\"text\" name=\"n_telefono\">
 <br><input type=\"checkbox\" name=\"c_telefono\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
@@ -444,9 +626,10 @@ echo "</select>/
 <br><input type=\"checkbox\" name=\"c_datanascita2\" value=\"SI\">".mex("cancella",$pag)."</td></tr>
 </table>
 ".mex("Commento",$pag).":<br>
-<textarea name=\"n_commento\" rows=3 cols=45 wrap=\"virtual\">$d_commento</textarea><br>
+<textarea name=\"n_commento\" rows=3 cols=45 wrap=\"virtual\">$d_commento</textarea><br>";
 
-<center>
+
+echo "<center>
 
 <input type=\"hidden\" name=\"d_cognome\" value=\"$d_cognome\">
 <input type=\"hidden\" name=\"d_nome\" value=\"$d_nome\">
@@ -474,7 +657,7 @@ echo "</select>/
 if ($tipo_tabella) { $origine = "visualizza_tabelle.php"; }
 echo "<center><hr width=\"95%\">
 <form method=\"post\" action=\"visualizza_contratto.php\">
-<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"anno\" value=\"$anno\"><input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idclienti\" value=\"$idclienti\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
 
@@ -500,7 +683,7 @@ echo "<center><hr width=\"95%\">
 <input type=\"submit\" name=\"torna\" value=\"".mex("Visualizza il contratto",$pag)."\">
 ".mex("di tipo",$pag)." 
 <select name=\"tipo_contratto\">";
-$nomi_contratti = esegui_query("select valpersonalizza from personalizza where idpersonalizza = 'nomi_contratti'");
+$nomi_contratti = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'nomi_contratti' and idutente = '$id_utente'");
 $nomi_contratti = risul_query($nomi_contratti,0,valpersonalizza);
 $nomi_contratti = explode("#@&",$nomi_contratti);
 $num_nomi_contratti = count($nomi_contratti);
@@ -509,20 +692,24 @@ $dati_nome_contratto = explode("#?&",$nomi_contratti[$num1]);
 $nome_contratto[$dati_nome_contratto[0]] = $dati_nome_contratto[1];
 } # fine for $num1
 for ($num_contratto = 1 ; $num_contratto <= 18 ; $num_contratto++) {
+if ($attiva_contratti_consentiti == "n" or $contratti_consentiti_vett[$num_contratto] == "SI") {
 if ($nome_contratto[$num_contratto]) $num_contratto_vedi = $nome_contratto[$num_contratto];
 else $num_contratto_vedi = $num_contratto;
 echo "<option value=\"$num_contratto\">$num_contratto_vedi</option>";
+} # fine if ($attiva_contratti_consentiti == "n" or...
 } # fine for $num1
 echo "</select><br></form><hr width=\"95%\">";
 
 
-$anni = esegui_query("select * from anni order by idanni");
+
+if ($priv_mod_prenota_iniziate != "s") $id_periodo_corrente = calcola_id_periodo_corrente ($anno);
+$anni = esegui_query("select * from $tableanni order by idanni");
 $num_anni = numlin_query($anni);
 for ($num1 = 0 ; $num1 < $num_anni ; $num1 = $num1 + 1) {
 $anno_mostra = risul_query($anni,$num1,idanni);
-$tableprenota_mostra = prenota. $anno_mostra;
-$tableperiodi_mostra = periodi. $anno_mostra;
-$prenotazioni = esegui_query("select * from $tableprenota_mostra where idclienti = $idclienti");
+$tableprenota_mostra = $PHPR_TAB_PRE."prenota".$anno_mostra;
+$tableperiodi_mostra = $PHPR_TAB_PRE."periodi".$anno_mostra;
+$prenotazioni = esegui_query("select * from $tableprenota_mostra where idclienti = '$idclienti'");
 $num_prenotazioni = numlin_query($prenotazioni);
 if ($num_prenotazioni != 0) {
 echo "<br><font size=+1><b>".mex("Prenotazioni del cliente",$pag)." $d_cognome ".mex("nel",$pag)." $anno_mostra</b></font>
@@ -555,10 +742,12 @@ if ($id_data_inizio == 0) { $data_inizio = "<".$data_inizio_assoluta; }
 else {
 $data_inizio = esegui_query("select * from $tableperiodi_mostra where idperiodi = $id_data_inizio");
 $data_inizio = risul_query($data_inizio,0,datainizio);
+$data_inizio_f = formatta_data($data_inizio,$stile_data);
 } # fine else if ($id_data_inizio == 0)
 $id_data_fine = risul_query($prenotazioni,$num2,iddatafine);
 $data_fine = esegui_query("select * from $tableperiodi_mostra where idperiodi = $id_data_fine");
 $data_fine = risul_query($data_fine,0,datafine);
+$data_fine_f = formatta_data($data_fine,$stile_data);
 $mese = explode("-",$data_inizio);
 $mese = $mese[1];
 
@@ -596,13 +785,27 @@ $costo_tot_p = punti_in_num($costo_tot,$stile_soldi);
 if ($pagato < $caparra) { $colore = "#CC0000"; }
 else { if ($pagato < $costo_tot) { $colore = "#FFCC00"; } }
 
-if ($anno == $anno_mostra) {
-echo "<tr><td align=\"center\"><a href=\"modifica_prenota.php?id_prenota=$numero&anno=$anno&origine=visualizza_tabelle.php\">$numero</a></td>";
+$link_modifica = "SI";
+if ($priv_mod_prenotazioni == "n") $link_modifica = "NO";
+if ($priv_mod_prenotazioni == "p") {
+$utente_inserimento = risul_query($prenotazioni,$num2,utente_inserimento);
+if ($utente_inserimento != $id_utente) $link_modifica = "NO";
+} # fine if ($priv_mod_prenotazioni == "p")
+if ($priv_mod_prenota_iniziate != "s" and $id_periodo_corrente >= $id_data_inizio) $link_modifica = "NO";
+if ($priv_mod_prenota_ore != "000") {
+$adesso = date("YmdHis");
+$data_ins = risul_query($prenotazioni,$num2,datainserimento);
+$limite = date("YmdHis",mktime((substr($data_ins,11,2) + $priv_mod_prenota_ore),substr($data_ins,14,2),substr($data_ins,17,2),substr($data_ins,5,2),substr($data_ins,8,2),substr($data_ins,0,4)));
+if ($adesso > $limite) $link_modifica = "NO";
+} # fine if ($priv_mod_prenota_ore != "000")
+
+if ($anno == $anno_mostra and $link_modifica == "SI") {
+echo "<tr><td align=\"center\"><a href=\"modifica_prenota.php?id_prenota=$numero&anno=$anno&id_sessione=$id_sessione&origine=visualizza_tabelle.php\">$numero</a></td>";
 } # fine if ($anno = $anno_mostra)
 else { echo "<tr><td align=\"center\">$numero</td>"; }
 echo "<td align=\"center\">$d_cognome</td>
-<td align=\"center\">$data_inizio</td>
-<td align=\"center\">$data_fine</td>
+<td align=\"center\">$data_inizio_f</td>
+<td align=\"center\">$data_fine_f</td>
 <td align=\"center\">$costo_tot_p</td>
 <td align=\"center\">$caparra_p</td>
 <td align=\"center\"";
@@ -639,6 +842,7 @@ echo "</table><br>";
 echo "<hr width=\"95%\">
 <form method=\"post\" action=\"$origine\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
 <input type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
 </form></center>";
@@ -647,6 +851,10 @@ echo "<hr width=\"95%\">
 } # fine else if ($modifica_cliente)
 
 
+} # fine if ($anno_utente_attivato == "SI" and...
+} # fine if ($id_utente)
+
+
 
 ?>
 
