@@ -2,7 +2,7 @@
 
 #################################################################################
 #    PHP-RESIDENCE
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2004 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #################################################################################
 
-function spezzaprenota ($idinizio,$idfine,$anno,$limiti_var,$profondita,$n_tronchi,$vet_appartamenti,$vett_idinizio,$vett_idfine,$num_persone,$app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_settimana_id,$dati_app,$nome_tab_prenota = "prenota") {
+function spezzaprenota ($idinizio,$idfine,$anno,&$limiti_var,$profondita,&$n_tronchi,&$vet_appartamenti,&$vett_idinizio,&$vett_idfine,$num_persone,&$app_prenota_id,&$app_orig_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$app_assegnabili_id,&$prenota_in_settimana_id,&$dati_app,$nome_tab_prenota = "prenota") {
 
 $limiti_var[n_ini] = $idinizio;
 $limiti_var[n_fine] = $idfine;
@@ -34,7 +34,7 @@ $max_prenota = esegui_query("select max(idprenota) from $tableprenota");
 $tot_prenota = risul_query($max_prenota,0,0);
 $profondita[tot_prenota_ini] = $tot_prenota;
 $profondita[tot_prenota_attuale] = $tot_prenota;
-tab_a_var (&$limiti_var,&$app_prenota_id,&$app_orig_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$app_assegnabili_id,&$prenota_in_settimana_id,$anno,&$dati_app,$profondita,$nome_tab_prenota);
+tab_a_var ($limiti_var,$app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_settimana_id,$anno,$dati_app,$profondita,$nome_tab_prenota);
 } # fine if (!is_array($profondita))
 
 if (!$n_tronchi) $n_tronchi = 0;
@@ -46,7 +46,7 @@ $n_tronchi3 = -1;
 for ($num1 = 0 ; $num1 < $dati_app[totapp] ; $num1++) {
 $numapp = $dati_app[posizione][$num1];
 if ($dati_app[maxocc][$numapp] >= $num_persone) {
-$prima_prenota = prenota_in_app_e_periodo($numapp,$idinizio,$idinizio,&$app_prenota_id,&$prenota_in_settimana_id);
+$prima_prenota = prenota_in_app_e_periodo($numapp,$idinizio,$idinizio,$app_prenota_id,$prenota_in_settimana_id);
 $num_prima_prenota = count($prima_prenota);
 if ($num_prima_prenota != 0) {
 $idprima_prenota = key($prima_prenota);
@@ -67,7 +67,7 @@ $vett_idfine2 = $vett_idfine;
 for ($num2 = 0 ; $num2 < $numsettimane ; $num2 = $num2 + 1) {
 $id_settimana = $idinizio + $num2;
 $fatto_libera = "";
-liberasettimane ($id_settimana,$id_settimana,&$limiti_var,$anno,&$fatto_libera,&$app_liber,$nuova_profondita,$ap_ric,&$app_prenota_id2,&$app_orig_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$app_assegnabili_id,&$prenota_in_settimana_id,&$dati_app,$nome_tab_prenota);
+liberasettimane ($id_settimana,$id_settimana,$limiti_var,$anno,$fatto_libera,$app_liber,$nuova_profondita,$ap_ric,$app_prenota_id2,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_settimana_id,$dati_app,$nome_tab_prenota);
 if ($fatto_libera == "SI") {
 $nuova_profondita[tot_prenota_attuale]++;
 $app_prenota_id2[$nuova_profondita[tot_prenota_attuale]] = $numapp;
@@ -88,7 +88,7 @@ $vett_idfine2[$n_tronchi2] = $idfine;
 if ($fatto_libera != "SI") {
 $idfine2 = $id_settimana - 1;
 $vett_idfine2[$n_tronchi2] = $idfine2;
-spezzaprenota ($id_settimana,$idfine,$anno,&$limiti_var,$nuova_profondita,&$n_tronchi2,&$vet_appartamenti2,&$vett_idinizio2,&$vett_idfine2,$num_persone,&$app_prenota_id2,&$app_orig_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$app_assegnabili_id,&$prenota_in_settimana_id,&$dati_app,$nome_tab_prenota);
+spezzaprenota ($id_settimana,$idfine,$anno,$limiti_var,$nuova_profondita,$n_tronchi2,$vet_appartamenti2,$vett_idinizio2,$vett_idfine2,$num_persone,$app_prenota_id2,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_settimana_id,$dati_app,$nome_tab_prenota);
 if ($n_tronchi2 == -1) { break; }
 } # fine if ($fatto_libera != "SI")
 
