@@ -8,7 +8,7 @@
 
 ##################################################################################
 #    PHP-RESIDENCE
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2004 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -29,13 +29,44 @@ $pag = "storia_soldi.php";
 
 include("./dati/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
-connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
+$numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
 include ("./includes/funzioni.php");
-$tablenometariffe = ntariffe . $anno;
-$tableprenota = prenota .$anno;
-$tableperiodi = periodi . $anno;
-$tablecosti = costi . $anno;
-$tablesoldi = soldi . $anno;
+$tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
+$tableprenota = $PHPR_TAB_PRE."prenota".$anno;
+$tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
+$tablecosti = $PHPR_TAB_PRE."costi".$anno;
+$tablesoldi = $PHPR_TAB_PRE."soldi".$anno;
+$tablepersonalizza = $PHPR_TAB_PRE."personalizza";
+$tableclienti = $PHPR_TAB_PRE."clienti";
+$tableutenti = $PHPR_TAB_PRE."utenti";
+
+
+$id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
+if ($id_utente) {
+
+if ($id_utente != 1) {
+$tableprivilegi = $PHPR_TAB_PRE."privilegi";
+$privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
+if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
+else {
+$anno_utente_attivato = "SI";
+$privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
+$priv_vedi_tab = risul_query($privilegi_annuali_utente,0,priv_vedi_tab);
+$priv_vedi_tab_costi = substr($priv_vedi_tab,2,1);
+$priv_ins_clienti = risul_query($privilegi_globali_utente,0,priv_ins_clienti);
+if (substr($priv_ins_clienti,2,1) == "s") $vedi_clienti = "SI";
+if (substr($priv_ins_clienti,2,1) == "p") $vedi_clienti = "PROPRI";
+if (substr($priv_ins_clienti,2,1) != "s" and substr($priv_ins_clienti,2,1) != "p") $vedi_clienti = "NO";
+} # fine else if (numlin_query($privilegi_annuali_utente) == 0)
+} # fine if ($id_utente != 1)
+else {
+$anno_utente_attivato = "SI";
+$priv_vedi_tab_costi = "s";
+$vedi_clienti = "SI";
+} # fine if ($id_utente != 1)
+if ($anno_utente_attivato == "SI" and $priv_vedi_tab_costi != "n") {
+
+
 $stile_soldi = stile_soldi();
 $stile_data = stile_data();
 
@@ -43,6 +74,7 @@ if (!$cerca_prenota) {
 echo "<table width=\"100%\"><tr><td align=\"left\">
 <form method=\"post\" action=\"storia_soldi.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"senza_colori\" value=\"$senza_colori\">
 <input type=\"submit\" name=\"cerca_prenota\" value=\"".mex("Vedi le modifiche",$pag)."\">
  ".mex("dal",$pag)." <select name=\"cerca_inizioperiodo\">
@@ -82,6 +114,7 @@ echo "</select>
 <td align=\"right\">
 <form method=\"post\" action=\"storia_soldi.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"pagina_prenota\" value=\"$pagina_prenota\">";
 if (!$senza_colori) {
 echo "<input type=\"hidden\" name=\"senza_colori\" value=\"SI\">
@@ -110,13 +143,23 @@ $saldo_prenota_TOT = 0;
 if (!$senza_colori) $colore = "#b9ccd4";
 else $colore = "#ffffff";
 
+$tutti_utenti = esegui_query("select * from $tableutenti order by idutenti");
+$num_tutti_utenti = numlin_query($tutti_utenti);
+for ($num1 = 0 ; $num1 < $num_tutti_utenti ; $num1++) {
+$idutenti = risul_query($tutti_utenti,$num1,idutenti);
+$nome_utente_id[$idutenti] = risul_query($tutti_utenti,$num1,nome_utente);
+} # fine for $num1
+
 echo "<center><font size=+2><b>".mex("Storia delle entate e uscite delle prenotazioni inserite nel",$pag)." $anno$frase_periodo</b></font></center><br>";
 
-$storia_soldi_prenota = esegui_query("select * from $tablesoldi where saldo_prenota != ''$periodo_query order by idsoldi");
+if ($priv_vedi_tab_costi == "p") $condizione_variazioni_proprie = "and utente_inserimento = '$id_utente'";
+else $condizione_variazioni_proprie = "";
+
+$storia_soldi_prenota = esegui_query("select * from $tablesoldi where saldo_prenota != ''$periodo_query $condizione_variazioni_proprie order by idsoldi");
 $num_storia_soldi_prenota = numlin_query($storia_soldi_prenota);
 
 if (!$cerca_prenota) {
-$num_vedi_in_tab = esegui_query("select valpersonalizza_num from personalizza where idpersonalizza = 'num_righe_tab_storia_soldi'");
+$num_vedi_in_tab = esegui_query("select valpersonalizza_num from $tablepersonalizza where idpersonalizza = 'num_righe_tab_storia_soldi' and idutente = '$id_utente'");
 $num_vedi_in_tab = risul_query($num_vedi_in_tab,0,valpersonalizza_num);
 if ($num_storia_soldi_prenota > $num_vedi_in_tab) {
 $num_pagine_prenota = ceil($num_storia_soldi_prenota/$num_vedi_in_tab);
@@ -125,7 +168,7 @@ if (!$pagina_prenota) $pagina_prenota = $num_pagine_prenota;
 for ($num1 = 1 ; $num1 <= $num_pagine_prenota ; $num1++) {
 $stringa_pagine .= " ";
 if ($num1 != $pagina_prenota) {
-$stringa_pagine .= "<a href=\"./storia_soldi.php?anno=$anno&senza_colori=$senza_colori&pagina_prenota=$num1\">";
+$stringa_pagine .= "<a href=\"./storia_soldi.php?anno=$anno&id_sessione=$id_sessione&senza_colori=$senza_colori&pagina_prenota=$num1\">";
 } # fine if ($num1 != $pagina_prenota)
 else $stringa_pagine .= "<b>";
 $stringa_pagine .= "$num1";
@@ -143,8 +186,9 @@ echo "<table width=200 border=3 cellspacing=2 cellpadding=4 align=\"center\" bgc
 <tr><td align=\"center\" colspan=3>".mex("Dati della prenotazione",$pag)."</td>
 <td align=\"center\" rowspan=2>".mex("Pagato prima",$pag)."</td>
 <td align=\"center\" rowspan=2>".mex("Pagato dopo",$pag)."</td>
-<td align=\"center\" rowspan=2>".mex("Saldo",$pag)."</td>
-<td align=\"center\" rowspan=2>".mex("Data_della modifica",$pag)."</td></tr>
+<td align=\"center\" rowspan=2>".mex("Saldo",$pag)."</td>";
+if ($num_tutti_utenti > 1) echo "<td align=\"center\" rowspan=2>".mex("Utente",$pag)."</td>";
+echo "<td align=\"center\" rowspan=2>".mex("Data_della modifica",$pag)."</td></tr>
 <tr><td>".mex("Cognome_cliente",$pag)."</td><td>".mex("Data_inizale",$pag)."</td><td>".mex("Data_finale",$pag)."</td></tr>";
 
 if (!$cerca_prenota and $num_storia_soldi_prenota > $num_vedi_in_tab and $pagina_prenota != 1) echo $stringa_puntini_tab;
@@ -157,17 +201,28 @@ $data_inserimento_f = formatta_data($data_inserimento,$stile_data);
 #$data_inserimento = ereg_replace($string,"",$data_inserimento);
 $motivazione = risul_query($storia_soldi_prenota,$num1,motivazione);
 $motivazione = explode(";",$motivazione);
-$cognome = esegui_query("select * from clienti where idclienti = ".$motivazione[0]);
-$cognome = risul_query($cognome,0,cognome);
-$data_inizio = esegui_query("select * from $tableperiodi where idperiodi = ".$motivazione[1]);
+$cognome = esegui_query("select cognome,utente_inserimento from $tableclienti where idclienti = ".$motivazione[0]);
+$mostra_cliente = "SI";
+if ($vedi_clienti == "NO") $mostra_cliente = "NO";
+if ($vedi_clienti == "PROPRI") {
+$utente_inserimento = risul_query($cognome,0,utente_inserimento);
+if ($utente_inserimento != $id_utente) $mostra_cliente = "NO";
+} # fine if ($vedi_clienti == "PROPRI")
+if ($mostra_cliente == "NO") $cognome = mex("Cliente",$pag)." ".$motivazione[0];
+else $cognome = risul_query($cognome,0,cognome);
+$data_inizio = esegui_query("select * from $tableperiodi where idperiodi = '".$motivazione[1]."'");
 $data_inizio = risul_query($data_inizio,0,datainizio);
-$data_fine = esegui_query("select * from $tableperiodi where idperiodi = ".$motivazione[2]);
+$data_fine = esegui_query("select * from $tableperiodi where idperiodi = '".$motivazione[2]."'");
 $data_fine = risul_query($data_fine,0,datafine);
 $soldi_prima = risul_query($storia_soldi_prenota,$num1,soldi_prima);
 $saldo_prenota = risul_query($storia_soldi_prenota,$num1,saldo_prenota);
 $soldi_dopo = $soldi_prima + $saldo_prenota;
 $saldo_prenota_TOT = $saldo_prenota_TOT + $saldo_prenota;
+$utente_inserimento = risul_query($storia_soldi_prenota,$num1,utente_inserimento);
+$nome_utente_inserimento = $nome_utente_id[$utente_inserimento];
 
+$data_inizio_f = formatta_data($data_inizio,$stile_data);
+$data_fine_f = formatta_data($data_fine,$stile_data);
 $soldi_prima_p = punti_in_num($soldi_prima,$stile_soldi);
 $soldi_dopo_p = punti_in_num($soldi_dopo,$stile_soldi);
 $saldo_prenota_p = punti_in_num($saldo_prenota,$stile_soldi);
@@ -175,12 +230,13 @@ $saldo_prenota_p = punti_in_num($saldo_prenota,$stile_soldi);
 if ($cerca_prenota or (($num1+1) > (($pagina_prenota - 1)*$num_vedi_in_tab) and ($num1+1) <= (($pagina_prenota)*$num_vedi_in_tab)) ) {
 
 echo "<tr><td align=\"center\">$cognome</td>
-<td align=\"center\">$data_inizio</td>
-<td align=\"center\">$data_fine</td>
+<td align=\"center\">$data_inizio_f</td>
+<td align=\"center\">$data_fine_f</td>
 <td align=\"center\">$soldi_prima_p</td>
 <td align=\"center\">$soldi_dopo_p</td>
-<td align=\"center\">$saldo_prenota_p</td>
-<td align=\"center\"><font size=-1>$data_inserimento_f</font></td></tr>";
+<td align=\"center\">$saldo_prenota_p</td>";
+if ($num_tutti_utenti > 1) echo "<td align=\"center\"><font size=-1>$nome_utente_inserimento</font></td>";
+echo "<td align=\"center\"><font size=-1>$data_inserimento_f</font></td></tr>";
 
 } # fine if ($cerca_prenota or (...
 
@@ -190,8 +246,9 @@ if (!$cerca_prenota and $num_storia_soldi_prenota > $num_vedi_in_tab and $pagina
 
 $saldo_prenota_TOT_p = punti_in_num($saldo_prenota_TOT,$stile_soldi);
 echo "<tr><td align=\"center\" colspan=5><b>".mex("TOTALE",$pag)."</b></td>
-<td align=\"center\">$saldo_prenota_TOT_p</td>
-<td align=\"center\">&nbsp;</td></tr>";
+<td align=\"center\">$saldo_prenota_TOT_p</td>";
+if ($num_tutti_utenti > 1) echo "<td align=\"center\">&nbsp;</td>";
+echo "<td align=\"center\">&nbsp;</td></tr>";
 
 $costo_cassa = esegui_query("select * from $tablecosti where idcosti = 0");
 $costo_cassa = risul_query($costo_cassa,0,val_costo);
@@ -201,9 +258,11 @@ $costo_cassa_p = punti_in_num($costo_cassa,$stile_soldi);
 $resto_tot_p = punti_in_num($resto_tot,$stile_soldi);
 echo "<tr><td align=\"center\" colspan=\"5\"><b><i>".mex("Trasferito in cassa",$pag).":</i></b></td>
 <td align=\"center\">$costo_cassa_p</td>";
+if ($num_tutti_utenti > 1) echo "<td align=\"center\">&nbsp;</td>";
 echo "<td align=\"center\">&nbsp;</td></tr>
 <tr><td align=\"center\" colspan=\"5\"><b><i>".mex("RESTO",$pag)."</i></b></td>
 <td align=\"center\">$resto_tot_p</td>";
+if ($num_tutti_utenti > 1) echo "<td align=\"center\">&nbsp;</td>";
 echo "<td align=\"center\">&nbsp;</td></tr>";
 } # fine if ($costo_cassa and !$cerca_prenota)
 
@@ -213,11 +272,18 @@ $stringa_pagine
 <br><center>
 <form method=\"post\" action=\"visualizza_tabelle.php\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"costi\">
 <input type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
 </form></center>";
 
 
+
+} # fine if ($anno_utente_attivato == "SI" and $priv_vedi_tab_costi != "n")
+} # fine if ($id_utente)
+
+
+
 ?>
 
 
