@@ -8,7 +8,7 @@
 
 #################################################################################
 #    PHP-RESIDENCE
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2004 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -29,8 +29,36 @@ $pag = "visualizza_contratto.php";
 
 include("./dati/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
-connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
+$numconnessione = connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
 include ("./includes/funzioni.php");
+
+
+$id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
+if ($id_utente) {
+
+if ($id_utente != 1) {
+$tableprivilegi = $PHPR_TAB_PRE."privilegi";
+$privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
+if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
+else {
+$anno_utente_attivato = "SI";
+$contratti_consentiti = risul_query($privilegi_annuali_utente,0,contratti_consentiti);
+$attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
+if ($attiva_contratti_consentiti == "s") {
+$contratti_consentiti = explode(",",substr($contratti_consentiti,2));
+unset($contratto_trovato);
+for ($num1 = 0 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1] and $contratti_consentiti[$num1] == $tipo_contratto) $contratto_trovato = "SI";
+if ($contratto_trovato != "SI") $anno_utente_attivato = "NO";
+} # fine if ($attiva_contratti_consentiti == "s")
+} # fine else if (numlin_query($privilegi_annuali_utente) == 0)
+} # fine if ($id_utente != 1)
+else {
+$anno_utente_attivato = "SI";
+$attiva_contratti_consentiti = "n";
+} # fine else if ($id_utente != 1)
+if ($anno_utente_attivato == "SI") {
+
+
 $stile_soldi = stile_soldi();
 
 $cognome = stripslashes($cognome);
@@ -55,6 +83,7 @@ $oggi = date("j/n/Y");
 
 if ($sesso == "f") {
 $il = "la";
+$Il = "La";
 $al = "alla";
 $e = "a";
 $o = "a";
@@ -62,6 +91,7 @@ $Mr = "s";
 } # fine if ($sesso == "f")
 else {
 $il = "il";
+$Il = "Il";
 $al = "al";
 $a = "";
 $o = "o";
@@ -70,17 +100,17 @@ $Mr = "";
 
 if ($sesso2 == "f") {
 $il2 = "la";
+$Il2 = "La";
 $al2 = "alla";
 $e2 = "a";
 $o2 = "a";
-$Mr2 = "s";
 } # fine if ($sesso2 == "f")
 else {
 $il2 = "il";
+$Il2 = "Il";
 $al2 = "al";
 $a2 = "";
 $o2 = "o";
-$Mr2 = "";
 } # fine else if ($sesso2 == "f")
 
 if (!$nome) { $nome = "<b>____________________</b>"; }
@@ -166,71 +196,47 @@ $valore_costo_agg_sel_p = $val_costo_agg_p;
 } # fine if ($num_costo_agg_sel == $numca)
 } # fine for $numca
 
-$surname = $cognome;
-$name = $nome;
-$birthday = $datanascita;
-$nation = $nazione;
-$city = $citta;
-$street = $via;
-$street2 = $via2;
-$street_number = $numcivico;
-$postal_code = $cap;
-$telephone = $telefono;
-$telephone2 = $telefono2;
-$telephone3 = $telefono3;
-$surname2 = $cognome2;
-$name2 = $nome2;
-$birthday2 = $datanascita2;
-$people_num = $num_persone;
-$extra_beds_num = $n_letti_agg;
-$people_num_tot = $num_persone_tot;
-$fare_tot = $costo_tot;
-$deposit = $caparra;
-$deposit_rest = $resto_caparra;
-$starting_date = $data_inizio;
-$ending_date = $data_fine;
-$fare_name = $nome_tariffa;
-$fare_price = $costo_tariffa;
-$discount = $sconto;
-$comment = $commento;
-$apartment = $appartamento;
-$apartment_list = $app_assegnabili;
-$paid = $pagato;
-$all_extra_costs = $tutti_i_costi_agg;
-$sel_extra_cost_name = $nome_costo_agg_sel;
-$sel_extra_cost_value = $valore_costo_agg_sel;
-$today = $oggi;
-$fare_tot_p = $costo_tot_p;
-$deposit_p = $caparra_p;
-$paid_p = $pagato_p;
-$deposit_rest_p = $resto_caparra_p;
-$fare_price_p = $costo_tariffa_p;
-$all_extra_costs_p = $tutti_i_costi_agg_p;
-$sel_extra_cost_value_p = $valore_costo_agg_sel_p;
-$discount_p = $sconto_p;
 
-if ($tipo_contratto == 1) { include ("./contr/contr01.php"); }
-if ($tipo_contratto == 2) { include ("./contr/contr02.php"); }
-if ($tipo_contratto == 3) { include ("./contr/contr03.php"); }
-if ($tipo_contratto == 4) { include ("./contr/contr04.php"); }
-if ($tipo_contratto == 5) { include ("./contr/contr05.php"); }
-if ($tipo_contratto == 6) { include ("./contr/contr06.php"); }
-if ($tipo_contratto == 7) { include ("./contr/contr07.php"); }
-if ($tipo_contratto == 8) { include ("./contr/contr08.php"); }
-if ($tipo_contratto == 9) { include ("./contr/contr09.php"); }
-if ($tipo_contratto == 10) { include ("./contr/contr10.php"); }
-if ($tipo_contratto == 11) { include ("./contr/contr11.php"); }
-if ($tipo_contratto == 12) { include ("./contr/contr12.php"); }
-if ($tipo_contratto == 13) { include ("./contr/contr13.php"); }
-if ($tipo_contratto == 14) { include ("./contr/contr14.php"); }
-if ($tipo_contratto == 15) { include ("./contr/contr15.php"); }
-if ($tipo_contratto == 16) { include ("./contr/contr16.php"); }
-if ($tipo_contratto == 17) { include ("./contr/contr17.php"); }
-if ($tipo_contratto == 18) { include ("./contr/contr18.php"); }
+include("./dati/lingua.php");
+$lang_dir = opendir("./includes/lang/");
+while ($ini_lingua = readdir($lang_dir)) {
+if ($ini_lingua != "." && $ini_lingua != ".." && $ini_lingua != $lingua) {
+include("./includes/lang/$ini_lingua/visualizza_contratto_var.php");
+} # fine if ($file != "." && $file != ".." && $ini_lingua != $lingua)
+} # fine while ($file = readdir($lang_dig))
+closedir($lang_dir);
+if ($lingua[$id_utente] != "ita") include("./includes/lang/".$lingua[$id_utente]."/visualizza_contratto_var.php");
+
+
+if ($tipo_contratto == 1) include ("./contr/contr01.php");
+if ($tipo_contratto == 2) include ("./contr/contr02.php");
+if ($tipo_contratto == 3) include ("./contr/contr03.php");
+if ($tipo_contratto == 4) include ("./contr/contr04.php");
+if ($tipo_contratto == 5) include ("./contr/contr05.php");
+if ($tipo_contratto == 6) include ("./contr/contr06.php");
+if ($tipo_contratto == 7) include ("./contr/contr07.php");
+if ($tipo_contratto == 8) include ("./contr/contr08.php");
+if ($tipo_contratto == 9) include ("./contr/contr09.php");
+if ($tipo_contratto == 10) include ("./contr/contr10.php");
+if ($tipo_contratto == 11) include ("./contr/contr11.php");
+if ($tipo_contratto == 12) include ("./contr/contr12.php");
+if ($tipo_contratto == 13) include ("./contr/contr13.php");
+if ($tipo_contratto == 14) include ("./contr/contr14.php");
+if ($tipo_contratto == 15) include ("./contr/contr15.php");
+if ($tipo_contratto == 16) include ("./contr/contr16.php");
+if ($tipo_contratto == 17) include ("./contr/contr17.php");
+if ($tipo_contratto == 18) include ("./contr/contr18.php");
 
 
 echo $contratto;
 
+
+
+} # fine if ($anno_utente_attivato == "SI")
+} # fine if ($id_utente)
+
+
+
 ?>
 
 </body>
